/**********************************************************************
TERMS OF USE - EASING EQUATIONS
Open source under the BSD License.
Copyright (c) 2001 Robert Penner
JavaScript version copyright (C) 2006 by Philippe Maegerman
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

   * Redistributions of source code must retain the above copyright
notice, this list of conditions and the following disclaimer.
   * Redistributions in binary form must reproduce the above
copyright notice, this list of conditions and the following disclaimer
in the documentation and/or other materials provided with the
distribution.
   * Neither the name of the author nor the names of contributors may
be used to endorse or promote products derived from this software
without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

*****************************************/
function Delegate() {}
Delegate.create = function (o, f) {
	var a = new Array() ;
	var l = arguments.length ;
	for(var i = 2 ; i < l ; i++) a[i - 2] = arguments[i] ;
	return function() {
		var aP = [].concat(arguments, a) ;
		f.apply(o, aP);
	}
}

Tween = function(obj, prop, func, begin, finish, duration, suffixe){
	this.init(obj, prop, func, begin, finish, duration, suffixe)
}
var t = Tween.prototype;

t.obj = new Object();
t.prop='';
t.func = function (t, b, c, d) { return c*t/d + b; };
t.begin = 0;
t.change = 0;
t.prevTime = 0;
t.prevPos = 0;
t.looping = false;
t._duration = 0;
t._time = 0;
t._pos = 0;
t._position = 0;
t._startTime = 0;
t._finish = 0;
t.name = '';
t.suffixe = '';
t._listeners = new Array();	
t.setTime = function(t){
	this.prevTime = this._time;
	if (t > this.getDuration()) {
		if (this.looping) {
			this.rewind (t - this._duration);
			this.update();
			this.broadcastMessage('onMotionLooped',{target:this,type:'onMotionLooped'});
		} else {
			this._time = this._duration;
			this.update();
			this.stop();
			this.broadcastMessage('onMotionFinished',{target:this,type:'onMotionFinished'});
		}
	} else if (t < 0) {
		this.rewind();
		this.update();
	} else {
		this._time = t;
		this.update();
	}
}
t.getTime = function(){
	return this._time;
}
t.setDuration = function(d){
	this._duration = (d == null || d <= 0) ? 100000 : d;
}
t.getDuration = function(){
	return this._duration;
}
t.setPosition = function(p){
	this.prevPos = this._pos;
	var a = this.suffixe != '' ? this.suffixe : '';
	this.obj[this.prop] = Math.round(p) + a;
	this._pos = p;
	this.broadcastMessage('onMotionChanged',{target:this,type:'onMotionChanged'});
}
t.getPosition = function(t){
	if (t == undefined) t = this._time;
	return this.func(t, this.begin, this.change, this._duration);
};
t.setFinish = function(f){
	this.change = f - this.begin;
};
t.getFinish = function(){
	return this.begin + this.change;
};
t.init = function(obj, prop, func, begin, finish, duration, suffixe){
	if (!arguments.length) return;
	this._listeners = new Array();
	this.addListener(this);
	if(suffixe) this.suffixe = suffixe;
	this.obj = obj;
	this.prop = prop;
	this.begin = begin;
	this._pos = begin;
	this.setDuration(duration);
	if (func!=null && func!='') {
		this.func = func;
	}
	this.setFinish(finish);
}
t.start = function(){
	this.rewind();
	this.startEnterFrame();
	this.broadcastMessage('onMotionStarted',{target:this,type:'onMotionStarted'});
	//alert('in');
}
t.rewind = function(t){
	this.stop();
	this._time = (t == undefined) ? 0 : t;
	this.fixTime();
	this.update();
}
t.fforward = function(){
	this._time = this._duration;
	this.fixTime();
	this.update();
}
t.update = function(){
	this.setPosition(this.getPosition(this._time));
	}
t.startEnterFrame = function(){
	this.stopEnterFrame();
	this.isPlaying = true;
	this.onEnterFrame();
}
t.onEnterFrame = function(){
	if(this.isPlaying) {
		this.nextFrame();
		setTimeout(Delegate.create(this, this.onEnterFrame), 0);
	}
}
t.nextFrame = function(){
	this.setTime((this.getTimer() - this._startTime) / 1000);
	}
t.stop = function(){
	this.stopEnterFrame();
	this.broadcastMessage('onMotionStopped',{target:this,type:'onMotionStopped'});
}
t.stopEnterFrame = function(){
	this.isPlaying = false;
}

t.continueTo = function(finish, duration){
	this.begin = this._pos;
	this.setFinish(finish);
	if (this._duration != undefined)
		this.setDuration(duration);
	this.start();
}
t.resume = function(){
	this.fixTime();
	this.startEnterFrame();
	this.broadcastMessage('onMotionResumed',{target:this,type:'onMotionResumed'});
}
t.yoyo = function (){
	this.continueTo(this.begin,this._time);
}

t.addListener = function(o){
	this.removeListener (o);
	return this._listeners.push(o);
}
t.removeListener = function(o){
	var a = this._listeners;	
	var i = a.length;
	while (i--) {
		if (a[i] == o) {
			a.splice (i, 1);
			return true;
		}
	}
	return false;
}
t.broadcastMessage = function(){
	var arr = new Array();
	for(var i = 0; i < arguments.length; i++){
		arr.push(arguments[i])
	}
	var e = arr.shift();
	var a = this._listeners;
	var l = a.length;
	for (var i=0; i<l; i++){
		if(a[i][e])
		a[i][e].apply(a[i], arr);
	}
}
t.fixTime = function(){
	this._startTime = this.getTimer() - this._time * 1000;
}
t.getTimer = function(){
	return new Date().getTime() - this._time;
}
Tween.backEaseIn = function(t,b,c,d,a,p){
	if (s == undefined) var s = 1.70158;
	return c*(t/=d)*t*((s+1)*t - s) + b;
}
Tween.backEaseOut = function(t,b,c,d,a,p){
	if (s == undefined) var s = 1.70158;
	return c*((t=t/d-1)*t*((s+1)*t + s) + 1) + b;
}
Tween.backEaseInOut = function(t,b,c,d,a,p){
	if (s == undefined) var s = 1.70158; 
	if ((t/=d/2) < 1) return c/2*(t*t*(((s*=(1.525))+1)*t - s)) + b;
	return c/2*((t-=2)*t*(((s*=(1.525))+1)*t + s) + 2) + b;
}
Tween.elasticEaseIn = function(t,b,c,d,a,p){
		if (t==0) return b;  
		if ((t/=d)==1) return b+c;  
		if (!p) p=d*.3;
		if (!a || a < Math.abs(c)) {
			a=c; var s=p/4;
		}
		else 
			var s = p/(2*Math.PI) * Math.asin (c/a);
		
		return -(a*Math.pow(2,10*(t-=1)) * Math.sin( (t*d-s)*(2*Math.PI)/p )) + b;
	
}
Tween.elasticEaseOut = function (t,b,c,d,a,p){
		if (t==0) return b;  if ((t/=d)==1) return b+c;  if (!p) p=d*.3;
		if (!a || a < Math.abs(c)) { a=c; var s=p/4; }
		else var s = p/(2*Math.PI) * Math.asin (c/a);
		return (a*Math.pow(2,-10*t) * Math.sin( (t*d-s)*(2*Math.PI)/p ) + c + b);
	}
Tween.elasticEaseInOut = function (t,b,c,d,a,p){
	if (t==0) return b;  if ((t/=d/2)==2) return b+c;  if (!p) var p=d*(.3*1.5);
	if (!a || a < Math.abs(c)) {var a=c; var s=p/4; }
	else var s = p/(2*Math.PI) * Math.asin (c/a);
	if (t < 1) return -.5*(a*Math.pow(2,10*(t-=1)) * Math.sin( (t*d-s)*(2*Math.PI)/p )) + b;
	return a*Math.pow(2,-10*(t-=1)) * Math.sin( (t*d-s)*(2*Math.PI)/p )*.5 + c + b;
}

Tween.bounceEaseOut = function(t,b,c,d){
	if ((t/=d) < (1/2.75)) {
		return c*(7.5625*t*t) + b;
	} else if (t < (2/2.75)) {
		return c*(7.5625*(t-=(1.5/2.75))*t + .75) + b;
	} else if (t < (2.5/2.75)) {
		return c*(7.5625*(t-=(2.25/2.75))*t + .9375) + b;
	} else {
		return c*(7.5625*(t-=(2.625/2.75))*t + .984375) + b;
	}
}
Tween.bounceEaseIn = function(t,b,c,d){
	return c - Tween.bounceEaseOut (d-t, 0, c, d) + b;
	}
Tween.bounceEaseInOut = function(t,b,c,d){
	if (t < d/2) return Tween.bounceEaseIn (t*2, 0, c, d) * .5 + b;
	else return Tween.bounceEaseOut (t*2-d, 0, c, d) * .5 + c*.5 + b;
	}

Tween.strongEaseInOut = function(t,b,c,d){
	return c*(t/=d)*t*t*t*t + b;
	}

Tween.regularEaseIn = function(t,b,c,d){
	return c*(t/=d)*t + b;
	}
Tween.regularEaseOut = function(t,b,c,d){
	return -c *(t/=d)*(t-2) + b;
	}

Tween.regularEaseInOut = function(t,b,c,d){
	if ((t/=d/2) < 1) return c/2*t*t + b;
	return -c/2 * ((--t)*(t-2) - 1) + b;
	}
Tween.strongEaseIn = function(t,b,c,d){
	return c*(t/=d)*t*t*t*t + b;
	}
Tween.strongEaseOut = function(t,b,c,d){
	return c*((t=t/d-1)*t*t*t*t + 1) + b;
	}

Tween.strongEaseInOut = function(t,b,c,d){
	if ((t/=d/2) < 1) return c/2*t*t*t*t*t + b;
	return c/2*((t-=2)*t*t*t*t + 2) + b;
	}


OpacityTween.prototype = new Tween();
OpacityTween.prototype.constructor = Tween;
OpacityTween.superclass = Tween.prototype;

function OpacityTween(obj,func,fromOpacity,toOpacity,duration){
	this.targetObject = obj;
	this.init(new Object(),'x',func,fromOpacity,toOpacity,duration);
}
var o = OpacityTween.prototype;
o.targetObject = {};
o.onMotionChanged = function(evt){
	var v = evt.target._pos;
	var t = this.targetObject;
	t.style['opacity'] = v / 100;
	t.style['-moz-opacity'] = v / 100;
	if(t.filters) t.filters.alpha['opacity'] = v;
}


//v1.7
// Flash Player Version Detection
// Detect Client Browser type
// Copyright 2005-2007 Adobe Systems Incorporated.  All rights reserved.
var isIE  = (navigator.appVersion.indexOf("MSIE") != -1) ? true : false;
var isWin = (navigator.appVersion.toLowerCase().indexOf("win") != -1) ? true : false;
var isOpera = (navigator.userAgent.indexOf("Opera") != -1) ? true : false;

function ControlVersion()
{
	var version;
	var axo;
	var e;

	// NOTE : new ActiveXObject(strFoo) throws an exception if strFoo isn't in the registry

	try {
		// version will be set for 7.X or greater players
		axo = new ActiveXObject("ShockwaveFlash.ShockwaveFlash.7");
		version = axo.GetVariable("$version");
	} catch (e) {
	}

	if (!version)
	{
		try {
			// version will be set for 6.X players only
			axo = new ActiveXObject("ShockwaveFlash.ShockwaveFlash.6");
			
			// installed player is some revision of 6.0
			// GetVariable("$version") crashes for versions 6.0.22 through 6.0.29,
			// so we have to be careful. 
			
			// default to the first public version
			version = "WIN 6,0,21,0";

			// throws if AllowScripAccess does not exist (introduced in 6.0r47)		
			axo.AllowScriptAccess = "always";

			// safe to call for 6.0r47 or greater
			version = axo.GetVariable("$version");

		} catch (e) {
		}
	}

	if (!version)
	{
		try {
			// version will be set for 4.X or 5.X player
			axo = new ActiveXObject("ShockwaveFlash.ShockwaveFlash.3");
			version = axo.GetVariable("$version");
		} catch (e) {
		}
	}

	if (!version)
	{
		try {
			// version will be set for 3.X player
			axo = new ActiveXObject("ShockwaveFlash.ShockwaveFlash.3");
			version = "WIN 3,0,18,0";
		} catch (e) {
		}
	}

	if (!version)
	{
		try {
			// version will be set for 2.X player
			axo = new ActiveXObject("ShockwaveFlash.ShockwaveFlash");
			version = "WIN 2,0,0,11";
		} catch (e) {
			version = -1;
		}
	}
	
	return version;
}

// JavaScript helper required to detect Flash Player PlugIn version information
function GetSwfVer(){
	// NS/Opera version >= 3 check for Flash plugin in plugin array
	var flashVer = -1;
	
	if (navigator.plugins != null && navigator.plugins.length > 0) {
		if (navigator.plugins["Shockwave Flash 2.0"] || navigator.plugins["Shockwave Flash"]) {
			var swVer2 = navigator.plugins["Shockwave Flash 2.0"] ? " 2.0" : "";
			var flashDescription = navigator.plugins["Shockwave Flash" + swVer2].description;
			var descArray = flashDescription.split(" ");
			var tempArrayMajor = descArray[2].split(".");			
			var versionMajor = tempArrayMajor[0];
			var versionMinor = tempArrayMajor[1];
			var versionRevision = descArray[3];
			if (versionRevision == "") {
				versionRevision = descArray[4];
			}
			if (versionRevision[0] == "d") {
				versionRevision = versionRevision.substring(1);
			} else if (versionRevision[0] == "r") {
				versionRevision = versionRevision.substring(1);
				if (versionRevision.indexOf("d") > 0) {
					versionRevision = versionRevision.substring(0, versionRevision.indexOf("d"));
				}
			}
			var flashVer = versionMajor + "." + versionMinor + "." + versionRevision;
		}
	}
	// MSN/WebTV 2.6 supports Flash 4
	else if (navigator.userAgent.toLowerCase().indexOf("webtv/2.6") != -1) flashVer = 4;
	// WebTV 2.5 supports Flash 3
	else if (navigator.userAgent.toLowerCase().indexOf("webtv/2.5") != -1) flashVer = 3;
	// older WebTV supports Flash 2
	else if (navigator.userAgent.toLowerCase().indexOf("webtv") != -1) flashVer = 2;
	else if ( isIE && isWin && !isOpera ) {
		flashVer = ControlVersion();
	}	
	return flashVer;
}

// When called with reqMajorVer, reqMinorVer, reqRevision returns true if that version or greater is available
function DetectFlashVer(reqMajorVer, reqMinorVer, reqRevision)
{
	versionStr = GetSwfVer();
	if (versionStr == -1 ) {
		return false;
	} else if (versionStr != 0) {
		if(isIE && isWin && !isOpera) {
			// Given "WIN 2,0,0,11"
			tempArray         = versionStr.split(" "); 	// ["WIN", "2,0,0,11"]
			tempString        = tempArray[1];			// "2,0,0,11"
			versionArray      = tempString.split(",");	// ['2', '0', '0', '11']
		} else {
			versionArray      = versionStr.split(".");
		}
		var versionMajor      = versionArray[0];
		var versionMinor      = versionArray[1];
		var versionRevision   = versionArray[2];

        	// is the major.revision >= requested major.revision AND the minor version >= requested minor
		if (versionMajor > parseFloat(reqMajorVer)) {
			return true;
		} else if (versionMajor == parseFloat(reqMajorVer)) {
			if (versionMinor > parseFloat(reqMinorVer))
				return true;
			else if (versionMinor == parseFloat(reqMinorVer)) {
				if (versionRevision >= parseFloat(reqRevision))
					return true;
			}
		}
		return false;
	}
}

function AC_AddExtension(src, ext)
{
  if (src.indexOf('?') != -1)
    return src.replace(/\?/, ext+'?'); 
  else
    return src + ext;
}

function AC_Generateobj(objAttrs, params, embedAttrs) 
{ 
  var str = '';
  if (isIE && isWin && !isOpera)
  {
    str += '<object ';
    for (var i in objAttrs)
    {
      str += i + '="' + objAttrs[i] + '" ';
    }
    str += '>';
    for (var i in params)
    {
      str += '<param name="' + i + '" value="' + params[i] + '" /> ';
    }
    str += '</object>';
  }
  else
  {
    str += '<embed ';
    for (var i in embedAttrs)
    {
      str += i + '="' + embedAttrs[i] + '" ';
    }
    str += '> </embed>';
  }

  document.write(str);
}

function AC_FL_RunContent(){
  var ret = 
    AC_GetArgs
    (  arguments, ".swf", "movie", "clsid:d27cdb6e-ae6d-11cf-96b8-444553540000"
     , "application/x-shockwave-flash"
    );
  AC_Generateobj(ret.objAttrs, ret.params, ret.embedAttrs);
}

function AC_SW_RunContent(){
  var ret = 
    AC_GetArgs
    (  arguments, ".dcr", "src", "clsid:166B1BCA-3F9C-11CF-8075-444553540000"
     , null
    );
  AC_Generateobj(ret.objAttrs, ret.params, ret.embedAttrs);
}

function AC_GetArgs(args, ext, srcParamName, classid, mimeType){
  var ret = new Object();
  ret.embedAttrs = new Object();
  ret.params = new Object();
  ret.objAttrs = new Object();
  for (var i=0; i < args.length; i=i+2){
    var currArg = args[i].toLowerCase();    

    switch (currArg){	
      case "classid":
        break;
      case "pluginspage":
        ret.embedAttrs[args[i]] = args[i+1];
        break;
      case "src":
      case "movie":	
        args[i+1] = AC_AddExtension(args[i+1], ext);
        ret.embedAttrs["src"] = args[i+1];
        ret.params[srcParamName] = args[i+1];
        break;
      case "onafterupdate":
      case "onbeforeupdate":
      case "onblur":
      case "oncellchange":
      case "onclick":
      case "ondblclick":
      case "ondrag":
      case "ondragend":
      case "ondragenter":
      case "ondragleave":
      case "ondragover":
      case "ondrop":
      case "onfinish":
      case "onfocus":
      case "onhelp":
      case "onmousedown":
      case "onmouseup":
      case "onmouseover":
      case "onmousemove":
      case "onmouseout":
      case "onkeypress":
      case "onkeydown":
      case "onkeyup":
      case "onload":
      case "onlosecapture":
      case "onpropertychange":
      case "onreadystatechange":
      case "onrowsdelete":
      case "onrowenter":
      case "onrowexit":
      case "onrowsinserted":
      case "onstart":
      case "onscroll":
      case "onbeforeeditfocus":
      case "onactivate":
      case "onbeforedeactivate":
      case "ondeactivate":
      case "type":
      case "codebase":
      case "id":
        ret.objAttrs[args[i]] = args[i+1];
        break;
      case "width":
      case "height":
      case "align":
      case "vspace": 
      case "hspace":
      case "class":
      case "title":
      case "accesskey":
      case "name":
      case "tabindex":
        ret.embedAttrs[args[i]] = ret.objAttrs[args[i]] = args[i+1];
        break;
      default:
        ret.embedAttrs[args[i]] = ret.params[args[i]] = args[i+1];
    }
  }
  ret.objAttrs["classid"] = classid;
  if (mimeType) ret.embedAttrs["type"] = mimeType;
  return ret;
}



/*!
 * jQuery JavaScript Library v1.6.1
 * http://jquery.com/
 *
 * Copyright 2011, John Resig
 * Dual licensed under the MIT or GPL Version 2 licenses.
 * http://jquery.org/license
 *
 * Includes Sizzle.js
 * http://sizzlejs.com/
 * Copyright 2011, The Dojo Foundation
 * Released under the MIT, BSD, and GPL Licenses.
 *
 * Date: Thu May 12 15:04:36 2011 -0400
 */
(function(a,b){function cy(a){return f.isWindow(a)?a:a.nodeType===9?a.defaultView||a.parentWindow:!1}function cv(a){if(!cj[a]){var b=f("<"+a+">").appendTo("body"),d=b.css("display");b.remove();if(d==="none"||d===""){ck||(ck=c.createElement("iframe"),ck.frameBorder=ck.width=ck.height=0),c.body.appendChild(ck);if(!cl||!ck.createElement)cl=(ck.contentWindow||ck.contentDocument).document,cl.write("<!doctype><html><body></body></html>");b=cl.createElement(a),cl.body.appendChild(b),d=f.css(b,"display"),c.body.removeChild(ck)}cj[a]=d}return cj[a]}function cu(a,b){var c={};f.each(cp.concat.apply([],cp.slice(0,b)),function(){c[this]=a});return c}function ct(){cq=b}function cs(){setTimeout(ct,0);return cq=f.now()}function ci(){try{return new a.ActiveXObject("Microsoft.XMLHTTP")}catch(b){}}function ch(){try{return new a.XMLHttpRequest}catch(b){}}function cb(a,c){a.dataFilter&&(c=a.dataFilter(c,a.dataType));var d=a.dataTypes,e={},g,h,i=d.length,j,k=d[0],l,m,n,o,p;for(g=1;g<i;g++){if(g===1)for(h in a.converters)typeof h=="string"&&(e[h.toLowerCase()]=a.converters[h]);l=k,k=d[g];if(k==="*")k=l;else if(l!=="*"&&l!==k){m=l+" "+k,n=e[m]||e["* "+k];if(!n){p=b;for(o in e){j=o.split(" ");if(j[0]===l||j[0]==="*"){p=e[j[1]+" "+k];if(p){o=e[o],o===!0?n=p:p===!0&&(n=o);break}}}}!n&&!p&&f.error("No conversion from "+m.replace(" "," to ")),n!==!0&&(c=n?n(c):p(o(c)))}}return c}function ca(a,c,d){var e=a.contents,f=a.dataTypes,g=a.responseFields,h,i,j,k;for(i in g)i in d&&(c[g[i]]=d[i]);while(f[0]==="*")f.shift(),h===b&&(h=a.mimeType||c.getResponseHeader("content-type"));if(h)for(i in e)if(e[i]&&e[i].test(h)){f.unshift(i);break}if(f[0]in d)j=f[0];else{for(i in d){if(!f[0]||a.converters[i+" "+f[0]]){j=i;break}k||(k=i)}j=j||k}if(j){j!==f[0]&&f.unshift(j);return d[j]}}function b_(a,b,c,d){if(f.isArray(b))f.each(b,function(b,e){c||bF.test(a)?d(a,e):b_(a+"["+(typeof e=="object"||f.isArray(e)?b:"")+"]",e,c,d)});else if(!c&&b!=null&&typeof b=="object")for(var e in b)b_(a+"["+e+"]",b[e],c,d);else d(a,b)}function b$(a,c,d,e,f,g){f=f||c.dataTypes[0],g=g||{},g[f]=!0;var h=a[f],i=0,j=h?h.length:0,k=a===bU,l;for(;i<j&&(k||!l);i++)l=h[i](c,d,e),typeof l=="string"&&(!k||g[l]?l=b:(c.dataTypes.unshift(l),l=b$(a,c,d,e,l,g)));(k||!l)&&!g["*"]&&(l=b$(a,c,d,e,"*",g));return l}function bZ(a){return function(b,c){typeof b!="string"&&(c=b,b="*");if(f.isFunction(c)){var d=b.toLowerCase().split(bQ),e=0,g=d.length,h,i,j;for(;e<g;e++)h=d[e],j=/^\+/.test(h),j&&(h=h.substr(1)||"*"),i=a[h]=a[h]||[],i[j?"unshift":"push"](c)}}}function bD(a,b,c){var d=b==="width"?bx:by,e=b==="width"?a.offsetWidth:a.offsetHeight;if(c==="border")return e;f.each(d,function(){c||(e-=parseFloat(f.css(a,"padding"+this))||0),c==="margin"?e+=parseFloat(f.css(a,"margin"+this))||0:e-=parseFloat(f.css(a,"border"+this+"Width"))||0});return e}function bn(a,b){b.src?f.ajax({url:b.src,async:!1,dataType:"script"}):f.globalEval((b.text||b.textContent||b.innerHTML||"").replace(bf,"/*$0*/")),b.parentNode&&b.parentNode.removeChild(b)}function bm(a){f.nodeName(a,"input")?bl(a):a.getElementsByTagName&&f.grep(a.getElementsByTagName("input"),bl)}function bl(a){if(a.type==="checkbox"||a.type==="radio")a.defaultChecked=a.checked}function bk(a){return"getElementsByTagName"in a?a.getElementsByTagName("*"):"querySelectorAll"in a?a.querySelectorAll("*"):[]}function bj(a,b){var c;if(b.nodeType===1){b.clearAttributes&&b.clearAttributes(),b.mergeAttributes&&b.mergeAttributes(a),c=b.nodeName.toLowerCase();if(c==="object")b.outerHTML=a.outerHTML;else if(c!=="input"||a.type!=="checkbox"&&a.type!=="radio"){if(c==="option")b.selected=a.defaultSelected;else if(c==="input"||c==="textarea")b.defaultValue=a.defaultValue}else a.checked&&(b.defaultChecked=b.checked=a.checked),b.value!==a.value&&(b.value=a.value);b.removeAttribute(f.expando)}}function bi(a,b){if(b.nodeType===1&&!!f.hasData(a)){var c=f.expando,d=f.data(a),e=f.data(b,d);if(d=d[c]){var g=d.events;e=e[c]=f.extend({},d);if(g){delete e.handle,e.events={};for(var h in g)for(var i=0,j=g[h].length;i<j;i++)f.event.add(b,h+(g[h][i].namespace?".":"")+g[h][i].namespace,g[h][i],g[h][i].data)}}}}function bh(a,b){return f.nodeName(a,"table")?a.getElementsByTagName("tbody")[0]||a.appendChild(a.ownerDocument.createElement("tbody")):a}function X(a,b,c){b=b||0;if(f.isFunction(b))return f.grep(a,function(a,d){var e=!!b.call(a,d,a);return e===c});if(b.nodeType)return f.grep(a,function(a,d){return a===b===c});if(typeof b=="string"){var d=f.grep(a,function(a){return a.nodeType===1});if(S.test(b))return f.filter(b,d,!c);b=f.filter(b,d)}return f.grep(a,function(a,d){return f.inArray(a,b)>=0===c})}function W(a){return!a||!a.parentNode||a.parentNode.nodeType===11}function O(a,b){return(a&&a!=="*"?a+".":"")+b.replace(A,"`").replace(B,"&")}function N(a){var b,c,d,e,g,h,i,j,k,l,m,n,o,p=[],q=[],r=f._data(this,"events");if(!(a.liveFired===this||!r||!r.live||a.target.disabled||a.button&&a.type==="click")){a.namespace&&(n=new RegExp("(^|\\.)"+a.namespace.split(".").join("\\.(?:.*\\.)?")+"(\\.|$)")),a.liveFired=this;var s=r.live.slice(0);for(i=0;i<s.length;i++)g=s[i],g.origType.replace(y,"")===a.type?q.push(g.selector):s.splice(i--,1);e=f(a.target).closest(q,a.currentTarget);for(j=0,k=e.length;j<k;j++){m=e[j];for(i=0;i<s.length;i++){g=s[i];if(m.selector===g.selector&&(!n||n.test(g.namespace))&&!m.elem.disabled){h=m.elem,d=null;if(g.preType==="mouseenter"||g.preType==="mouseleave")a.type=g.preType,d=f(a.relatedTarget).closest(g.selector)[0],d&&f.contains(h,d)&&(d=h);(!d||d!==h)&&p.push({elem:h,handleObj:g,level:m.level})}}}for(j=0,k=p.length;j<k;j++){e=p[j];if(c&&e.level>c)break;a.currentTarget=e.elem,a.data=e.handleObj.data,a.handleObj=e.handleObj,o=e.handleObj.origHandler.apply(e.elem,arguments);if(o===!1||a.isPropagationStopped()){c=e.level,o===!1&&(b=!1);if(a.isImmediatePropagationStopped())break}}return b}}function L(a,c,d){var e=f.extend({},d[0]);e.type=a,e.originalEvent={},e.liveFired=b,f.event.handle.call(c,e),e.isDefaultPrevented()&&d[0].preventDefault()}function F(){return!0}function E(){return!1}function m(a,c,d){var e=c+"defer",g=c+"queue",h=c+"mark",i=f.data(a,e,b,!0);i&&(d==="queue"||!f.data(a,g,b,!0))&&(d==="mark"||!f.data(a,h,b,!0))&&setTimeout(function(){!f.data(a,g,b,!0)&&!f.data(a,h,b,!0)&&(f.removeData(a,e,!0),i.resolve())},0)}function l(a){for(var b in a)if(b!=="toJSON")return!1;return!0}function k(a,c,d){if(d===b&&a.nodeType===1){var e="data-"+c.replace(j,"$1-$2").toLowerCase();d=a.getAttribute(e);if(typeof d=="string"){try{d=d==="true"?!0:d==="false"?!1:d==="null"?null:f.isNaN(d)?i.test(d)?f.parseJSON(d):d:parseFloat(d)}catch(g){}f.data(a,c,d)}else d=b}return d}var c=a.document,d=a.navigator,e=a.location,f=function(){function H(){if(!e.isReady){try{c.documentElement.doScroll("left")}catch(a){setTimeout(H,1);return}e.ready()}}var e=function(a,b){return new e.fn.init(a,b,h)},f=a.jQuery,g=a.$,h,i=/^(?:[^<]*(<[\w\W]+>)[^>]*$|#([\w\-]*)$)/,j=/\S/,k=/^\s+/,l=/\s+$/,m=/\d/,n=/^<(\w+)\s*\/?>(?:<\/\1>)?$/,o=/^[\],:{}\s]*$/,p=/\\(?:["\\\/bfnrt]|u[0-9a-fA-F]{4})/g,q=/"[^"\\\n\r]*"|true|false|null|-?\d+(?:\.\d*)?(?:[eE][+\-]?\d+)?/g,r=/(?:^|:|,)(?:\s*\[)+/g,s=/(webkit)[ \/]([\w.]+)/,t=/(opera)(?:.*version)?[ \/]([\w.]+)/,u=/(msie) ([\w.]+)/,v=/(mozilla)(?:.*? rv:([\w.]+))?/,w=d.userAgent,x,y,z,A=Object.prototype.toString,B=Object.prototype.hasOwnProperty,C=Array.prototype.push,D=Array.prototype.slice,E=String.prototype.trim,F=Array.prototype.indexOf,G={};e.fn=e.prototype={constructor:e,init:function(a,d,f){var g,h,j,k;if(!a)return this;if(a.nodeType){this.context=this[0]=a,this.length=1;return this}if(a==="body"&&!d&&c.body){this.context=c,this[0]=c.body,this.selector=a,this.length=1;return this}if(typeof a=="string"){a.charAt(0)!=="<"||a.charAt(a.length-1)!==">"||a.length<3?g=i.exec(a):g=[null,a,null];if(g&&(g[1]||!d)){if(g[1]){d=d instanceof e?d[0]:d,k=d?d.ownerDocument||d:c,j=n.exec(a),j?e.isPlainObject(d)?(a=[c.createElement(j[1])],e.fn.attr.call(a,d,!0)):a=[k.createElement(j[1])]:(j=e.buildFragment([g[1]],[k]),a=(j.cacheable?e.clone(j.fragment):j.fragment).childNodes);return e.merge(this,a)}h=c.getElementById(g[2]);if(h&&h.parentNode){if(h.id!==g[2])return f.find(a);this.length=1,this[0]=h}this.context=c,this.selector=a;return this}return!d||d.jquery?(d||f).find(a):this.constructor(d).find(a)}if(e.isFunction(a))return f.ready(a);a.selector!==b&&(this.selector=a.selector,this.context=a.context);return e.makeArray(a,this)},selector:"",jquery:"1.6.1",length:0,size:function(){return this.length},toArray:function(){return D.call(this,0)},get:function(a){return a==null?this.toArray():a<0?this[this.length+a]:this[a]},pushStack:function(a,b,c){var d=this.constructor();e.isArray(a)?C.apply(d,a):e.merge(d,a),d.prevObject=this,d.context=this.context,b==="find"?d.selector=this.selector+(this.selector?" ":"")+c:b&&(d.selector=this.selector+"."+b+"("+c+")");return d},each:function(a,b){return e.each(this,a,b)},ready:function(a){e.bindReady(),y.done(a);return this},eq:function(a){return a===-1?this.slice(a):this.slice(a,+a+1)},first:function(){return this.eq(0)},last:function(){return this.eq(-1)},slice:function(){return this.pushStack(D.apply(this,arguments),"slice",D.call(arguments).join(","))},map:function(a){return this.pushStack(e.map(this,function(b,c){return a.call(b,c,b)}))},end:function(){return this.prevObject||this.constructor(null)},push:C,sort:[].sort,splice:[].splice},e.fn.init.prototype=e.fn,e.extend=e.fn.extend=function(){var a,c,d,f,g,h,i=arguments[0]||{},j=1,k=arguments.length,l=!1;typeof i=="boolean"&&(l=i,i=arguments[1]||{},j=2),typeof i!="object"&&!e.isFunction(i)&&(i={}),k===j&&(i=this,--j);for(;j<k;j++)if((a=arguments[j])!=null)for(c in a){d=i[c],f=a[c];if(i===f)continue;l&&f&&(e.isPlainObject(f)||(g=e.isArray(f)))?(g?(g=!1,h=d&&e.isArray(d)?d:[]):h=d&&e.isPlainObject(d)?d:{},i[c]=e.extend(l,h,f)):f!==b&&(i[c]=f)}return i},e.extend({noConflict:function(b){a.$===e&&(a.$=g),b&&a.jQuery===e&&(a.jQuery=f);return e},isReady:!1,readyWait:1,holdReady:function(a){a?e.readyWait++:e.ready(!0)},ready:function(a){if(a===!0&&!--e.readyWait||a!==!0&&!e.isReady){if(!c.body)return setTimeout(e.ready,1);e.isReady=!0;if(a!==!0&&--e.readyWait>0)return;y.resolveWith(c,[e]),e.fn.trigger&&e(c).trigger("ready").unbind("ready")}},bindReady:function(){if(!y){y=e._Deferred();if(c.readyState==="complete")return setTimeout(e.ready,1);if(c.addEventListener)c.addEventListener("DOMContentLoaded",z,!1),a.addEventListener("load",e.ready,!1);else if(c.attachEvent){c.attachEvent("onreadystatechange",z),a.attachEvent("onload",e.ready);var b=!1;try{b=a.frameElement==null}catch(d){}c.documentElement.doScroll&&b&&H()}}},isFunction:function(a){return e.type(a)==="function"},isArray:Array.isArray||function(a){return e.type(a)==="array"},isWindow:function(a){return a&&typeof a=="object"&&"setInterval"in a},isNaN:function(a){return a==null||!m.test(a)||isNaN(a)},type:function(a){return a==null?String(a):G[A.call(a)]||"object"},isPlainObject:function(a){if(!a||e.type(a)!=="object"||a.nodeType||e.isWindow(a))return!1;if(a.constructor&&!B.call(a,"constructor")&&!B.call(a.constructor.prototype,"isPrototypeOf"))return!1;var c;for(c in a);return c===b||B.call(a,c)},isEmptyObject:function(a){for(var b in a)return!1;return!0},error:function(a){throw a},parseJSON:function(b){if(typeof b!="string"||!b)return null;b=e.trim(b);if(a.JSON&&a.JSON.parse)return a.JSON.parse(b);if(o.test(b.replace(p,"@").replace(q,"]").replace(r,"")))return(new Function("return "+b))();e.error("Invalid JSON: "+b)},parseXML:function(b,c,d){a.DOMParser?(d=new DOMParser,c=d.parseFromString(b,"text/xml")):(c=new ActiveXObject("Microsoft.XMLDOM"),c.async="false",c.loadXML(b)),d=c.documentElement,(!d||!d.nodeName||d.nodeName==="parsererror")&&e.error("Invalid XML: "+b);return c},noop:function(){},globalEval:function(b){b&&j.test(b)&&(a.execScript||function(b){a.eval.call(a,b)})(b)},nodeName:function(a,b){return a.nodeName&&a.nodeName.toUpperCase()===b.toUpperCase()},each:function(a,c,d){var f,g=0,h=a.length,i=h===b||e.isFunction(a);if(d){if(i){for(f in a)if(c.apply(a[f],d)===!1)break}else for(;g<h;)if(c.apply(a[g++],d)===!1)break}else if(i){for(f in a)if(c.call(a[f],f,a[f])===!1)break}else for(;g<h;)if(c.call(a[g],g,a[g++])===!1)break;return a},trim:E?function(a){return a==null?"":E.call(a)}:function(a){return a==null?"":(a+"").replace(k,"").replace(l,"")},makeArray:function(a,b){var c=b||[];if(a!=null){var d=e.type(a);a.length==null||d==="string"||d==="function"||d==="regexp"||e.isWindow(a)?C.call(c,a):e.merge(c,a)}return c},inArray:function(a,b){if(F)return F.call(b,a);for(var c=0,d=b.length;c<d;c++)if(b[c]===a)return c;return-1},merge:function(a,c){var d=a.length,e=0;if(typeof c.length=="number")for(var f=c.length;e<f;e++)a[d++]=c[e];else while(c[e]!==b)a[d++]=c[e++];a.length=d;return a},grep:function(a,b,c){var d=[],e;c=!!c;for(var f=0,g=a.length;f<g;f++)e=!!b(a[f],f),c!==e&&d.push(a[f]);return d},map:function(a,c,d){var f,g,h=[],i=0,j=a.length,k=a instanceof e||j!==b&&typeof j=="number"&&(j>0&&a[0]&&a[j-1]||j===0||e.isArray(a));if(k)for(;i<j;i++)f=c(a[i],i,d),f!=null&&(h[h.length]=f);else for(g in a)f=c(a[g],g,d),f!=null&&(h[h.length]=f);return h.concat.apply([],h)},guid:1,proxy:function(a,c){if(typeof c=="string"){var d=a[c];c=a,a=d}if(!e.isFunction(a))return b;var f=D.call(arguments,2),g=function(){return a.apply(c,f.concat(D.call(arguments)))};g.guid=a.guid=a.guid||g.guid||e.guid++;return g},access:function(a,c,d,f,g,h){var i=a.length;if(typeof c=="object"){for(var j in c)e.access(a,j,c[j],f,g,d);return a}if(d!==b){f=!h&&f&&e.isFunction(d);for(var k=0;k<i;k++)g(a[k],c,f?d.call(a[k],k,g(a[k],c)):d,h);return a}return i?g(a[0],c):b},now:function(){return(new Date).getTime()},uaMatch:function(a){a=a.toLowerCase();var b=s.exec(a)||t.exec(a)||u.exec(a)||a.indexOf("compatible")<0&&v.exec(a)||[];return{browser:b[1]||"",version:b[2]||"0"}},sub:function(){function a(b,c){return new a.fn.init(b,c)}e.extend(!0,a,this),a.superclass=this,a.fn=a.prototype=this(),a.fn.constructor=a,a.sub=this.sub,a.fn.init=function(d,f){f&&f instanceof e&&!(f instanceof a)&&(f=a(f));return e.fn.init.call(this,d,f,b)},a.fn.init.prototype=a.fn;var b=a(c);return a},browser:{}}),e.each("Boolean Number String Function Array Date RegExp Object".split(" "),function(a,b){G["[object "+b+"]"]=b.toLowerCase()}),x=e.uaMatch(w),x.browser&&(e.browser[x.browser]=!0,e.browser.version=x.version),e.browser.webkit&&(e.browser.safari=!0),j.test(" ")&&(k=/^[\s\xA0]+/,l=/[\s\xA0]+$/),h=e(c),c.addEventListener?z=function(){c.removeEventListener("DOMContentLoaded",z,!1),e.ready()}:c.attachEvent&&(z=function(){c.readyState==="complete"&&(c.detachEvent("onreadystatechange",z),e.ready())});return e}(),g="done fail isResolved isRejected promise then always pipe".split(" "),h=[].slice;f.extend({_Deferred:function(){var a=[],b,c,d,e={done:function(){if(!d){var c=arguments,g,h,i,j,k;b&&(k=b,b=0);for(g=0,h=c.length;g<h;g++)i=c[g],j=f.type(i),j==="array"?e.done.apply(e,i):j==="function"&&a.push(i);k&&e.resolveWith(k[0],k[1])}return this},resolveWith:function(e,f){if(!d&&!b&&!c){f=f||[],c=1;try{while(a[0])a.shift().apply(e,f)}finally{b=[e,f],c=0}}return this},resolve:function(){e.resolveWith(this,arguments);return this},isResolved:function(){return!!c||!!b},cancel:function(){d=1,a=[];return this}};return e},Deferred:function(a){var b=f._Deferred(),c=f._Deferred(),d;f.extend(b,{then:function(a,c){b.done(a).fail(c);return this},always:function(){return b.done.apply(b,arguments).fail.apply(this,arguments)},fail:c.done,rejectWith:c.resolveWith,reject:c.resolve,isRejected:c.isResolved,pipe:function(a,c){return f.Deferred(function(d){f.each({done:[a,"resolve"],fail:[c,"reject"]},function(a,c){var e=c[0],g=c[1],h;f.isFunction(e)?b[a](function(){h=e.apply(this,arguments),h&&f.isFunction(h.promise)?h.promise().then(d.resolve,d.reject):d[g](h)}):b[a](d[g])})}).promise()},promise:function(a){if(a==null){if(d)return d;d=a={}}var c=g.length;while(c--)a[g[c]]=b[g[c]];return a}}),b.done(c.cancel).fail(b.cancel),delete b.cancel,a&&a.call(b,b);return b},when:function(a){function i(a){return function(c){b[a]=arguments.length>1?h.call(arguments,0):c,--e||g.resolveWith(g,h.call(b,0))}}var b=arguments,c=0,d=b.length,e=d,g=d<=1&&a&&f.isFunction(a.promise)?a:f.Deferred();if(d>1){for(;c<d;c++)b[c]&&f.isFunction(b[c].promise)?b[c].promise().then(i(c),g.reject):--e;e||g.resolveWith(g,b)}else g!==a&&g.resolveWith(g,d?[a]:[]);return g.promise()}}),f.support=function(){var a=c.createElement("div"),b=c.documentElement,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r;a.setAttribute("className","t"),a.innerHTML="   <link/><table></table><a href='/a' style='top:1px;float:left;opacity:.55;'>a</a><input type='checkbox'/>",d=a.getElementsByTagName("*"),e=a.getElementsByTagName("a")[0];if(!d||!d.length||!e)return{};f=c.createElement("select"),g=f.appendChild(c.createElement("option")),h=a.getElementsByTagName("input")[0],j={leadingWhitespace:a.firstChild.nodeType===3,tbody:!a.getElementsByTagName("tbody").length,htmlSerialize:!!a.getElementsByTagName("link").length,style:/top/.test(e.getAttribute("style")),hrefNormalized:e.getAttribute("href")==="/a",opacity:/^0.55$/.test(e.style.opacity),cssFloat:!!e.style.cssFloat,checkOn:h.value==="on",optSelected:g.selected,getSetAttribute:a.className!=="t",submitBubbles:!0,changeBubbles:!0,focusinBubbles:!1,deleteExpando:!0,noCloneEvent:!0,inlineBlockNeedsLayout:!1,shrinkWrapBlocks:!1,reliableMarginRight:!0},h.checked=!0,j.noCloneChecked=h.cloneNode(!0).checked,f.disabled=!0,j.optDisabled=!g.disabled;try{delete a.test}catch(s){j.deleteExpando=!1}!a.addEventListener&&a.attachEvent&&a.fireEvent&&(a.attachEvent("onclick",function b(){j.noCloneEvent=!1,a.detachEvent("onclick",b)}),a.cloneNode(!0).fireEvent("onclick")),h=c.createElement("input"),h.value="t",h.setAttribute("type","radio"),j.radioValue=h.value==="t",h.setAttribute("checked","checked"),a.appendChild(h),k=c.createDocumentFragment(),k.appendChild(a.firstChild),j.checkClone=k.cloneNode(!0).cloneNode(!0).lastChild.checked,a.innerHTML="",a.style.width=a.style.paddingLeft="1px",l=c.createElement("body"),m={visibility:"hidden",width:0,height:0,border:0,margin:0,background:"none"};for(q in m)l.style[q]=m[q];l.appendChild(a),b.insertBefore(l,b.firstChild),j.appendChecked=h.checked,j.boxModel=a.offsetWidth===2,"zoom"in a.style&&(a.style.display="inline",a.style.zoom=1,j.inlineBlockNeedsLayout=a.offsetWidth===2,a.style.display="",a.innerHTML="<div style='width:4px;'></div>",j.shrinkWrapBlocks=a.offsetWidth!==2),a.innerHTML="<table><tr><td style='padding:0;border:0;display:none'></td><td>t</td></tr></table>",n=a.getElementsByTagName("td"),r=n[0].offsetHeight===0,n[0].style.display="",n[1].style.display="none",j.reliableHiddenOffsets=r&&n[0].offsetHeight===0,a.innerHTML="",c.defaultView&&c.defaultView.getComputedStyle&&(i=c.createElement("div"),i.style.width="0",i.style.marginRight="0",a.appendChild(i),j.reliableMarginRight=(parseInt((c.defaultView.getComputedStyle(i,null)||{marginRight:0}).marginRight,10)||0)===0),l.innerHTML="",b.removeChild(l);if(a.attachEvent)for(q in{submit:1,change:1,focusin:1})p="on"+q,r=p in a,r||(a.setAttribute(p,"return;"),r=typeof a[p]=="function"),j[q+"Bubbles"]=r;return j}(),f.boxModel=f.support.boxModel;var i=/^(?:\{.*\}|\[.*\])$/,j=/([a-z])([A-Z])/g;f.extend({cache:{},uuid:0,expando:"jQuery"+(f.fn.jquery+Math.random()).replace(/\D/g,""),noData:{embed:!0,object:"clsid:D27CDB6E-AE6D-11cf-96B8-444553540000",applet:!0},hasData:function(a){a=a.nodeType?f.cache[a[f.expando]]:a[f.expando];return!!a&&!l(a)},data:function(a,c,d,e){if(!!f.acceptData(a)){var g=f.expando,h=typeof c=="string",i,j=a.nodeType,k=j?f.cache:a,l=j?a[f.expando]:a[f.expando]&&f.expando;if((!l||e&&l&&!k[l][g])&&h&&d===b)return;l||(j?a[f.expando]=l=++f.uuid:l=f.expando),k[l]||(k[l]={},j||(k[l].toJSON=f.noop));if(typeof c=="object"||typeof c=="function")e?k[l][g]=f.extend(k[l][g],c):k[l]=f.extend(k[l],c);i=k[l],e&&(i[g]||(i[g]={}),i=i[g]),d!==b&&(i[f.camelCase(c)]=d);if(c==="events"&&!i[c])return i[g]&&i[g].events;return h?i[f.camelCase(c)]:i}},removeData:function(b,c,d){if(!!f.acceptData(b)){var e=f.expando,g=b.nodeType,h=g?f.cache:b,i=g?b[f.expando]:f.expando;if(!h[i])return;if(c){var j=d?h[i][e]:h[i];if(j){delete j[c];if(!l(j))return}}if(d){delete h[i][e];if(!l(h[i]))return}var k=h[i][e];f.support.deleteExpando||h!=a?delete h[i]:h[i]=null,k?(h[i]={},g||(h[i].toJSON=f.noop),h[i][e]=k):g&&(f.support.deleteExpando?delete b[f.expando]:b.removeAttribute?b.removeAttribute(f.expando):b[f.expando]=null)}},_data:function(a,b,c){return f.data(a,b,c,!0)},acceptData:function(a){if(a.nodeName){var b=f.noData[a.nodeName.toLowerCase()];if(b)return b!==!0&&a.getAttribute("classid")===b}return!0}}),f.fn.extend({data:function(a,c){var d=null;if(typeof a=="undefined"){if(this.length){d=f.data(this[0]);if(this[0].nodeType===1){var e=this[0].attributes,g;for(var h=0,i=e.length;h<i;h++)g=e[h].name,g.indexOf("data-")===0&&(g=f.camelCase(g.substring(5)),k(this[0],g,d[g]))}}return d}if(typeof a=="object")return this.each(function(){f.data(this,a)});var j=a.split(".");j[1]=j[1]?"."+j[1]:"";if(c===b){d=this.triggerHandler("getData"+j[1]+"!",[j[0]]),d===b&&this.length&&(d=f.data(this[0],a),d=k(this[0],a,d));return d===b&&j[1]?this.data(j[0]):d}return this.each(function(){var b=f(this),d=[j[0],c];b.triggerHandler("setData"+j[1]+"!",d),f.data(this,a,c),b.triggerHandler("changeData"+j[1]+"!",d)})},removeData:function(a){return this.each(function(){f.removeData(this,a)})}}),f.extend({_mark:function(a,c){a&&(c=(c||"fx")+"mark",f.data(a,c,(f.data(a,c,b,!0)||0)+1,!0))},_unmark:function(a,c,d){a!==!0&&(d=c,c=a,a=!1);if(c){d=d||"fx";var e=d+"mark",g=a?0:(f.data(c,e,b,!0)||1)-1;g?f.data(c,e,g,!0):(f.removeData(c,e,!0),m(c,d,"mark"))}},queue:function(a,c,d){if(a){c=(c||"fx")+"queue";var e=f.data(a,c,b,!0);d&&(!e||f.isArray(d)?e=f.data(a,c,f.makeArray(d),!0):e.push(d));return e||[]}},dequeue:function(a,b){b=b||"fx";var c=f.queue(a,b),d=c.shift(),e;d==="inprogress"&&(d=c.shift()),d&&(b==="fx"&&c.unshift("inprogress"),d.call(a,function(){f.dequeue(a,b)})),c.length||(f.removeData(a,b+"queue",!0),m(a,b,"queue"))}}),f.fn.extend({queue:function(a,c){typeof a!="string"&&(c=a,a="fx");if(c===b)return f.queue(this[0],a);return this.each(function(){var b=f.queue(this,a,c);a==="fx"&&b[0]!=="inprogress"&&f.dequeue(this,a)})},dequeue:function(a){return this.each(function(){f.dequeue(this,a)})},delay:function(a,b){a=f.fx?f.fx.speeds[a]||a:a,b=b||"fx";return this.queue(b,function(){var c=this;setTimeout(function(){f.dequeue(c,b)},a)})},clearQueue:function(a){return this.queue(a||"fx",[])},promise:function(a,c){function m(){--h||d.resolveWith(e,[e])}typeof a!="string"&&(c=a,a=b),a=a||"fx";var d=f.Deferred(),e=this,g=e.length,h=1,i=a+"defer",j=a+"queue",k=a+"mark",l;while(g--)if(l=f.data(e[g],i,b,!0)||(f.data(e[g],j,b,!0)||f.data(e[g],k,b,!0))&&f.data(e[g],i,f._Deferred(),!0))h++,l.done(m);m();return d.promise()}});var n=/[\n\t\r]/g,o=/\s+/,p=/\r/g,q=/^(?:button|input)$/i,r=/^(?:button|input|object|select|textarea)$/i,s=/^a(?:rea)?$/i,t=/^(?:autofocus|autoplay|async|checked|controls|defer|disabled|hidden|loop|multiple|open|readonly|required|scoped|selected)$/i,u=/\:/,v,w;f.fn.extend({attr:function(a,b){return f.access(this,a,b,!0,f.attr)},removeAttr:function(a){return this.each(function(){f.removeAttr(this,a)})},prop:function(a,b){return f.access(this,a,b,!0,f.prop)},removeProp:function(a){a=f.propFix[a]||a;return this.each(function(){try{this[a]=b,delete this[a]}catch(c){}})},addClass:function(a){if(f.isFunction(a))return this.each(function(b){var c=f(this);c.addClass(a.call(this,b,c.attr("class")||""))});if(a&&typeof a=="string"){var b=(a||"").split(o);for(var c=0,d=this.length;c<d;c++){var e=this[c];if(e.nodeType===1)if(!e.className)e.className=a;else{var g=" "+e.className+" ",h=e.className;for(var i=0,j=b.length;i<j;i++)g.indexOf(" "+b[i]+" ")<0&&(h+=" "+b[i]);e.className=f.trim(h)}}}return this},removeClass:function(a){if(f.isFunction(a))return this.each(function(b){var c=f(this);c.removeClass(a.call(this,b,c.attr("class")))});if(a&&typeof a=="string"||a===b){var c=(a||"").split(o);for(var d=0,e=this.length;d<e;d++){var g=this[d];if(g.nodeType===1&&g.className)if(a){var h=(" "+g.className+" ").replace(n," ");for(var i=0,j=c.length;i<j;i++)h=h.replace(" "+c[i]+" "," ");g.className=f.trim(h)}else g.className=""}}return this},toggleClass:function(a,b){var c=typeof a,d=typeof b=="boolean";if(f.isFunction(a))return this.each(function(c){var d=f(this);d.toggleClass(a.call(this,c,d.attr("class"),b),b)});return this.each(function(){if(c==="string"){var e,g=0,h=f(this),i=b,j=a.split(o);while(e=j[g++])i=d?i:!h.hasClass(e),h[i?"addClass":"removeClass"](e)}else if(c==="undefined"||c==="boolean")this.className&&f._data(this,"__className__",this.className),this.className=this.className||a===!1?"":f._data(this,"__className__")||""})},hasClass:function(a){var b=" "+a+" ";for(var c=0,d=this.length;c<d;c++)if((" "+this[c].className+" ").replace(n," ").indexOf(b)>-1)return!0;return!1},val:function(a){var c,d,e=this[0];if(!arguments.length){if(e){c=f.valHooks[e.nodeName.toLowerCase()]||f.valHooks[e.type];if(c&&"get"in c&&(d=c.get(e,"value"))!==b)return d;return(e.value||"").replace(p,"")}return b}var g=f.isFunction(a);return this.each(function(d){var e=f(this),h;if(this.nodeType===1){g?h=a.call(this,d,e.val()):h=a,h==null?h="":typeof h=="number"?h+="":f.isArray(h)&&(h=f.map(h,function(a){return a==null?"":a+""})),c=f.valHooks[this.nodeName.toLowerCase()]||f.valHooks[this.type];if(!c||!("set"in c)||c.set(this,h,"value")===b)this.value=h}})}}),f.extend({valHooks:{option:{get:function(a){var b=a.attributes.value;return!b||b.specified?a.value:a.text}},select:{get:function(a){var b,c=a.selectedIndex,d=[],e=a.options,g=a.type==="select-one";if(c<0)return null;for(var h=g?c:0,i=g?c+1:e.length;h<i;h++){var j=e[h];if(j.selected&&(f.support.optDisabled?!j.disabled:j.getAttribute("disabled")===null)&&(!j.parentNode.disabled||!f.nodeName(j.parentNode,"optgroup"))){b=f(j).val();if(g)return b;d.push(b)}}if(g&&!d.length&&e.length)return f(e[c]).val();return d},set:function(a,b){var c=f.makeArray(b);f(a).find("option").each(function(){this.selected=f.inArray(f(this).val(),c)>=0}),c.length||(a.selectedIndex=-1);return c}}},attrFn:{val:!0,css:!0,html:!0,text:!0,data:!0,width:!0,height:!0,offset:!0},attrFix:{tabindex:"tabIndex"},attr:function(a,c,d,e){var g=a.nodeType;if(!a||g===3||g===8||g===2)return b;if(e&&c in f.attrFn)return f(a)[c](d);if(!("getAttribute"in a))return f.prop(a,c,d);var h,i,j=g!==1||!f.isXMLDoc(a);c=j&&f.attrFix[c]||c,i=f.attrHooks[c],i||(!t.test(c)||typeof d!="boolean"&&d!==b&&d.toLowerCase()!==c.toLowerCase()?v&&(f.nodeName(a,"form")||u.test(c))&&(i=v):i=w);if(d!==b){if(d===null){f.removeAttr(a,c);return b}if(i&&"set"in i&&j&&(h=i.set(a,d,c))!==b)return h;a.setAttribute(c,""+d);return d}if(i&&"get"in i&&j)return i.get(a,c);h=a.getAttribute(c);return h===null?b:h},removeAttr:function(a,b){var c;a.nodeType===1&&(b=f.attrFix[b]||b,f.support.getSetAttribute?a.removeAttribute(b):(f.attr(a,b,""),a.removeAttributeNode(a.getAttributeNode(b))),t.test(b)&&(c=f.propFix[b]||b)in a&&(a[c]=!1))},attrHooks:{type:{set:function(a,b){if(q.test(a.nodeName)&&a.parentNode)f.error("type property can't be changed");else if(!f.support.radioValue&&b==="radio"&&f.nodeName(a,"input")){var c=a.value;a.setAttribute("type",b),c&&(a.value=c);return b}}},tabIndex:{get:function(a){var c=a.getAttributeNode("tabIndex");return c&&c.specified?parseInt(c.value,10):r.test(a.nodeName)||s.test(a.nodeName)&&a.href?0:b}}},propFix:{tabindex:"tabIndex",readonly:"readOnly","for":"htmlFor","class":"className",maxlength:"maxLength",cellspacing:"cellSpacing",cellpadding:"cellPadding",rowspan:"rowSpan",colspan:"colSpan",usemap:"useMap",frameborder:"frameBorder",contenteditable:"contentEditable"},prop:function(a,c,d){var e=a.nodeType;if(!a||e===3||e===8||e===2)return b;var g,h,i=e!==1||!f.isXMLDoc(a);c=i&&f.propFix[c]||c,h=f.propHooks[c];return d!==b?h&&"set"in h&&(g=h.set(a,d,c))!==b?g:a[c]=d:h&&"get"in h&&(g=h.get(a,c))!==b?g:a[c]},propHooks:{}}),w={get:function(a,c){return a[f.propFix[c]||c]?c.toLowerCase():b},set:function(a,b,c){var d;b===!1?f.removeAttr(a,c):(d=f.propFix[c]||c,d in a&&(a[d]=b),a.setAttribute(c,c.toLowerCase()));return c}},f.attrHooks.value={get:function(a,b){if(v&&f.nodeName(a,"button"))return v.get(a,b);return a.value},set:function(a,b,c){if(v&&f.nodeName(a,"button"))return v.set(a,b,c);a.value=b}},f.support.getSetAttribute||(f.attrFix=f.propFix,v=f.attrHooks.name=f.valHooks.button={get:function(a,c){var d;d=a.getAttributeNode(c);return d&&d.nodeValue!==""?d.nodeValue:b},set:function(a,b,c){var d=a.getAttributeNode(c);if(d){d.nodeValue=b;return b}}},f.each(["width","height"],function(a,b){f.attrHooks[b]=f.extend(f.attrHooks[b],{set:function(a,c){if(c===""){a.setAttribute(b,"auto");return c}}})})),f.support.hrefNormalized||f.each(["href","src","width","height"],function(a,c){f.attrHooks[c]=f.extend(f.attrHooks[c],{get:function(a){var d=a.getAttribute(c,2);return d===null?b:d}})}),f.support.style||(f.attrHooks.style={get:function(a){return a.style.cssText.toLowerCase()||b},set:function(a,b){return a.style.cssText=""+b}}),f.support.optSelected||(f.propHooks.selected=f.extend(f.propHooks.selected,{get:function(a){var b=a.parentNode;b&&(b.selectedIndex,b.parentNode&&b.parentNode.selectedIndex)}})),f.support.checkOn||f.each(["radio","checkbox"],function(){f.valHooks[this]={get:function(a){return a.getAttribute("value")===null?"on":a.value}}}),f.each(["radio","checkbox"],function(){f.valHooks[this]=f.extend(f.valHooks[this],{set:function(a,b){if(f.isArray(b))return a.checked=f.inArray(f(a).val(),b)>=0}})});var x=Object.prototype.hasOwnProperty,y=/\.(.*)$/,z=/^(?:textarea|input|select)$/i,A=/\./g,B=/ /g,C=/[^\w\s.|`]/g,D=function(a){return a.replace(C,"\\$&")};f.event={add:function(a,c,d,e){if(a.nodeType!==3&&a.nodeType!==8){if(d===!1)d=E;else if(!d)return;var g,h;d.handler&&(g=d,d=g.handler),d.guid||(d.guid=f.guid++);var i=f._data(a);if(!i)return;var j=i.events,k=i.handle;j||(i.events=j={}),k||(i.handle=k=function(a){return typeof f!="undefined"&&(!a||f.event.triggered!==a.type)?f.event.handle.apply(k.elem,arguments):b}),k.elem=a,c=c.split(" ");var l,m=0,n;while(l=c[m++]){h=g?f.extend({},g):{handler:d,data:e},l.indexOf(".")>-1?(n=l.split("."),l=n.shift(),h.namespace=n.slice(0).sort().join(".")):(n=[],h.namespace=""),h.type=l,h.guid||(h.guid=d.guid);var o=j[l],p=f.event.special[l]||{};if(!o){o=j[l]=[];if(!p.setup||p.setup.call(a,e,n,k)===!1)a.addEventListener?a.addEventListener(l,k,!1):a.attachEvent&&a.attachEvent("on"+l,k)}p.add&&(p.add.call(a,h),h.handler.guid||(h.handler.guid=d.guid)),o.push(h),f.event.global[l]=!0}a=null}},global:{},remove:function(a,c,d,e){if(a.nodeType!==3&&a.nodeType!==8){d===!1&&(d=E);var g,h,i,j,k=0,l,m,n,o,p,q,r,s=f.hasData(a)&&f._data(a),t=s&&s.events;if(!s||!t)return;c&&c.type&&(d=c.handler,c=c.type);if(!c||typeof c=="string"&&c.charAt(0)==="."){c=c||"";for(h in t)f.event.remove(a,h+c);return}c=c.split(" ");while(h=c[k++]){r=h,q=null,l=h.indexOf(".")<0,m=[],l||(m=h.split("."),h=m.shift(),n=new RegExp("(^|\\.)"+f.map(m.slice(0).sort(),D).join("\\.(?:.*\\.)?")+"(\\.|$)")),p=t[h];if(!p)continue;if(!d){for(j=0;j<p.length;j++){q=p[j];if(l||n.test(q.namespace))f.event.remove(a,r,q.handler,j),p.splice(j--,1)}continue}o=f.event.special[h]||{};for(j=e||0;j<p.length;j++){q=p[j];if(d.guid===q.guid){if(l||n.test(q.namespace))e==null&&p.splice(j--,1),o.remove&&o.remove.call(a,q);if(e!=null)break}}if(p.length===0||e!=null&&p.length===1)(!o.teardown||o.teardown.call(a,m)===!1)&&f.removeEvent(a,h,s.handle),g=null,delete t[h]}if(f.isEmptyObject(t)){var u=s.handle;u&&(u.elem=null),delete s.events,delete s.handle,f.isEmptyObject(s)&&f.removeData(a,b,!0)}}},customEvent:{getData:!0,setData:!0,changeData:!0},trigger:function(c,d,e,g){var h=c.type||c,i=[],j;h.indexOf("!")>=0&&(h=h.slice(0,-1),j=!0),h.indexOf(".")>=0&&(i=h.split("."),h=i.shift(),i.sort());if(!!e&&!f.event.customEvent[h]||!!f.event.global[h]){c=typeof c=="object"?c[f.expando]?c:new f.Event(h,c):new f.Event(h),c.type=h,c.exclusive=j,c.namespace=i.join("."),c.namespace_re=new RegExp("(^|\\.)"+i.join("\\.(?:.*\\.)?")+"(\\.|$)");if(g||!e)c.preventDefault(),c.stopPropagation();if(!e){f.each(f.cache,function(){var a=f.expando,b=this[a];b&&b.events&&b.events[h]&&f.event.trigger(c,d,b.handle.elem
)});return}if(e.nodeType===3||e.nodeType===8)return;c.result=b,c.target=e,d=d?f.makeArray(d):[],d.unshift(c);var k=e,l=h.indexOf(":")<0?"on"+h:"";do{var m=f._data(k,"handle");c.currentTarget=k,m&&m.apply(k,d),l&&f.acceptData(k)&&k[l]&&k[l].apply(k,d)===!1&&(c.result=!1,c.preventDefault()),k=k.parentNode||k.ownerDocument||k===c.target.ownerDocument&&a}while(k&&!c.isPropagationStopped());if(!c.isDefaultPrevented()){var n,o=f.event.special[h]||{};if((!o._default||o._default.call(e.ownerDocument,c)===!1)&&(h!=="click"||!f.nodeName(e,"a"))&&f.acceptData(e)){try{l&&e[h]&&(n=e[l],n&&(e[l]=null),f.event.triggered=h,e[h]())}catch(p){}n&&(e[l]=n),f.event.triggered=b}}return c.result}},handle:function(c){c=f.event.fix(c||a.event);var d=((f._data(this,"events")||{})[c.type]||[]).slice(0),e=!c.exclusive&&!c.namespace,g=Array.prototype.slice.call(arguments,0);g[0]=c,c.currentTarget=this;for(var h=0,i=d.length;h<i;h++){var j=d[h];if(e||c.namespace_re.test(j.namespace)){c.handler=j.handler,c.data=j.data,c.handleObj=j;var k=j.handler.apply(this,g);k!==b&&(c.result=k,k===!1&&(c.preventDefault(),c.stopPropagation()));if(c.isImmediatePropagationStopped())break}}return c.result},props:"altKey attrChange attrName bubbles button cancelable charCode clientX clientY ctrlKey currentTarget data detail eventPhase fromElement handler keyCode layerX layerY metaKey newValue offsetX offsetY pageX pageY prevValue relatedNode relatedTarget screenX screenY shiftKey srcElement target toElement view wheelDelta which".split(" "),fix:function(a){if(a[f.expando])return a;var d=a;a=f.Event(d);for(var e=this.props.length,g;e;)g=this.props[--e],a[g]=d[g];a.target||(a.target=a.srcElement||c),a.target.nodeType===3&&(a.target=a.target.parentNode),!a.relatedTarget&&a.fromElement&&(a.relatedTarget=a.fromElement===a.target?a.toElement:a.fromElement);if(a.pageX==null&&a.clientX!=null){var h=a.target.ownerDocument||c,i=h.documentElement,j=h.body;a.pageX=a.clientX+(i&&i.scrollLeft||j&&j.scrollLeft||0)-(i&&i.clientLeft||j&&j.clientLeft||0),a.pageY=a.clientY+(i&&i.scrollTop||j&&j.scrollTop||0)-(i&&i.clientTop||j&&j.clientTop||0)}a.which==null&&(a.charCode!=null||a.keyCode!=null)&&(a.which=a.charCode!=null?a.charCode:a.keyCode),!a.metaKey&&a.ctrlKey&&(a.metaKey=a.ctrlKey),!a.which&&a.button!==b&&(a.which=a.button&1?1:a.button&2?3:a.button&4?2:0);return a},guid:1e8,proxy:f.proxy,special:{ready:{setup:f.bindReady,teardown:f.noop},live:{add:function(a){f.event.add(this,O(a.origType,a.selector),f.extend({},a,{handler:N,guid:a.handler.guid}))},remove:function(a){f.event.remove(this,O(a.origType,a.selector),a)}},beforeunload:{setup:function(a,b,c){f.isWindow(this)&&(this.onbeforeunload=c)},teardown:function(a,b){this.onbeforeunload===b&&(this.onbeforeunload=null)}}}},f.removeEvent=c.removeEventListener?function(a,b,c){a.removeEventListener&&a.removeEventListener(b,c,!1)}:function(a,b,c){a.detachEvent&&a.detachEvent("on"+b,c)},f.Event=function(a,b){if(!this.preventDefault)return new f.Event(a,b);a&&a.type?(this.originalEvent=a,this.type=a.type,this.isDefaultPrevented=a.defaultPrevented||a.returnValue===!1||a.getPreventDefault&&a.getPreventDefault()?F:E):this.type=a,b&&f.extend(this,b),this.timeStamp=f.now(),this[f.expando]=!0},f.Event.prototype={preventDefault:function(){this.isDefaultPrevented=F;var a=this.originalEvent;!a||(a.preventDefault?a.preventDefault():a.returnValue=!1)},stopPropagation:function(){this.isPropagationStopped=F;var a=this.originalEvent;!a||(a.stopPropagation&&a.stopPropagation(),a.cancelBubble=!0)},stopImmediatePropagation:function(){this.isImmediatePropagationStopped=F,this.stopPropagation()},isDefaultPrevented:E,isPropagationStopped:E,isImmediatePropagationStopped:E};var G=function(a){var b=a.relatedTarget;a.type=a.data;try{if(b&&b!==c&&!b.parentNode)return;while(b&&b!==this)b=b.parentNode;b!==this&&f.event.handle.apply(this,arguments)}catch(d){}},H=function(a){a.type=a.data,f.event.handle.apply(this,arguments)};f.each({mouseenter:"mouseover",mouseleave:"mouseout"},function(a,b){f.event.special[a]={setup:function(c){f.event.add(this,b,c&&c.selector?H:G,a)},teardown:function(a){f.event.remove(this,b,a&&a.selector?H:G)}}}),f.support.submitBubbles||(f.event.special.submit={setup:function(a,b){if(!f.nodeName(this,"form"))f.event.add(this,"click.specialSubmit",function(a){var b=a.target,c=b.type;(c==="submit"||c==="image")&&f(b).closest("form").length&&L("submit",this,arguments)}),f.event.add(this,"keypress.specialSubmit",function(a){var b=a.target,c=b.type;(c==="text"||c==="password")&&f(b).closest("form").length&&a.keyCode===13&&L("submit",this,arguments)});else return!1},teardown:function(a){f.event.remove(this,".specialSubmit")}});if(!f.support.changeBubbles){var I,J=function(a){var b=a.type,c=a.value;b==="radio"||b==="checkbox"?c=a.checked:b==="select-multiple"?c=a.selectedIndex>-1?f.map(a.options,function(a){return a.selected}).join("-"):"":f.nodeName(a,"select")&&(c=a.selectedIndex);return c},K=function(c){var d=c.target,e,g;if(!!z.test(d.nodeName)&&!d.readOnly){e=f._data(d,"_change_data"),g=J(d),(c.type!=="focusout"||d.type!=="radio")&&f._data(d,"_change_data",g);if(e===b||g===e)return;if(e!=null||g)c.type="change",c.liveFired=b,f.event.trigger(c,arguments[1],d)}};f.event.special.change={filters:{focusout:K,beforedeactivate:K,click:function(a){var b=a.target,c=f.nodeName(b,"input")?b.type:"";(c==="radio"||c==="checkbox"||f.nodeName(b,"select"))&&K.call(this,a)},keydown:function(a){var b=a.target,c=f.nodeName(b,"input")?b.type:"";(a.keyCode===13&&!f.nodeName(b,"textarea")||a.keyCode===32&&(c==="checkbox"||c==="radio")||c==="select-multiple")&&K.call(this,a)},beforeactivate:function(a){var b=a.target;f._data(b,"_change_data",J(b))}},setup:function(a,b){if(this.type==="file")return!1;for(var c in I)f.event.add(this,c+".specialChange",I[c]);return z.test(this.nodeName)},teardown:function(a){f.event.remove(this,".specialChange");return z.test(this.nodeName)}},I=f.event.special.change.filters,I.focus=I.beforeactivate}f.support.focusinBubbles||f.each({focus:"focusin",blur:"focusout"},function(a,b){function e(a){var c=f.event.fix(a);c.type=b,c.originalEvent={},f.event.trigger(c,null,c.target),c.isDefaultPrevented()&&a.preventDefault()}var d=0;f.event.special[b]={setup:function(){d++===0&&c.addEventListener(a,e,!0)},teardown:function(){--d===0&&c.removeEventListener(a,e,!0)}}}),f.each(["bind","one"],function(a,c){f.fn[c]=function(a,d,e){var g;if(typeof a=="object"){for(var h in a)this[c](h,d,a[h],e);return this}if(arguments.length===2||d===!1)e=d,d=b;c==="one"?(g=function(a){f(this).unbind(a,g);return e.apply(this,arguments)},g.guid=e.guid||f.guid++):g=e;if(a==="unload"&&c!=="one")this.one(a,d,e);else for(var i=0,j=this.length;i<j;i++)f.event.add(this[i],a,g,d);return this}}),f.fn.extend({unbind:function(a,b){if(typeof a=="object"&&!a.preventDefault)for(var c in a)this.unbind(c,a[c]);else for(var d=0,e=this.length;d<e;d++)f.event.remove(this[d],a,b);return this},delegate:function(a,b,c,d){return this.live(b,c,d,a)},undelegate:function(a,b,c){return arguments.length===0?this.unbind("live"):this.die(b,null,c,a)},trigger:function(a,b){return this.each(function(){f.event.trigger(a,b,this)})},triggerHandler:function(a,b){if(this[0])return f.event.trigger(a,b,this[0],!0)},toggle:function(a){var b=arguments,c=a.guid||f.guid++,d=0,e=function(c){var e=(f.data(this,"lastToggle"+a.guid)||0)%d;f.data(this,"lastToggle"+a.guid,e+1),c.preventDefault();return b[e].apply(this,arguments)||!1};e.guid=c;while(d<b.length)b[d++].guid=c;return this.click(e)},hover:function(a,b){return this.mouseenter(a).mouseleave(b||a)}});var M={focus:"focusin",blur:"focusout",mouseenter:"mouseover",mouseleave:"mouseout"};f.each(["live","die"],function(a,c){f.fn[c]=function(a,d,e,g){var h,i=0,j,k,l,m=g||this.selector,n=g?this:f(this.context);if(typeof a=="object"&&!a.preventDefault){for(var o in a)n[c](o,d,a[o],m);return this}if(c==="die"&&!a&&g&&g.charAt(0)==="."){n.unbind(g);return this}if(d===!1||f.isFunction(d))e=d||E,d=b;a=(a||"").split(" ");while((h=a[i++])!=null){j=y.exec(h),k="",j&&(k=j[0],h=h.replace(y,""));if(h==="hover"){a.push("mouseenter"+k,"mouseleave"+k);continue}l=h,M[h]?(a.push(M[h]+k),h=h+k):h=(M[h]||h)+k;if(c==="live")for(var p=0,q=n.length;p<q;p++)f.event.add(n[p],"live."+O(h,m),{data:d,selector:m,handler:e,origType:h,origHandler:e,preType:l});else n.unbind("live."+O(h,m),e)}return this}}),f.each("blur focus focusin focusout load resize scroll unload click dblclick mousedown mouseup mousemove mouseover mouseout mouseenter mouseleave change select submit keydown keypress keyup error".split(" "),function(a,b){f.fn[b]=function(a,c){c==null&&(c=a,a=null);return arguments.length>0?this.bind(b,a,c):this.trigger(b)},f.attrFn&&(f.attrFn[b]=!0)}),function(){function u(a,b,c,d,e,f){for(var g=0,h=d.length;g<h;g++){var i=d[g];if(i){var j=!1;i=i[a];while(i){if(i.sizcache===c){j=d[i.sizset];break}if(i.nodeType===1){f||(i.sizcache=c,i.sizset=g);if(typeof b!="string"){if(i===b){j=!0;break}}else if(k.filter(b,[i]).length>0){j=i;break}}i=i[a]}d[g]=j}}}function t(a,b,c,d,e,f){for(var g=0,h=d.length;g<h;g++){var i=d[g];if(i){var j=!1;i=i[a];while(i){if(i.sizcache===c){j=d[i.sizset];break}i.nodeType===1&&!f&&(i.sizcache=c,i.sizset=g);if(i.nodeName.toLowerCase()===b){j=i;break}i=i[a]}d[g]=j}}}var a=/((?:\((?:\([^()]+\)|[^()]+)+\)|\[(?:\[[^\[\]]*\]|['"][^'"]*['"]|[^\[\]'"]+)+\]|\\.|[^ >+~,(\[\\]+)+|[>+~])(\s*,\s*)?((?:.|\r|\n)*)/g,d=0,e=Object.prototype.toString,g=!1,h=!0,i=/\\/g,j=/\W/;[0,0].sort(function(){h=!1;return 0});var k=function(b,d,f,g){f=f||[],d=d||c;var h=d;if(d.nodeType!==1&&d.nodeType!==9)return[];if(!b||typeof b!="string")return f;var i,j,n,o,q,r,s,t,u=!0,w=k.isXML(d),x=[],y=b;do{a.exec(""),i=a.exec(y);if(i){y=i[3],x.push(i[1]);if(i[2]){o=i[3];break}}}while(i);if(x.length>1&&m.exec(b))if(x.length===2&&l.relative[x[0]])j=v(x[0]+x[1],d);else{j=l.relative[x[0]]?[d]:k(x.shift(),d);while(x.length)b=x.shift(),l.relative[b]&&(b+=x.shift()),j=v(b,j)}else{!g&&x.length>1&&d.nodeType===9&&!w&&l.match.ID.test(x[0])&&!l.match.ID.test(x[x.length-1])&&(q=k.find(x.shift(),d,w),d=q.expr?k.filter(q.expr,q.set)[0]:q.set[0]);if(d){q=g?{expr:x.pop(),set:p(g)}:k.find(x.pop(),x.length===1&&(x[0]==="~"||x[0]==="+")&&d.parentNode?d.parentNode:d,w),j=q.expr?k.filter(q.expr,q.set):q.set,x.length>0?n=p(j):u=!1;while(x.length)r=x.pop(),s=r,l.relative[r]?s=x.pop():r="",s==null&&(s=d),l.relative[r](n,s,w)}else n=x=[]}n||(n=j),n||k.error(r||b);if(e.call(n)==="[object Array]")if(!u)f.push.apply(f,n);else if(d&&d.nodeType===1)for(t=0;n[t]!=null;t++)n[t]&&(n[t]===!0||n[t].nodeType===1&&k.contains(d,n[t]))&&f.push(j[t]);else for(t=0;n[t]!=null;t++)n[t]&&n[t].nodeType===1&&f.push(j[t]);else p(n,f);o&&(k(o,h,f,g),k.uniqueSort(f));return f};k.uniqueSort=function(a){if(r){g=h,a.sort(r);if(g)for(var b=1;b<a.length;b++)a[b]===a[b-1]&&a.splice(b--,1)}return a},k.matches=function(a,b){return k(a,null,null,b)},k.matchesSelector=function(a,b){return k(b,null,null,[a]).length>0},k.find=function(a,b,c){var d;if(!a)return[];for(var e=0,f=l.order.length;e<f;e++){var g,h=l.order[e];if(g=l.leftMatch[h].exec(a)){var j=g[1];g.splice(1,1);if(j.substr(j.length-1)!=="\\"){g[1]=(g[1]||"").replace(i,""),d=l.find[h](g,b,c);if(d!=null){a=a.replace(l.match[h],"");break}}}}d||(d=typeof b.getElementsByTagName!="undefined"?b.getElementsByTagName("*"):[]);return{set:d,expr:a}},k.filter=function(a,c,d,e){var f,g,h=a,i=[],j=c,m=c&&c[0]&&k.isXML(c[0]);while(a&&c.length){for(var n in l.filter)if((f=l.leftMatch[n].exec(a))!=null&&f[2]){var o,p,q=l.filter[n],r=f[1];g=!1,f.splice(1,1);if(r.substr(r.length-1)==="\\")continue;j===i&&(i=[]);if(l.preFilter[n]){f=l.preFilter[n](f,j,d,i,e,m);if(!f)g=o=!0;else if(f===!0)continue}if(f)for(var s=0;(p=j[s])!=null;s++)if(p){o=q(p,f,s,j);var t=e^!!o;d&&o!=null?t?g=!0:j[s]=!1:t&&(i.push(p),g=!0)}if(o!==b){d||(j=i),a=a.replace(l.match[n],"");if(!g)return[];break}}if(a===h)if(g==null)k.error(a);else break;h=a}return j},k.error=function(a){throw"Syntax error, unrecognized expression: "+a};var l=k.selectors={order:["ID","NAME","TAG"],match:{ID:/#((?:[\w\u00c0-\uFFFF\-]|\\.)+)/,CLASS:/\.((?:[\w\u00c0-\uFFFF\-]|\\.)+)/,NAME:/\[name=['"]*((?:[\w\u00c0-\uFFFF\-]|\\.)+)['"]*\]/,ATTR:/\[\s*((?:[\w\u00c0-\uFFFF\-]|\\.)+)\s*(?:(\S?=)\s*(?:(['"])(.*?)\3|(#?(?:[\w\u00c0-\uFFFF\-]|\\.)*)|)|)\s*\]/,TAG:/^((?:[\w\u00c0-\uFFFF\*\-]|\\.)+)/,CHILD:/:(only|nth|last|first)-child(?:\(\s*(even|odd|(?:[+\-]?\d+|(?:[+\-]?\d*)?n\s*(?:[+\-]\s*\d+)?))\s*\))?/,POS:/:(nth|eq|gt|lt|first|last|even|odd)(?:\((\d*)\))?(?=[^\-]|$)/,PSEUDO:/:((?:[\w\u00c0-\uFFFF\-]|\\.)+)(?:\((['"]?)((?:\([^\)]+\)|[^\(\)]*)+)\2\))?/},leftMatch:{},attrMap:{"class":"className","for":"htmlFor"},attrHandle:{href:function(a){return a.getAttribute("href")},type:function(a){return a.getAttribute("type")}},relative:{"+":function(a,b){var c=typeof b=="string",d=c&&!j.test(b),e=c&&!d;d&&(b=b.toLowerCase());for(var f=0,g=a.length,h;f<g;f++)if(h=a[f]){while((h=h.previousSibling)&&h.nodeType!==1);a[f]=e||h&&h.nodeName.toLowerCase()===b?h||!1:h===b}e&&k.filter(b,a,!0)},">":function(a,b){var c,d=typeof b=="string",e=0,f=a.length;if(d&&!j.test(b)){b=b.toLowerCase();for(;e<f;e++){c=a[e];if(c){var g=c.parentNode;a[e]=g.nodeName.toLowerCase()===b?g:!1}}}else{for(;e<f;e++)c=a[e],c&&(a[e]=d?c.parentNode:c.parentNode===b);d&&k.filter(b,a,!0)}},"":function(a,b,c){var e,f=d++,g=u;typeof b=="string"&&!j.test(b)&&(b=b.toLowerCase(),e=b,g=t),g("parentNode",b,f,a,e,c)},"~":function(a,b,c){var e,f=d++,g=u;typeof b=="string"&&!j.test(b)&&(b=b.toLowerCase(),e=b,g=t),g("previousSibling",b,f,a,e,c)}},find:{ID:function(a,b,c){if(typeof b.getElementById!="undefined"&&!c){var d=b.getElementById(a[1]);return d&&d.parentNode?[d]:[]}},NAME:function(a,b){if(typeof b.getElementsByName!="undefined"){var c=[],d=b.getElementsByName(a[1]);for(var e=0,f=d.length;e<f;e++)d[e].getAttribute("name")===a[1]&&c.push(d[e]);return c.length===0?null:c}},TAG:function(a,b){if(typeof b.getElementsByTagName!="undefined")return b.getElementsByTagName(a[1])}},preFilter:{CLASS:function(a,b,c,d,e,f){a=" "+a[1].replace(i,"")+" ";if(f)return a;for(var g=0,h;(h=b[g])!=null;g++)h&&(e^(h.className&&(" "+h.className+" ").replace(/[\t\n\r]/g," ").indexOf(a)>=0)?c||d.push(h):c&&(b[g]=!1));return!1},ID:function(a){return a[1].replace(i,"")},TAG:function(a,b){return a[1].replace(i,"").toLowerCase()},CHILD:function(a){if(a[1]==="nth"){a[2]||k.error(a[0]),a[2]=a[2].replace(/^\+|\s*/g,"");var b=/(-?)(\d*)(?:n([+\-]?\d*))?/.exec(a[2]==="even"&&"2n"||a[2]==="odd"&&"2n+1"||!/\D/.test(a[2])&&"0n+"+a[2]||a[2]);a[2]=b[1]+(b[2]||1)-0,a[3]=b[3]-0}else a[2]&&k.error(a[0]);a[0]=d++;return a},ATTR:function(a,b,c,d,e,f){var g=a[1]=a[1].replace(i,"");!f&&l.attrMap[g]&&(a[1]=l.attrMap[g]),a[4]=(a[4]||a[5]||"").replace(i,""),a[2]==="~="&&(a[4]=" "+a[4]+" ");return a},PSEUDO:function(b,c,d,e,f){if(b[1]==="not")if((a.exec(b[3])||"").length>1||/^\w/.test(b[3]))b[3]=k(b[3],null,null,c);else{var g=k.filter(b[3],c,d,!0^f);d||e.push.apply(e,g);return!1}else if(l.match.POS.test(b[0])||l.match.CHILD.test(b[0]))return!0;return b},POS:function(a){a.unshift(!0);return a}},filters:{enabled:function(a){return a.disabled===!1&&a.type!=="hidden"},disabled:function(a){return a.disabled===!0},checked:function(a){return a.checked===!0},selected:function(a){a.parentNode&&a.parentNode.selectedIndex;return a.selected===!0},parent:function(a){return!!a.firstChild},empty:function(a){return!a.firstChild},has:function(a,b,c){return!!k(c[3],a).length},header:function(a){return/h\d/i.test(a.nodeName)},text:function(a){var b=a.getAttribute("type"),c=a.type;return a.nodeName.toLowerCase()==="input"&&"text"===c&&(b===c||b===null)},radio:function(a){return a.nodeName.toLowerCase()==="input"&&"radio"===a.type},checkbox:function(a){return a.nodeName.toLowerCase()==="input"&&"checkbox"===a.type},file:function(a){return a.nodeName.toLowerCase()==="input"&&"file"===a.type},password:function(a){return a.nodeName.toLowerCase()==="input"&&"password"===a.type},submit:function(a){var b=a.nodeName.toLowerCase();return(b==="input"||b==="button")&&"submit"===a.type},image:function(a){return a.nodeName.toLowerCase()==="input"&&"image"===a.type},reset:function(a){var b=a.nodeName.toLowerCase();return(b==="input"||b==="button")&&"reset"===a.type},button:function(a){var b=a.nodeName.toLowerCase();return b==="input"&&"button"===a.type||b==="button"},input:function(a){return/input|select|textarea|button/i.test(a.nodeName)},focus:function(a){return a===a.ownerDocument.activeElement}},setFilters:{first:function(a,b){return b===0},last:function(a,b,c,d){return b===d.length-1},even:function(a,b){return b%2===0},odd:function(a,b){return b%2===1},lt:function(a,b,c){return b<c[3]-0},gt:function(a,b,c){return b>c[3]-0},nth:function(a,b,c){return c[3]-0===b},eq:function(a,b,c){return c[3]-0===b}},filter:{PSEUDO:function(a,b,c,d){var e=b[1],f=l.filters[e];if(f)return f(a,c,b,d);if(e==="contains")return(a.textContent||a.innerText||k.getText([a])||"").indexOf(b[3])>=0;if(e==="not"){var g=b[3];for(var h=0,i=g.length;h<i;h++)if(g[h]===a)return!1;return!0}k.error(e)},CHILD:function(a,b){var c=b[1],d=a;switch(c){case"only":case"first":while(d=d.previousSibling)if(d.nodeType===1)return!1;if(c==="first")return!0;d=a;case"last":while(d=d.nextSibling)if(d.nodeType===1)return!1;return!0;case"nth":var e=b[2],f=b[3];if(e===1&&f===0)return!0;var g=b[0],h=a.parentNode;if(h&&(h.sizcache!==g||!a.nodeIndex)){var i=0;for(d=h.firstChild;d;d=d.nextSibling)d.nodeType===1&&(d.nodeIndex=++i);h.sizcache=g}var j=a.nodeIndex-f;return e===0?j===0:j%e===0&&j/e>=0}},ID:function(a,b){return a.nodeType===1&&a.getAttribute("id")===b},TAG:function(a,b){return b==="*"&&a.nodeType===1||a.nodeName.toLowerCase()===b},CLASS:function(a,b){return(" "+(a.className||a.getAttribute("class"))+" ").indexOf(b)>-1},ATTR:function(a,b){var c=b[1],d=l.attrHandle[c]?l.attrHandle[c](a):a[c]!=null?a[c]:a.getAttribute(c),e=d+"",f=b[2],g=b[4];return d==null?f==="!=":f==="="?e===g:f==="*="?e.indexOf(g)>=0:f==="~="?(" "+e+" ").indexOf(g)>=0:g?f==="!="?e!==g:f==="^="?e.indexOf(g)===0:f==="$="?e.substr(e.length-g.length)===g:f==="|="?e===g||e.substr(0,g.length+1)===g+"-":!1:e&&d!==!1},POS:function(a,b,c,d){var e=b[2],f=l.setFilters[e];if(f)return f(a,c,b,d)}}},m=l.match.POS,n=function(a,b){return"\\"+(b-0+1)};for(var o in l.match)l.match[o]=new RegExp(l.match[o].source+/(?![^\[]*\])(?![^\(]*\))/.source),l.leftMatch[o]=new RegExp(/(^(?:.|\r|\n)*?)/.source+l.match[o].source.replace(/\\(\d+)/g,n));var p=function(a,b){a=Array.prototype.slice.call(a,0);if(b){b.push.apply(b,a);return b}return a};try{Array.prototype.slice.call(c.documentElement.childNodes,0)[0].nodeType}catch(q){p=function(a,b){var c=0,d=b||[];if(e.call(a)==="[object Array]")Array.prototype.push.apply(d,a);else if(typeof a.length=="number")for(var f=a.length;c<f;c++)d.push(a[c]);else for(;a[c];c++)d.push(a[c]);return d}}var r,s;c.documentElement.compareDocumentPosition?r=function(a,b){if(a===b){g=!0;return 0}if(!a.compareDocumentPosition||!b.compareDocumentPosition)return a.compareDocumentPosition?-1:1;return a.compareDocumentPosition(b)&4?-1:1}:(r=function(a,b){if(a===b){g=!0;return 0}if(a.sourceIndex&&b.sourceIndex)return a.sourceIndex-b.sourceIndex;var c,d,e=[],f=[],h=a.parentNode,i=b.parentNode,j=h;if(h===i)return s(a,b);if(!h)return-1;if(!i)return 1;while(j)e.unshift(j),j=j.parentNode;j=i;while(j)f.unshift(j),j=j.parentNode;c=e.length,d=f.length;for(var k=0;k<c&&k<d;k++)if(e[k]!==f[k])return s(e[k],f[k]);return k===c?s(a,f[k],-1):s(e[k],b,1)},s=function(a,b,c){if(a===b)return c;var d=a.nextSibling;while(d){if(d===b)return-1;d=d.nextSibling}return 1}),k.getText=function(a){var b="",c;for(var d=0;a[d];d++)c=a[d],c.nodeType===3||c.nodeType===4?b+=c.nodeValue:c.nodeType!==8&&(b+=k.getText(c.childNodes));return b},function(){var a=c.createElement("div"),d="script"+(new Date).getTime(),e=c.documentElement;a.innerHTML="<a name='"+d+"'/>",e.insertBefore(a,e.firstChild),c.getElementById(d)&&(l.find.ID=function(a,c,d){if(typeof c.getElementById!="undefined"&&!d){var e=c.getElementById(a[1]);return e?e.id===a[1]||typeof e.getAttributeNode!="undefined"&&e.getAttributeNode("id").nodeValue===a[1]?[e]:b:[]}},l.filter.ID=function(a,b){var c=typeof a.getAttributeNode!="undefined"&&a.getAttributeNode("id");return a.nodeType===1&&c&&c.nodeValue===b}),e.removeChild(a),e=a=null}(),function(){var a=c.createElement("div");a.appendChild(c.createComment("")),a.getElementsByTagName("*").length>0&&(l.find.TAG=function(a,b){var c=b.getElementsByTagName(a[1]);if(a[1]==="*"){var d=[];for(var e=0;c[e];e++)c[e].nodeType===1&&d.push(c[e]);c=d}return c}),a.innerHTML="<a href='#'></a>",a.firstChild&&typeof a.firstChild.getAttribute!="undefined"&&a.firstChild.getAttribute("href")!=="#"&&(l.attrHandle.href=function(a){return a.getAttribute("href",2)}),a=null}(),c.querySelectorAll&&function(){var a=k,b=c.createElement("div"),d="__sizzle__";b.innerHTML="<p class='TEST'></p>";if(!b.querySelectorAll||b.querySelectorAll(".TEST").length!==0){k=function(b,e,f,g){e=e||c;if(!g&&!k.isXML(e)){var h=/^(\w+$)|^\.([\w\-]+$)|^#([\w\-]+$)/.exec(b);if(h&&(e.nodeType===1||e.nodeType===9)){if(h[1])return p(e.getElementsByTagName(b),f);if(h[2]&&l.find.CLASS&&e.getElementsByClassName)return p(e.getElementsByClassName(h[2]),f)}if(e.nodeType===9){if(b==="body"&&e.body)return p([e.body],f);if(h&&h[3]){var i=e.getElementById(h[3]);if(!i||!i.parentNode)return p([],f);if(i.id===h[3])return p([i],f)}try{return p(e.querySelectorAll(b),f)}catch(j){}}else if(e.nodeType===1&&e.nodeName.toLowerCase()!=="object"){var m=e,n=e.getAttribute("id"),o=n||d,q=e.parentNode,r=/^\s*[+~]/.test(b);n?o=o.replace(/'/g,"\\$&"):e.setAttribute("id",o),r&&q&&(e=e.parentNode);try{if(!r||q)return p(e.querySelectorAll("[id='"+o+"'] "+b),f)}catch(s){}finally{n||m.removeAttribute("id")}}}return a(b,e,f,g)};for(var e in a)k[e]=a[e];b=null}}(),function(){var a=c.documentElement,b=a.matchesSelector||a.mozMatchesSelector||a.webkitMatchesSelector||a.msMatchesSelector;if(b){var d=!b.call(c.createElement("div"),"div"),e=!1;try{b.call(c.documentElement,"[test!='']:sizzle")}catch(f){e=!0}k.matchesSelector=function(a,c){c=c.replace(/\=\s*([^'"\]]*)\s*\]/g,"='$1']");if(!k.isXML(a))try{if(e||!l.match.PSEUDO.test(c)&&!/!=/.test(c)){var f=b.call(a,c);if(f||!d||a.document&&a.document.nodeType!==11)return f}}catch(g){}return k(c,null,null,[a]).length>0}}}(),function(){var a=c.createElement("div");a.innerHTML="<div class='test e'></div><div class='test'></div>";if(!!a.getElementsByClassName&&a.getElementsByClassName("e").length!==0){a.lastChild.className="e";if(a.getElementsByClassName("e").length===1)return;l.order.splice(1,0,"CLASS"),l.find.CLASS=function(a,b,c){if(typeof b.getElementsByClassName!="undefined"&&!c)return b.getElementsByClassName(a[1])},a=null}}(),c.documentElement.contains?k.contains=function(a,b){return a!==b&&(a.contains?a.contains(b):!0)}:c.documentElement.compareDocumentPosition?k.contains=function(a,b){return!!(a.compareDocumentPosition(b)&16)}:k.contains=function(){return!1},k.isXML=function(a){var b=(a?a.ownerDocument||a:0).documentElement;return b?b.nodeName!=="HTML":!1};var v=function(a,b){var c,d=[],e="",f=b.nodeType?[b]:b;while(c=l.match.PSEUDO.exec(a))e+=c[0],a=a.replace(l.match.PSEUDO,"");a=l.relative[a]?a+"*":a;for(var g=0,h=f.length;g<h;g++)k(a,f[g],d);return k.filter(e,d)};f.find=k,f.expr=k.selectors,f.expr[":"]=f.expr.filters,f.unique=k.uniqueSort,f.text=k.getText,f.isXMLDoc=k.isXML,f.contains=k.contains}();var P=/Until$/,Q=/^(?:parents|prevUntil|prevAll)/,R=/,/,S=/^.[^:#\[\.,]*$/,T=Array.prototype.slice,U=f.expr.match.POS,V={children:!0,contents:!0,next:!0,prev:!0};f.fn.extend({find:function(a){var b=this,c,d;if(typeof a!="string")return f(a).filter(function(){for(c=0,d=b.length;c<d;c++)if(f.contains(b[c],this))return!0});var e=this.pushStack("","find",a),g,h,i;for(c=0,d=this.length;c<d;c++){g=e.length,f.find(a,this[c],e);if(c>0)for(h=g;h<e.length;h++)for(i=0;i<g;i++)if(e[i]===e[h]){e.splice(h--,1);break}}return e},has:function(a){var b=f(a);return this.filter(function(){for(var a=0,c=b.length;a<c;a++)if(f.contains(this,b[a]))return!0})},not:function(a){return this.pushStack(X(this,a,!1),"not",a)},filter:function(a){return this.pushStack(X(this,a,!0),"filter",a)},is:function(a){return!!a&&(typeof a=="string"?f.filter(a,this).length>0:this.filter(a).length>0)},closest:function(a,b){var c=[],d,e,g=this[0];if(f.isArray(a)){var h,i,j={},k=1;if(g&&a.length){for(d=0,e=a.length;d<e;d++)i=a[d],j[i]||(j[i]=U.test(i)?f(i,b||this.context):i);while(g&&g.ownerDocument&&g!==b){for(i in j)h=j[i],(h.jquery?h.index(g)>-1:f(g).is(h))&&c.push({selector:i,elem:g,level:k});g=g.parentNode,k++}}return c}var l=U.test(a)||typeof a!="string"?f(a,b||this.context):0;for(d=0,e=this.length;d<e;d++){g=this[d];while(g){if(l?l.index(g)>-1:f.find.matchesSelector(g,a)){c.push(g);break}g=g.parentNode;if(!g||!g.ownerDocument||g===b||g.nodeType===11)break}}c=c.length>1?f.unique(c):c;return this.pushStack(c,"closest",a)},index:function(a){if(!a||typeof a=="string")return f.inArray(this[0],a?f(a):this.parent().children());return f.inArray(a.jquery?a[0]:a,this)},add:function(a,b){var c=typeof a=="string"?f(a,b):f.makeArray(a&&a.nodeType?[a]:a),d=f.merge(this.get(),c);return this.pushStack(W(c[0])||W(d[0])?d:f.unique(d))},andSelf:function(){return this.add(this.prevObject)}}),f.each({parent:function(a){var b=a.parentNode;return b&&b.nodeType!==11?b:null},parents:function(a){return f.dir(a,"parentNode")},parentsUntil:function(a,b,c){return f.dir(a,"parentNode",c)},next:function(a){return f.nth(a,2,"nextSibling")},prev:function(a){return f.nth(a,2,"previousSibling")},nextAll:function(a){return f.dir(a,"nextSibling")},prevAll:function(a){return f.dir(a,"previousSibling")},nextUntil:function(a,b,c){return f.dir(a,"nextSibling",c)},prevUntil:function(a,b,c){return f.dir(a,"previousSibling",c)},siblings:function(a){return f.sibling(a.parentNode.firstChild,a)},children:function(a){return f.sibling(a.firstChild)},contents:function(a){return f.nodeName(a,"iframe")?a.contentDocument||a.contentWindow.document:f.makeArray(a.childNodes)}},function(a,b){f.fn[a]=function(c,d){var e=f.map(this,b,c),g=T.call(arguments);P.test(a)||(d=c),d&&typeof d=="string"&&(e=f.filter(d,e)),e=this.length>1&&!V[a]?f.unique(e):e,(this.length>1||R.test(d))&&Q.test(a)&&(e=e.reverse());return this.pushStack(e,a,g.join(","))}}),f.extend({filter:function(a,b,c){c&&(a=":not("+a+")");return b.length===1?f.find.matchesSelector(b[0],a)?[b[0]]:[]:f.find.matches(a,b)},dir:function(a,c,d){var e=[],g=a[c];while(g&&g.nodeType!==9&&(d===b||g.nodeType!==1||!f(g).is(d)))g.nodeType===1&&e.push(g),g=g[c];return e},nth:function(a,b,c,d){b=b||1;var e=0;for(;a;a=a[c])if(a.nodeType===1&&++e===b)break;return a},sibling:function(a,b){var c=[];for(;a;a=a.nextSibling)a.nodeType===1&&a!==b&&c.push(a);return c}});var Y=/ jQuery\d+="(?:\d+|null)"/g,Z=/^\s+/,$=/<(?!area|br|col|embed|hr|img|input|link|meta|param)(([\w:]+)[^>]*)\/>/ig,_=/<([\w:]+)/,ba=/<tbody/i,bb=/<|&#?\w+;/,bc=/<(?:script|object|embed|option|style)/i,bd=/checked\s*(?:[^=]|=\s*.checked.)/i,be=/\/(java|ecma)script/i,bf=/^\s*<!(?:\[CDATA\[|\-\-)/,bg={option:[1,"<select multiple='multiple'>","</select>"],legend:[1,"<fieldset>","</fieldset>"],thead:[1,"<table>","</table>"],tr:[2,"<table><tbody>","</tbody></table>"],td:[3,"<table><tbody><tr>","</tr></tbody></table>"],col:[2,"<table><tbody></tbody><colgroup>","</colgroup></table>"],area:[1,"<map>","</map>"],_default:[0,"",""]};bg.optgroup=bg.option,bg.tbody=bg.tfoot=bg.colgroup=bg.caption=bg.thead,bg.th=bg.td,f.support.htmlSerialize||(bg._default=[1,"div<div>","</div>"]),f.fn.extend({text:function(a){if(f.isFunction(a))return this.each(function(b){var c=f(this);c.text(a.call(this,b,c.text()))});if(typeof a!="object"&&a!==b)return this.empty().append((this[0]&&this[0].ownerDocument||c).createTextNode(a));return f.text(this)},wrapAll:function(a){if(f.isFunction(a))return this.each(function(b){f(this).wrapAll(a.call(this,b))});if(this[0]){var b=f(a,this[0].ownerDocument).eq(0).clone(!0);this[0].parentNode&&b.insertBefore(this[0]),b.map(function(){var a=this;while(a.firstChild&&a.firstChild.nodeType===1)a=a.firstChild;return a}).append(this)}return this},wrapInner:function(a){if(f.isFunction(a))return this.each(function(b){f(this).wrapInner(a.call(this,b))});return this.each(function(){var b=f(this),c=b.contents();c.length?c.wrapAll(a):b.append(a)})},wrap:function(a){return this.each(function(){f(this).wrapAll(a)})},unwrap:function(){return this.parent().each(function(){f.nodeName(this,"body")||f(this).replaceWith(this.childNodes)}).end()},append:function(){return this.domManip(arguments,!0,function(a){this.nodeType===1&&this.appendChild(a)})},prepend:function(){return this.domManip(arguments,!0,function(a){this.nodeType===1&&this.insertBefore(a,this.firstChild)})},before:function(){if(this[0]&&this[0].parentNode)return this.domManip(arguments,!1,function(a){this.parentNode.insertBefore(a,this)});if(arguments.length){var a=f(arguments[0]);a.push.apply(a,this.toArray());return this.pushStack(a,"before",arguments)}},after:function(){if(this[0]&&this[0].parentNode)return this.domManip(arguments,!1,function(a){this.parentNode.insertBefore(a,this.nextSibling)});if(arguments.length){var a=this.pushStack(this,"after",arguments);a.push.apply(a,f(arguments[0]).toArray());return a}},remove:function(a,b){for(var c=0,d;(d=this[c])!=null;c++)if(!a||f.filter(a,[d]).length)!b&&d.nodeType===1&&(f.cleanData(d.getElementsByTagName("*")),f.cleanData([d])),d.parentNode&&d.parentNode.removeChild(d);return this},empty:function(){for(var a=0,b;(b=this[a])!=null;a++){b.nodeType===1&&f.cleanData(b.getElementsByTagName("*"));while(b.firstChild)b.removeChild(b.firstChild)}return this},clone:function(a,b){a=a==null?!1:a,b=b==null?a:b;return this.map(function(){return f.clone(this,a,b)})},html:function(a){if(a===b)return this[0]&&this[0].nodeType===1?this[0].innerHTML.replace(Y,""):null;if(typeof a=="string"&&!bc.test(a)&&(f.support.leadingWhitespace||!Z.test(a))&&!bg[(_.exec(a)||["",""])[1].toLowerCase()]){a=a.replace($,"<$1></$2>");try{for(var c=0,d=this.length;c<d;c++)this[c].nodeType===1&&(f.cleanData(this[c].getElementsByTagName("*")),this[c].innerHTML=a)}catch(e){this.empty().append(a)}}else f.isFunction(a)?this.each(function(b){var c=f(this);c.html(a.call(this,b,c.html()))}):this.empty().append(a);return this},replaceWith:function(a){if(this[0]&&this[0].parentNode){if(f.isFunction(a))return this.each(function(b){var c=f(this),d=c.html();c.replaceWith(a.call(this,b,d))});typeof a!="string"&&(a=f(a).detach());return this.each(function(){var b=this.nextSibling,c=this.parentNode;f(this).remove(),b?f(b).before(a):f(c).append(a)})}return this.length?this.pushStack(f(f.isFunction(a)?a():a),"replaceWith",a):this},detach:function(a){return this.remove(a,!0)},domManip:function(a,c,d){var e,g,h,i,j=a[0],k=[];if(!f.support.checkClone&&arguments.length===3&&typeof j=="string"&&bd.test(j))return this.each(function(){f(this).domManip(a,c,d,!0)});if(f.isFunction(j))return this.each(function(e){var g=f(this);a[0]=j.call(this,e,c?g.html():b),g.domManip(a,c,d)});if(this[0]){i=j&&j.parentNode,f.support.parentNode&&i&&i.nodeType===11&&i.childNodes.length===this.length?e={fragment:i}:e=f.buildFragment(a,this,k),h=e.fragment,h.childNodes.length===1?g=h=h.firstChild:g=h.firstChild;if(g){c=c&&f.nodeName(g,"tr");for(var l=0,m=this.length,n=m-1;l<m;l++)d.call(c?bh(this[l],g):this[l],e.cacheable||m>1&&l<n?f.clone(h,!0,!0):h)}k.length&&f.each(k,bn)}return this}}),f.buildFragment=function(a,b,d){var e,g,h,i=b&&b[0]?b[0].ownerDocument||b[0]:c;a.length===1&&typeof a[0]=="string"&&a[0].length<512&&i===c&&a[0].charAt(0)==="<"&&!bc.test(a[0])&&(f.support.checkClone||!bd.test(a[0]))&&(g=!0,h=f.fragments[a[0]],h&&h!==1&&(e=h)),e||(e=i.createDocumentFragment(),f.clean(a,i,e,d)),g&&(f.fragments[a[0]]=h?e:1);return{fragment:e,cacheable:g}},f.fragments={},f.each({appendTo:"append",prependTo:"prepend",insertBefore:"before",insertAfter:"after",replaceAll:"replaceWith"},function(a,b){f.fn[a]=function(c){var d=[],e=f(c),g=this.length===1&&this[0].parentNode;if(g&&g.nodeType===11&&g.childNodes.length===1&&e.length===1){e[b](this[0]);return this}for(var h=0,i=e.length;h<i;h++){var j=(h>0?this.clone(!0):this).get();f(e[h])[b](j),d=d.concat(j)}return this.pushStack(d,a,e.selector)}}),f.extend({clone:function(a,b,c){var d=a.cloneNode(!0),e,g,h;if((!f.support.noCloneEvent||!f.support.noCloneChecked)&&(a.nodeType===1||a.nodeType===11)&&!f.isXMLDoc(a)){bj(a,d),e=bk(a),g=bk(d);for(h=0;e[h];++h)bj(e[h],g[h])}if(b){bi(a,d);if(c){e=bk(a),g=bk(d);for(h=0;e[h];++h)bi(e[h],g[h])}}return d},clean:function(a,b,d,e){var g;b=b||c,typeof b.createElement=="undefined"&&(b=b.ownerDocument||
b[0]&&b[0].ownerDocument||c);var h=[],i;for(var j=0,k;(k=a[j])!=null;j++){typeof k=="number"&&(k+="");if(!k)continue;if(typeof k=="string")if(!bb.test(k))k=b.createTextNode(k);else{k=k.replace($,"<$1></$2>");var l=(_.exec(k)||["",""])[1].toLowerCase(),m=bg[l]||bg._default,n=m[0],o=b.createElement("div");o.innerHTML=m[1]+k+m[2];while(n--)o=o.lastChild;if(!f.support.tbody){var p=ba.test(k),q=l==="table"&&!p?o.firstChild&&o.firstChild.childNodes:m[1]==="<table>"&&!p?o.childNodes:[];for(i=q.length-1;i>=0;--i)f.nodeName(q[i],"tbody")&&!q[i].childNodes.length&&q[i].parentNode.removeChild(q[i])}!f.support.leadingWhitespace&&Z.test(k)&&o.insertBefore(b.createTextNode(Z.exec(k)[0]),o.firstChild),k=o.childNodes}var r;if(!f.support.appendChecked)if(k[0]&&typeof (r=k.length)=="number")for(i=0;i<r;i++)bm(k[i]);else bm(k);k.nodeType?h.push(k):h=f.merge(h,k)}if(d){g=function(a){return!a.type||be.test(a.type)};for(j=0;h[j];j++)if(e&&f.nodeName(h[j],"script")&&(!h[j].type||h[j].type.toLowerCase()==="text/javascript"))e.push(h[j].parentNode?h[j].parentNode.removeChild(h[j]):h[j]);else{if(h[j].nodeType===1){var s=f.grep(h[j].getElementsByTagName("script"),g);h.splice.apply(h,[j+1,0].concat(s))}d.appendChild(h[j])}}return h},cleanData:function(a){var b,c,d=f.cache,e=f.expando,g=f.event.special,h=f.support.deleteExpando;for(var i=0,j;(j=a[i])!=null;i++){if(j.nodeName&&f.noData[j.nodeName.toLowerCase()])continue;c=j[f.expando];if(c){b=d[c]&&d[c][e];if(b&&b.events){for(var k in b.events)g[k]?f.event.remove(j,k):f.removeEvent(j,k,b.handle);b.handle&&(b.handle.elem=null)}h?delete j[f.expando]:j.removeAttribute&&j.removeAttribute(f.expando),delete d[c]}}}});var bo=/alpha\([^)]*\)/i,bp=/opacity=([^)]*)/,bq=/-([a-z])/ig,br=/([A-Z]|^ms)/g,bs=/^-?\d+(?:px)?$/i,bt=/^-?\d/,bu=/^[+\-]=/,bv=/[^+\-\.\de]+/g,bw={position:"absolute",visibility:"hidden",display:"block"},bx=["Left","Right"],by=["Top","Bottom"],bz,bA,bB,bC=function(a,b){return b.toUpperCase()};f.fn.css=function(a,c){if(arguments.length===2&&c===b)return this;return f.access(this,a,c,!0,function(a,c,d){return d!==b?f.style(a,c,d):f.css(a,c)})},f.extend({cssHooks:{opacity:{get:function(a,b){if(b){var c=bz(a,"opacity","opacity");return c===""?"1":c}return a.style.opacity}}},cssNumber:{zIndex:!0,fontWeight:!0,opacity:!0,zoom:!0,lineHeight:!0,widows:!0,orphans:!0},cssProps:{"float":f.support.cssFloat?"cssFloat":"styleFloat"},style:function(a,c,d,e){if(!!a&&a.nodeType!==3&&a.nodeType!==8&&!!a.style){var g,h,i=f.camelCase(c),j=a.style,k=f.cssHooks[i];c=f.cssProps[i]||i;if(d===b){if(k&&"get"in k&&(g=k.get(a,!1,e))!==b)return g;return j[c]}h=typeof d;if(h==="number"&&isNaN(d)||d==null)return;h==="string"&&bu.test(d)&&(d=+d.replace(bv,"")+parseFloat(f.css(a,c))),h==="number"&&!f.cssNumber[i]&&(d+="px");if(!k||!("set"in k)||(d=k.set(a,d))!==b)try{j[c]=d}catch(l){}}},css:function(a,c,d){var e,g;c=f.camelCase(c),g=f.cssHooks[c],c=f.cssProps[c]||c,c==="cssFloat"&&(c="float");if(g&&"get"in g&&(e=g.get(a,!0,d))!==b)return e;if(bz)return bz(a,c)},swap:function(a,b,c){var d={};for(var e in b)d[e]=a.style[e],a.style[e]=b[e];c.call(a);for(e in b)a.style[e]=d[e]},camelCase:function(a){return a.replace(bq,bC)}}),f.curCSS=f.css,f.each(["height","width"],function(a,b){f.cssHooks[b]={get:function(a,c,d){var e;if(c){a.offsetWidth!==0?e=bD(a,b,d):f.swap(a,bw,function(){e=bD(a,b,d)});if(e<=0){e=bz(a,b,b),e==="0px"&&bB&&(e=bB(a,b,b));if(e!=null)return e===""||e==="auto"?"0px":e}if(e<0||e==null){e=a.style[b];return e===""||e==="auto"?"0px":e}return typeof e=="string"?e:e+"px"}},set:function(a,b){if(!bs.test(b))return b;b=parseFloat(b);if(b>=0)return b+"px"}}}),f.support.opacity||(f.cssHooks.opacity={get:function(a,b){return bp.test((b&&a.currentStyle?a.currentStyle.filter:a.style.filter)||"")?parseFloat(RegExp.$1)/100+"":b?"1":""},set:function(a,b){var c=a.style,d=a.currentStyle;c.zoom=1;var e=f.isNaN(b)?"":"alpha(opacity="+b*100+")",g=d&&d.filter||c.filter||"";c.filter=bo.test(g)?g.replace(bo,e):g+" "+e}}),f(function(){f.support.reliableMarginRight||(f.cssHooks.marginRight={get:function(a,b){var c;f.swap(a,{display:"inline-block"},function(){b?c=bz(a,"margin-right","marginRight"):c=a.style.marginRight});return c}})}),c.defaultView&&c.defaultView.getComputedStyle&&(bA=function(a,c){var d,e,g;c=c.replace(br,"-$1").toLowerCase();if(!(e=a.ownerDocument.defaultView))return b;if(g=e.getComputedStyle(a,null))d=g.getPropertyValue(c),d===""&&!f.contains(a.ownerDocument.documentElement,a)&&(d=f.style(a,c));return d}),c.documentElement.currentStyle&&(bB=function(a,b){var c,d=a.currentStyle&&a.currentStyle[b],e=a.runtimeStyle&&a.runtimeStyle[b],f=a.style;!bs.test(d)&&bt.test(d)&&(c=f.left,e&&(a.runtimeStyle.left=a.currentStyle.left),f.left=b==="fontSize"?"1em":d||0,d=f.pixelLeft+"px",f.left=c,e&&(a.runtimeStyle.left=e));return d===""?"auto":d}),bz=bA||bB,f.expr&&f.expr.filters&&(f.expr.filters.hidden=function(a){var b=a.offsetWidth,c=a.offsetHeight;return b===0&&c===0||!f.support.reliableHiddenOffsets&&(a.style.display||f.css(a,"display"))==="none"},f.expr.filters.visible=function(a){return!f.expr.filters.hidden(a)});var bE=/%20/g,bF=/\[\]$/,bG=/\r?\n/g,bH=/#.*$/,bI=/^(.*?):[ \t]*([^\r\n]*)\r?$/mg,bJ=/^(?:color|date|datetime|email|hidden|month|number|password|range|search|tel|text|time|url|week)$/i,bK=/^(?:about|app|app\-storage|.+\-extension|file|widget):$/,bL=/^(?:GET|HEAD)$/,bM=/^\/\//,bN=/\?/,bO=/<script\b[^<]*(?:(?!<\/script>)<[^<]*)*<\/script>/gi,bP=/^(?:select|textarea)/i,bQ=/\s+/,bR=/([?&])_=[^&]*/,bS=/^([\w\+\.\-]+:)(?:\/\/([^\/?#:]*)(?::(\d+))?)?/,bT=f.fn.load,bU={},bV={},bW,bX;try{bW=e.href}catch(bY){bW=c.createElement("a"),bW.href="",bW=bW.href}bX=bS.exec(bW.toLowerCase())||[],f.fn.extend({load:function(a,c,d){if(typeof a!="string"&&bT)return bT.apply(this,arguments);if(!this.length)return this;var e=a.indexOf(" ");if(e>=0){var g=a.slice(e,a.length);a=a.slice(0,e)}var h="GET";c&&(f.isFunction(c)?(d=c,c=b):typeof c=="object"&&(c=f.param(c,f.ajaxSettings.traditional),h="POST"));var i=this;f.ajax({url:a,type:h,dataType:"html",data:c,complete:function(a,b,c){c=a.responseText,a.isResolved()&&(a.done(function(a){c=a}),i.html(g?f("<div>").append(c.replace(bO,"")).find(g):c)),d&&i.each(d,[c,b,a])}});return this},serialize:function(){return f.param(this.serializeArray())},serializeArray:function(){return this.map(function(){return this.elements?f.makeArray(this.elements):this}).filter(function(){return this.name&&!this.disabled&&(this.checked||bP.test(this.nodeName)||bJ.test(this.type))}).map(function(a,b){var c=f(this).val();return c==null?null:f.isArray(c)?f.map(c,function(a,c){return{name:b.name,value:a.replace(bG,"\r\n")}}):{name:b.name,value:c.replace(bG,"\r\n")}}).get()}}),f.each("ajaxStart ajaxStop ajaxComplete ajaxError ajaxSuccess ajaxSend".split(" "),function(a,b){f.fn[b]=function(a){return this.bind(b,a)}}),f.each(["get","post"],function(a,c){f[c]=function(a,d,e,g){f.isFunction(d)&&(g=g||e,e=d,d=b);return f.ajax({type:c,url:a,data:d,success:e,dataType:g})}}),f.extend({getScript:function(a,c){return f.get(a,b,c,"script")},getJSON:function(a,b,c){return f.get(a,b,c,"json")},ajaxSetup:function(a,b){b?f.extend(!0,a,f.ajaxSettings,b):(b=a,a=f.extend(!0,f.ajaxSettings,b));for(var c in{context:1,url:1})c in b?a[c]=b[c]:c in f.ajaxSettings&&(a[c]=f.ajaxSettings[c]);return a},ajaxSettings:{url:bW,isLocal:bK.test(bX[1]),global:!0,type:"GET",contentType:"application/x-www-form-urlencoded",processData:!0,async:!0,accepts:{xml:"application/xml, text/xml",html:"text/html",text:"text/plain",json:"application/json, text/javascript","*":"*/*"},contents:{xml:/xml/,html:/html/,json:/json/},responseFields:{xml:"responseXML",text:"responseText"},converters:{"* text":a.String,"text html":!0,"text json":f.parseJSON,"text xml":f.parseXML}},ajaxPrefilter:bZ(bU),ajaxTransport:bZ(bV),ajax:function(a,c){function w(a,c,l,m){if(s!==2){s=2,q&&clearTimeout(q),p=b,n=m||"",v.readyState=a?4:0;var o,r,u,w=l?ca(d,v,l):b,x,y;if(a>=200&&a<300||a===304){if(d.ifModified){if(x=v.getResponseHeader("Last-Modified"))f.lastModified[k]=x;if(y=v.getResponseHeader("Etag"))f.etag[k]=y}if(a===304)c="notmodified",o=!0;else try{r=cb(d,w),c="success",o=!0}catch(z){c="parsererror",u=z}}else{u=c;if(!c||a)c="error",a<0&&(a=0)}v.status=a,v.statusText=c,o?h.resolveWith(e,[r,c,v]):h.rejectWith(e,[v,c,u]),v.statusCode(j),j=b,t&&g.trigger("ajax"+(o?"Success":"Error"),[v,d,o?r:u]),i.resolveWith(e,[v,c]),t&&(g.trigger("ajaxComplete",[v,d]),--f.active||f.event.trigger("ajaxStop"))}}typeof a=="object"&&(c=a,a=b),c=c||{};var d=f.ajaxSetup({},c),e=d.context||d,g=e!==d&&(e.nodeType||e instanceof f)?f(e):f.event,h=f.Deferred(),i=f._Deferred(),j=d.statusCode||{},k,l={},m={},n,o,p,q,r,s=0,t,u,v={readyState:0,setRequestHeader:function(a,b){if(!s){var c=a.toLowerCase();a=m[c]=m[c]||a,l[a]=b}return this},getAllResponseHeaders:function(){return s===2?n:null},getResponseHeader:function(a){var c;if(s===2){if(!o){o={};while(c=bI.exec(n))o[c[1].toLowerCase()]=c[2]}c=o[a.toLowerCase()]}return c===b?null:c},overrideMimeType:function(a){s||(d.mimeType=a);return this},abort:function(a){a=a||"abort",p&&p.abort(a),w(0,a);return this}};h.promise(v),v.success=v.done,v.error=v.fail,v.complete=i.done,v.statusCode=function(a){if(a){var b;if(s<2)for(b in a)j[b]=[j[b],a[b]];else b=a[v.status],v.then(b,b)}return this},d.url=((a||d.url)+"").replace(bH,"").replace(bM,bX[1]+"//"),d.dataTypes=f.trim(d.dataType||"*").toLowerCase().split(bQ),d.crossDomain==null&&(r=bS.exec(d.url.toLowerCase()),d.crossDomain=!(!r||r[1]==bX[1]&&r[2]==bX[2]&&(r[3]||(r[1]==="http:"?80:443))==(bX[3]||(bX[1]==="http:"?80:443)))),d.data&&d.processData&&typeof d.data!="string"&&(d.data=f.param(d.data,d.traditional)),b$(bU,d,c,v);if(s===2)return!1;t=d.global,d.type=d.type.toUpperCase(),d.hasContent=!bL.test(d.type),t&&f.active++===0&&f.event.trigger("ajaxStart");if(!d.hasContent){d.data&&(d.url+=(bN.test(d.url)?"&":"?")+d.data),k=d.url;if(d.cache===!1){var x=f.now(),y=d.url.replace(bR,"$1_="+x);d.url=y+(y===d.url?(bN.test(d.url)?"&":"?")+"_="+x:"")}}(d.data&&d.hasContent&&d.contentType!==!1||c.contentType)&&v.setRequestHeader("Content-Type",d.contentType),d.ifModified&&(k=k||d.url,f.lastModified[k]&&v.setRequestHeader("If-Modified-Since",f.lastModified[k]),f.etag[k]&&v.setRequestHeader("If-None-Match",f.etag[k])),v.setRequestHeader("Accept",d.dataTypes[0]&&d.accepts[d.dataTypes[0]]?d.accepts[d.dataTypes[0]]+(d.dataTypes[0]!=="*"?", */*; q=0.01":""):d.accepts["*"]);for(u in d.headers)v.setRequestHeader(u,d.headers[u]);if(d.beforeSend&&(d.beforeSend.call(e,v,d)===!1||s===2)){v.abort();return!1}for(u in{success:1,error:1,complete:1})v[u](d[u]);p=b$(bV,d,c,v);if(!p)w(-1,"No Transport");else{v.readyState=1,t&&g.trigger("ajaxSend",[v,d]),d.async&&d.timeout>0&&(q=setTimeout(function(){v.abort("timeout")},d.timeout));try{s=1,p.send(l,w)}catch(z){status<2?w(-1,z):f.error(z)}}return v},param:function(a,c){var d=[],e=function(a,b){b=f.isFunction(b)?b():b,d[d.length]=encodeURIComponent(a)+"="+encodeURIComponent(b)};c===b&&(c=f.ajaxSettings.traditional);if(f.isArray(a)||a.jquery&&!f.isPlainObject(a))f.each(a,function(){e(this.name,this.value)});else for(var g in a)b_(g,a[g],c,e);return d.join("&").replace(bE,"+")}}),f.extend({active:0,lastModified:{},etag:{}});var cc=f.now(),cd=/(\=)\?(&|$)|\?\?/i;f.ajaxSetup({jsonp:"callback",jsonpCallback:function(){return f.expando+"_"+cc++}}),f.ajaxPrefilter("json jsonp",function(b,c,d){var e=b.contentType==="application/x-www-form-urlencoded"&&typeof b.data=="string";if(b.dataTypes[0]==="jsonp"||b.jsonp!==!1&&(cd.test(b.url)||e&&cd.test(b.data))){var g,h=b.jsonpCallback=f.isFunction(b.jsonpCallback)?b.jsonpCallback():b.jsonpCallback,i=a[h],j=b.url,k=b.data,l="$1"+h+"$2";b.jsonp!==!1&&(j=j.replace(cd,l),b.url===j&&(e&&(k=k.replace(cd,l)),b.data===k&&(j+=(/\?/.test(j)?"&":"?")+b.jsonp+"="+h))),b.url=j,b.data=k,a[h]=function(a){g=[a]},d.always(function(){a[h]=i,g&&f.isFunction(i)&&a[h](g[0])}),b.converters["script json"]=function(){g||f.error(h+" was not called");return g[0]},b.dataTypes[0]="json";return"script"}}),f.ajaxSetup({accepts:{script:"text/javascript, application/javascript, application/ecmascript, application/x-ecmascript"},contents:{script:/javascript|ecmascript/},converters:{"text script":function(a){f.globalEval(a);return a}}}),f.ajaxPrefilter("script",function(a){a.cache===b&&(a.cache=!1),a.crossDomain&&(a.type="GET",a.global=!1)}),f.ajaxTransport("script",function(a){if(a.crossDomain){var d,e=c.head||c.getElementsByTagName("head")[0]||c.documentElement;return{send:function(f,g){d=c.createElement("script"),d.async="async",a.scriptCharset&&(d.charset=a.scriptCharset),d.src=a.url,d.onload=d.onreadystatechange=function(a,c){if(c||!d.readyState||/loaded|complete/.test(d.readyState))d.onload=d.onreadystatechange=null,e&&d.parentNode&&e.removeChild(d),d=b,c||g(200,"success")},e.insertBefore(d,e.firstChild)},abort:function(){d&&d.onload(0,1)}}}});var ce=a.ActiveXObject?function(){for(var a in cg)cg[a](0,1)}:!1,cf=0,cg;f.ajaxSettings.xhr=a.ActiveXObject?function(){return!this.isLocal&&ch()||ci()}:ch,function(a){f.extend(f.support,{ajax:!!a,cors:!!a&&"withCredentials"in a})}(f.ajaxSettings.xhr()),f.support.ajax&&f.ajaxTransport(function(c){if(!c.crossDomain||f.support.cors){var d;return{send:function(e,g){var h=c.xhr(),i,j;c.username?h.open(c.type,c.url,c.async,c.username,c.password):h.open(c.type,c.url,c.async);if(c.xhrFields)for(j in c.xhrFields)h[j]=c.xhrFields[j];c.mimeType&&h.overrideMimeType&&h.overrideMimeType(c.mimeType),!c.crossDomain&&!e["X-Requested-With"]&&(e["X-Requested-With"]="XMLHttpRequest");try{for(j in e)h.setRequestHeader(j,e[j])}catch(k){}h.send(c.hasContent&&c.data||null),d=function(a,e){var j,k,l,m,n;try{if(d&&(e||h.readyState===4)){d=b,i&&(h.onreadystatechange=f.noop,ce&&delete cg[i]);if(e)h.readyState!==4&&h.abort();else{j=h.status,l=h.getAllResponseHeaders(),m={},n=h.responseXML,n&&n.documentElement&&(m.xml=n),m.text=h.responseText;try{k=h.statusText}catch(o){k=""}!j&&c.isLocal&&!c.crossDomain?j=m.text?200:404:j===1223&&(j=204)}}}catch(p){e||g(-1,p)}m&&g(j,k,m,l)},!c.async||h.readyState===4?d():(i=++cf,ce&&(cg||(cg={},f(a).unload(ce)),cg[i]=d),h.onreadystatechange=d)},abort:function(){d&&d(0,1)}}}});var cj={},ck,cl,cm=/^(?:toggle|show|hide)$/,cn=/^([+\-]=)?([\d+.\-]+)([a-z%]*)$/i,co,cp=[["height","marginTop","marginBottom","paddingTop","paddingBottom"],["width","marginLeft","marginRight","paddingLeft","paddingRight"],["opacity"]],cq,cr=a.webkitRequestAnimationFrame||a.mozRequestAnimationFrame||a.oRequestAnimationFrame;f.fn.extend({show:function(a,b,c){var d,e;if(a||a===0)return this.animate(cu("show",3),a,b,c);for(var g=0,h=this.length;g<h;g++)d=this[g],d.style&&(e=d.style.display,!f._data(d,"olddisplay")&&e==="none"&&(e=d.style.display=""),e===""&&f.css(d,"display")==="none"&&f._data(d,"olddisplay",cv(d.nodeName)));for(g=0;g<h;g++){d=this[g];if(d.style){e=d.style.display;if(e===""||e==="none")d.style.display=f._data(d,"olddisplay")||""}}return this},hide:function(a,b,c){if(a||a===0)return this.animate(cu("hide",3),a,b,c);for(var d=0,e=this.length;d<e;d++)if(this[d].style){var g=f.css(this[d],"display");g!=="none"&&!f._data(this[d],"olddisplay")&&f._data(this[d],"olddisplay",g)}for(d=0;d<e;d++)this[d].style&&(this[d].style.display="none");return this},_toggle:f.fn.toggle,toggle:function(a,b,c){var d=typeof a=="boolean";f.isFunction(a)&&f.isFunction(b)?this._toggle.apply(this,arguments):a==null||d?this.each(function(){var b=d?a:f(this).is(":hidden");f(this)[b?"show":"hide"]()}):this.animate(cu("toggle",3),a,b,c);return this},fadeTo:function(a,b,c,d){return this.filter(":hidden").css("opacity",0).show().end().animate({opacity:b},a,c,d)},animate:function(a,b,c,d){var e=f.speed(b,c,d);if(f.isEmptyObject(a))return this.each(e.complete,[!1]);a=f.extend({},a);return this[e.queue===!1?"each":"queue"](function(){e.queue===!1&&f._mark(this);var b=f.extend({},e),c=this.nodeType===1,d=c&&f(this).is(":hidden"),g,h,i,j,k,l,m,n,o;b.animatedProperties={};for(i in a){g=f.camelCase(i),i!==g&&(a[g]=a[i],delete a[i]),h=a[g],f.isArray(h)?(b.animatedProperties[g]=h[1],h=a[g]=h[0]):b.animatedProperties[g]=b.specialEasing&&b.specialEasing[g]||b.easing||"swing";if(h==="hide"&&d||h==="show"&&!d)return b.complete.call(this);c&&(g==="height"||g==="width")&&(b.overflow=[this.style.overflow,this.style.overflowX,this.style.overflowY],f.css(this,"display")==="inline"&&f.css(this,"float")==="none"&&(f.support.inlineBlockNeedsLayout?(j=cv(this.nodeName),j==="inline"?this.style.display="inline-block":(this.style.display="inline",this.style.zoom=1)):this.style.display="inline-block"))}b.overflow!=null&&(this.style.overflow="hidden");for(i in a)k=new f.fx(this,b,i),h=a[i],cm.test(h)?k[h==="toggle"?d?"show":"hide":h]():(l=cn.exec(h),m=k.cur(),l?(n=parseFloat(l[2]),o=l[3]||(f.cssNumber[i]?"":"px"),o!=="px"&&(f.style(this,i,(n||1)+o),m=(n||1)/k.cur()*m,f.style(this,i,m+o)),l[1]&&(n=(l[1]==="-="?-1:1)*n+m),k.custom(m,n,o)):k.custom(m,h,""));return!0})},stop:function(a,b){a&&this.queue([]),this.each(function(){var a=f.timers,c=a.length;b||f._unmark(!0,this);while(c--)a[c].elem===this&&(b&&a[c](!0),a.splice(c,1))}),b||this.dequeue();return this}}),f.each({slideDown:cu("show",1),slideUp:cu("hide",1),slideToggle:cu("toggle",1),fadeIn:{opacity:"show"},fadeOut:{opacity:"hide"},fadeToggle:{opacity:"toggle"}},function(a,b){f.fn[a]=function(a,c,d){return this.animate(b,a,c,d)}}),f.extend({speed:function(a,b,c){var d=a&&typeof a=="object"?f.extend({},a):{complete:c||!c&&b||f.isFunction(a)&&a,duration:a,easing:c&&b||b&&!f.isFunction(b)&&b};d.duration=f.fx.off?0:typeof d.duration=="number"?d.duration:d.duration in f.fx.speeds?f.fx.speeds[d.duration]:f.fx.speeds._default,d.old=d.complete,d.complete=function(a){d.queue!==!1?f.dequeue(this):a!==!1&&f._unmark(this),f.isFunction(d.old)&&d.old.call(this)};return d},easing:{linear:function(a,b,c,d){return c+d*a},swing:function(a,b,c,d){return(-Math.cos(a*Math.PI)/2+.5)*d+c}},timers:[],fx:function(a,b,c){this.options=b,this.elem=a,this.prop=c,b.orig=b.orig||{}}}),f.fx.prototype={update:function(){this.options.step&&this.options.step.call(this.elem,this.now,this),(f.fx.step[this.prop]||f.fx.step._default)(this)},cur:function(){if(this.elem[this.prop]!=null&&(!this.elem.style||this.elem.style[this.prop]==null))return this.elem[this.prop];var a,b=f.css(this.elem,this.prop);return isNaN(a=parseFloat(b))?!b||b==="auto"?0:b:a},custom:function(a,b,c){function h(a){return d.step(a)}var d=this,e=f.fx,g;this.startTime=cq||cs(),this.start=a,this.end=b,this.unit=c||this.unit||(f.cssNumber[this.prop]?"":"px"),this.now=this.start,this.pos=this.state=0,h.elem=this.elem,h()&&f.timers.push(h)&&!co&&(cr?(co=1,g=function(){co&&(cr(g),e.tick())},cr(g)):co=setInterval(e.tick,e.interval))},show:function(){this.options.orig[this.prop]=f.style(this.elem,this.prop),this.options.show=!0,this.custom(this.prop==="width"||this.prop==="height"?1:0,this.cur()),f(this.elem).show()},hide:function(){this.options.orig[this.prop]=f.style(this.elem,this.prop),this.options.hide=!0,this.custom(this.cur(),0)},step:function(a){var b=cq||cs(),c=!0,d=this.elem,e=this.options,g,h;if(a||b>=e.duration+this.startTime){this.now=this.end,this.pos=this.state=1,this.update(),e.animatedProperties[this.prop]=!0;for(g in e.animatedProperties)e.animatedProperties[g]!==!0&&(c=!1);if(c){e.overflow!=null&&!f.support.shrinkWrapBlocks&&f.each(["","X","Y"],function(a,b){d.style["overflow"+b]=e.overflow[a]}),e.hide&&f(d).hide();if(e.hide||e.show)for(var i in e.animatedProperties)f.style(d,i,e.orig[i]);e.complete.call(d)}return!1}e.duration==Infinity?this.now=b:(h=b-this.startTime,this.state=h/e.duration,this.pos=f.easing[e.animatedProperties[this.prop]](this.state,h,0,1,e.duration),this.now=this.start+(this.end-this.start)*this.pos),this.update();return!0}},f.extend(f.fx,{tick:function(){for(var a=f.timers,b=0;b<a.length;++b)a[b]()||a.splice(b--,1);a.length||f.fx.stop()},interval:13,stop:function(){clearInterval(co),co=null},speeds:{slow:600,fast:200,_default:400},step:{opacity:function(a){f.style(a.elem,"opacity",a.now)},_default:function(a){a.elem.style&&a.elem.style[a.prop]!=null?a.elem.style[a.prop]=(a.prop==="width"||a.prop==="height"?Math.max(0,a.now):a.now)+a.unit:a.elem[a.prop]=a.now}}}),f.expr&&f.expr.filters&&(f.expr.filters.animated=function(a){return f.grep(f.timers,function(b){return a===b.elem}).length});var cw=/^t(?:able|d|h)$/i,cx=/^(?:body|html)$/i;"getBoundingClientRect"in c.documentElement?f.fn.offset=function(a){var b=this[0],c;if(a)return this.each(function(b){f.offset.setOffset(this,a,b)});if(!b||!b.ownerDocument)return null;if(b===b.ownerDocument.body)return f.offset.bodyOffset(b);try{c=b.getBoundingClientRect()}catch(d){}var e=b.ownerDocument,g=e.documentElement;if(!c||!f.contains(g,b))return c?{top:c.top,left:c.left}:{top:0,left:0};var h=e.body,i=cy(e),j=g.clientTop||h.clientTop||0,k=g.clientLeft||h.clientLeft||0,l=i.pageYOffset||f.support.boxModel&&g.scrollTop||h.scrollTop,m=i.pageXOffset||f.support.boxModel&&g.scrollLeft||h.scrollLeft,n=c.top+l-j,o=c.left+m-k;return{top:n,left:o}}:f.fn.offset=function(a){var b=this[0];if(a)return this.each(function(b){f.offset.setOffset(this,a,b)});if(!b||!b.ownerDocument)return null;if(b===b.ownerDocument.body)return f.offset.bodyOffset(b);f.offset.initialize();var c,d=b.offsetParent,e=b,g=b.ownerDocument,h=g.documentElement,i=g.body,j=g.defaultView,k=j?j.getComputedStyle(b,null):b.currentStyle,l=b.offsetTop,m=b.offsetLeft;while((b=b.parentNode)&&b!==i&&b!==h){if(f.offset.supportsFixedPosition&&k.position==="fixed")break;c=j?j.getComputedStyle(b,null):b.currentStyle,l-=b.scrollTop,m-=b.scrollLeft,b===d&&(l+=b.offsetTop,m+=b.offsetLeft,f.offset.doesNotAddBorder&&(!f.offset.doesAddBorderForTableAndCells||!cw.test(b.nodeName))&&(l+=parseFloat(c.borderTopWidth)||0,m+=parseFloat(c.borderLeftWidth)||0),e=d,d=b.offsetParent),f.offset.subtractsBorderForOverflowNotVisible&&c.overflow!=="visible"&&(l+=parseFloat(c.borderTopWidth)||0,m+=parseFloat(c.borderLeftWidth)||0),k=c}if(k.position==="relative"||k.position==="static")l+=i.offsetTop,m+=i.offsetLeft;f.offset.supportsFixedPosition&&k.position==="fixed"&&(l+=Math.max(h.scrollTop,i.scrollTop),m+=Math.max(h.scrollLeft,i.scrollLeft));return{top:l,left:m}},f.offset={initialize:function(){var a=c.body,b=c.createElement("div"),d,e,g,h,i=parseFloat(f.css(a,"marginTop"))||0,j="<div style='position:absolute;top:0;left:0;margin:0;border:5px solid #000;padding:0;width:1px;height:1px;'><div></div></div><table style='position:absolute;top:0;left:0;margin:0;border:5px solid #000;padding:0;width:1px;height:1px;' cellpadding='0' cellspacing='0'><tr><td></td></tr></table>";f.extend(b.style,{position:"absolute",top:0,left:0,margin:0,border:0,width:"1px",height:"1px",visibility:"hidden"}),b.innerHTML=j,a.insertBefore(b,a.firstChild),d=b.firstChild,e=d.firstChild,h=d.nextSibling.firstChild.firstChild,this.doesNotAddBorder=e.offsetTop!==5,this.doesAddBorderForTableAndCells=h.offsetTop===5,e.style.position="fixed",e.style.top="20px",this.supportsFixedPosition=e.offsetTop===20||e.offsetTop===15,e.style.position=e.style.top="",d.style.overflow="hidden",d.style.position="relative",this.subtractsBorderForOverflowNotVisible=e.offsetTop===-5,this.doesNotIncludeMarginInBodyOffset=a.offsetTop!==i,a.removeChild(b),f.offset.initialize=f.noop},bodyOffset:function(a){var b=a.offsetTop,c=a.offsetLeft;f.offset.initialize(),f.offset.doesNotIncludeMarginInBodyOffset&&(b+=parseFloat(f.css(a,"marginTop"))||0,c+=parseFloat(f.css(a,"marginLeft"))||0);return{top:b,left:c}},setOffset:function(a,b,c){var d=f.css(a,"position");d==="static"&&(a.style.position="relative");var e=f(a),g=e.offset(),h=f.css(a,"top"),i=f.css(a,"left"),j=(d==="absolute"||d==="fixed")&&f.inArray("auto",[h,i])>-1,k={},l={},m,n;j?(l=e.position(),m=l.top,n=l.left):(m=parseFloat(h)||0,n=parseFloat(i)||0),f.isFunction(b)&&(b=b.call(a,c,g)),b.top!=null&&(k.top=b.top-g.top+m),b.left!=null&&(k.left=b.left-g.left+n),"using"in b?b.using.call(a,k):e.css(k)}},f.fn.extend({position:function(){if(!this[0])return null;var a=this[0],b=this.offsetParent(),c=this.offset(),d=cx.test(b[0].nodeName)?{top:0,left:0}:b.offset();c.top-=parseFloat(f.css(a,"marginTop"))||0,c.left-=parseFloat(f.css(a,"marginLeft"))||0,d.top+=parseFloat(f.css(b[0],"borderTopWidth"))||0,d.left+=parseFloat(f.css(b[0],"borderLeftWidth"))||0;return{top:c.top-d.top,left:c.left-d.left}},offsetParent:function(){return this.map(function(){var a=this.offsetParent||c.body;while(a&&!cx.test(a.nodeName)&&f.css(a,"position")==="static")a=a.offsetParent;return a})}}),f.each(["Left","Top"],function(a,c){var d="scroll"+c;f.fn[d]=function(c){var e,g;if(c===b){e=this[0];if(!e)return null;g=cy(e);return g?"pageXOffset"in g?g[a?"pageYOffset":"pageXOffset"]:f.support.boxModel&&g.document.documentElement[d]||g.document.body[d]:e[d]}return this.each(function(){g=cy(this),g?g.scrollTo(a?f(g).scrollLeft():c,a?c:f(g).scrollTop()):this[d]=c})}}),f.each(["Height","Width"],function(a,c){var d=c.toLowerCase();f.fn["inner"+c]=function(){return this[0]?parseFloat(f.css(this[0],d,"padding")):null},f.fn["outer"+c]=function(a){return this[0]?parseFloat(f.css(this[0],d,a?"margin":"border")):null},f.fn[d]=function(a){var e=this[0];if(!e)return a==null?null:this;if(f.isFunction(a))return this.each(function(b){var c=f(this);c[d](a.call(this,b,c[d]()))});if(f.isWindow(e)){var g=e.document.documentElement["client"+c];return e.document.compatMode==="CSS1Compat"&&g||e.document.body["client"+c]||g}if(e.nodeType===9)return Math.max(e.documentElement["client"+c],e.body["scroll"+c],e.documentElement["scroll"+c],e.body["offset"+c],e.documentElement["offset"+c]);if(a===b){var h=f.css(e,d),i=parseFloat(h);return f.isNaN(i)?h:i}return this.css(d,typeof a=="string"?a:a+"px")}}),a.jQuery=a.$=f})(window);

/*jquery json*/
(function($){$.toJSON=function(o)
{if(typeof(JSON)=='object'&&JSON.stringify)
return JSON.stringify(o);var type=typeof(o);if(o===null)
return"null";if(type=="undefined")
return undefined;if(type=="number"||type=="boolean")
return o+"";if(type=="string")
return $.quoteString(o);if(type=='object')
{if(typeof o.toJSON=="function")
return $.toJSON(o.toJSON());if(o.constructor===Date)
{var month=o.getUTCMonth()+1;if(month<10)month='0'+month;var day=o.getUTCDate();if(day<10)day='0'+day;var year=o.getUTCFullYear();var hours=o.getUTCHours();if(hours<10)hours='0'+hours;var minutes=o.getUTCMinutes();if(minutes<10)minutes='0'+minutes;var seconds=o.getUTCSeconds();if(seconds<10)seconds='0'+seconds;var milli=o.getUTCMilliseconds();if(milli<100)milli='0'+milli;if(milli<10)milli='0'+milli;return'"'+year+'-'+month+'-'+day+'T'+
hours+':'+minutes+':'+seconds+'.'+milli+'Z"';}
if(o.constructor===Array)
{var ret=[];for(var i=0;i<o.length;i++)
ret.push($.toJSON(o[i])||"null");return"["+ret.join(",")+"]";}
var pairs=[];for(var k in o){var name;var type=typeof k;if(type=="number")
name='"'+k+'"';else if(type=="string")
name=$.quoteString(k);else
continue;if(typeof o[k]=="function")
continue;var val=$.toJSON(o[k]);pairs.push(name+":"+val);}
return"{"+pairs.join(", ")+"}";}};$.evalJSON=function(src)
{if(typeof(JSON)=='object'&&JSON.parse)
return JSON.parse(src);return eval("("+src+")");};$.secureEvalJSON=function(src)
{if(typeof(JSON)=='object'&&JSON.parse)
return JSON.parse(src);var filtered=src;filtered=filtered.replace(/\\["\\\/bfnrtu]/g,'@');filtered=filtered.replace(/"[^"\\\n\r]*"|true|false|null|-?\d+(?:\.\d*)?(?:[eE][+\-]?\d+)?/g,']');filtered=filtered.replace(/(?:^|:|,)(?:\s*\[)+/g,'');if(/^[\],:{}\s]*$/.test(filtered))
return eval("("+src+")");else
throw new SyntaxError("Error parsing JSON, source is not valid.");};$.quoteString=function(string)
{if(string.match(_escapeable))
{return'"'+string.replace(_escapeable,function(a)
{var c=_meta[a];if(typeof c==='string')return c;c=a.charCodeAt();return'\\u00'+Math.floor(c/16).toString(16)+(c%16).toString(16);})+'"';}
return'"'+string+'"';};var _escapeable=/["\\\x00-\x1f\x7f-\x9f]/g;var _meta={'\b':'\\b','\t':'\\t','\n':'\\n','\f':'\\f','\r':'\\r','"':'\\"','\\':'\\\\'};})(jQuery);






////////////////ここまでライブラリ///////////core order libs//////////

function object(o) {
var f = object.f, i, len, n, prop;
f.prototype = o;
n = new f;
for (i=1, len=arguments.length; i<len; ++i)
for (prop in arguments[i])
n[prop] = arguments[i][prop];
return n;
}
object.f = function(){};
var r9_start = function(start_folder, global){
var libs = object(r9.Libs);
global["libs"] = libs;
var game = object(r9.Game);
global["game"] = game;
var title = object(r9.Title);
global["game"].titleObj = title;
if (start_folder === "game_maker") {
}
else {
title.init(start_folder);
}
global["flag_apri"] = false;
$("script").each(function(){
if($(this).attr("src")){
if($(this).attr("src").indexOf("cordova")!=-1){
global["flag_apri"] = true;
}
}
});
}
var r9 ={};
r9.define={};
r9.define.VENDER_PREFIX = (function() {
var ua = navigator.userAgent;
if (ua.indexOf('Opera') != -1) {
return 'O';
} else if (ua.indexOf('MSIE') != -1) {
return 'ms';
} else if (ua.indexOf('WebKit') != -1) {
return 'webkit';
} else if (navigator.product == 'Gecko') {
return 'Moz';
} else {
return '';
}
})();
r9.define.ENVIRONMENT = (function(){
var ua = navigator.userAgent;
if(ua.indexOf('iPhone') > -1){
return 'iphone';
}else if(ua.indexOf('iPad') > -1){
return 'iphone';
}else if(ua.indexOf('Android') > -1 ){
return 'andoroid';
}else{
return "pc";
}
})();
function r9_path_define(r9game_folder,r9){
r9.define.MYDATA_PATH = (function(){
return "./" + r9game_folder + "/";
})();
r9.define.BACKGROUND_PATH = r9.define.MYDATA_PATH + "image/";
r9.define.CHARACTER_PATH = r9.define.MYDATA_PATH + "image/";
r9.define.SOUND_PATH = r9.define.MYDATA_PATH + "sound/";
r9.define.MUSIC_PATH = r9.define.MYDATA_PATH + "sound/";
r9.define.VIDEO_PATH = r9.define.MYDATA_PATH + "video/";
}
r9_path_define(r9game_folder,r9);
r9.define.ROOT_PATH ="";
r9.define.DISPLAY_WIDTH = 640;
r9.define.DISPLAY_HEIGHT = 390;
r9.state={};
r9.state.enable_next_order = true;
r9.state.visible_message_window = true;// メッセージウィンドウが表示されていない
r9.state.now_divergence = false;
r9.state.now_backlog	= false;
r9.state.now_skip	= false;
r9.Title = {
order:"",
vital:["バージョン","最初"],
param_map:{},
error:"",
init:function(start_folder){
this.order = start_folder;
this.param_map["タイトルファイル"] = start_folder;
var that = this;
var httpObj = jQuery.get("./"+start_folder+"/start.txt?"+Math.floor( Math.random() * 1000000 ), null,
function(obj){
var title_str = "";
if(httpObj){
if(httpObj.responseText){
title_str = httpObj.responseText;
}else{
title_str = obj;
}
}else{
title_str = obj;
}
that.createTitle(title_str);
}
);
if(httpObj.statusText ==="error"){
alert("start.txt ファイルが見つかりませんでした");
}
},
createTitle:function(title_str){
this.param_map = {};
var array = title_str.split("\n");
var error_str ="";
for (var i = 0; i < array.length; i++) {
try {
var str = libs.rmspace(array[i]);
var tmp_array = str.split("=");
var order = tmp_array[0];
var param = tmp_array[1];
this.param_map[order] = param;
}catch(e){
error_str +="";
}
}
libs.checkParam(this);
if(this.error !=""){
alert(this.error);
alert("実行を中止します");
return false;
}
if(r9_game_mode === "preview"){
this.param_map["最初"] = r9_story_file;
}
$("#background_panel").attr("src",r9.define.BACKGROUND_PATH + this.param_map["背景"]);
game.current_background = this.param_map["背景"];
var array_select_element = [];
var that = this;
var start_menu = {"START":"","LOAD":""};
var num = 230;
for (select_str in start_menu) {
(function(){
var element ={};
if(select_str ==="START"){
element = $("<div style='display:none;cursor:pointer;left:220px;top:" + num + "px;position:absolute;' ><img width='200px' class='btn' src='./system/images/start.png' /></div>");
}else{
element = $("<div style='display:none;cursor:pointer;left:220px;top:" + num + "px;position:absolute;' ><img width='200px' class='btn' src='./system/images/load.png' /></div>");
}
var that_select = select_str;
element.click(function(ev){
if (ev) {
ev.stopImmediatePropagation();
}
if(that_select =="START"){
var s_file = that.param_map["最初"];
game.init(s_file);
for (var i = 0; i < array_select_element.length; i++) {
array_select_element[i].hide("slow");
}
element.unbind();
}else if(that_select =="LOAD"){
var save = object(r9.Save);
save.showSaveDialog("load");
for (var i = 0; i < array_select_element.length; i++) {
array_select_element[i].hide("slow");
}
element.unbind();
}
});
element.appendTo("#contents_panel");
array_select_element.push(element);
element.show("normal");
})();
num += 65;
}
var title_element = $("<div style='color:white;text-align:center;padding:5px;font-size:20px;left:100px;top:150px;width:400px;position:relative;font-weight:bold;text-shadow: black 1px 1px 1px;' >" + this.param_map["タイトル"] + "</div>");
title_element.appendTo("#contents_panel");
array_select_element.push(title_element);
if(this.param_map["音楽"]){
$("#noveljs").mouseover(function(ev){
$("#noveljs").unbind();
sound_swf = libs.swfName("externalnovelsound");
sound_swf.playMusic(r9.define.MUSIC_PATH + that.param_map["音楽"],99999);
game.current_music = that.param_map["音楽"];
}
);
}
if(r9_game_mode == "comment"){
var that = this;
$("#noveljs").mouseover(function(ev){
if(window.r9comment){
return false;
}
window.r9comment ={};
that.getComment(that.param_map["最初"]);
});
}else{
var cmobj = object(r9.Comment);
cmobj.state = false;
window["r9comment"] = cmobj;
}
if(this.param_map["ノベル"]){
if(this.param_map["ノベル"]==="はい"){
game.config.TEXT_MODE = "novel";
$("#text_panel").css("height",370).css("top",10).css("width",600);
$("#message_inner_panel").css("height",370).css("top",20).css("width",570).css("left",30);
$("#story_text").css("padding-right",15).css("line-height","25px");
}
}
if(r9.define.ENVIRONMENT =="iphone" || r9.define.ENVIRONMENT == "andoroid"){
this.fitBaseSize();
$(window).bind("load orientationchange resize",function(){
if(Math.abs(window.orientation) === 90){
if(window.pageYOffset===0){window.scrollTo(0,1);}
that.fitBaseSize();
}
else{
if (window.pageYOffset === 0) { window.scrollTo(0,1); }
that.fitBaseSize();
}
});
}
game.base = this.param_map;
game.base.r9game_folder= this.order;
},
fitBaseSize:function(){
var width  = parseInt($("#noveljs").css("width"));
var height = parseInt($("#noveljs").css("height"));
var view_width = libs.getViewPort().width;
var view_height = libs.getViewPort().height;
var width_f = view_width / width ;
var height_f = view_height / height;
var scale_f = 0;
$("#noveljs").css("-webkit-transform-origin","0 0");
var space_width = 0;
if(width_f > height_f){
scale_f = height_f;
}else{
scale_f = width_f;
}
$("#noveljs").css("-webkit-transform","scale("+scale_f+") ");
},
getComment:function(story_file,call_back){
game.current_story_file = story_file;
if(window.query_map){}else{return;}
$.ajax({
url: "http://corokke.jp/api/comment/" + query_map["game_id"] + "/"+story_file,
data: {
tags: 'cat',
tagmode: 'any',
format: 'json'
},
dataType: 'jsonp',
jsonp: 'callback',
complete: function(){
},
success: function(data, status){
var array_comment = data["result_array"];
var cmobj = object(r9.Comment);
cmobj.init(array_comment);
window["r9comment"] = cmobj;
cmobj.check();
if(call_back){
call_back();
}
}
});
}
};
r9.Effect = {
move:function(element, from, to, effect, speed, call_back){
var t1 = new Tween(element.get(0).style,'left',effect,from,to,speed,'px');
if(call_back){
t1.onMotionFinished = call_back;
}
t1.start();
}	};
r9.Event = {
init:function(){
if (!libs.ready) {
$("#close_window_button").click(this.clickMessageCloseButton);
$("#noveljs").click(this.clickBody);
$("#noveljs").bind("selectstart",function(){return false;});
$("#noveljs").bind("mousedown",function(){return false;});
$("#save_button").click(this.clickSave);
$("#load_button").click(this.clickLoad);
$("#back_button").click(this.clickBack);
$("#skip_button").click(this.clickSkip);
$("#share_button").click(this.clickShare);
libs.ready = true;
}
},
clickMessageCloseButton: function(ev){
if (ev) {
ev.stopImmediatePropagation();
}
if (game.state.now_skip == true) {
return;
}
if (game.state.visible_message_window == true) {
$("#message_window_panel").hide();
game.state.visible_message_window = false;
}else{
$("#message_window_panel").show();
game.state.visible_message_window = true;
}
return false;
},
clickBody: function(ev){
if (game.state.visible_message_window == false) {
if(game.state.enable_next_order == false){
return false;
}
game.event.clickMessageCloseButton();
}
if (game.state.now_skip == true){
game.state.now_skip = false;
$("#skip_button").css("background-color","black");
}
game.nextOrder();
},
clickSave:function(ev){
if (ev) {
ev.stopImmediatePropagation();
}
var save = object(r9.Save);
save.showSaveDialog("save");
},
clickLoad:function(ev){
if (ev) {
ev.stopImmediatePropagation();
}
var save = object(r9.Save);
save.showSaveDialog("load");
},
clickBack:function(ev ){
if (ev) {
ev.stopImmediatePropagation();
}
var backlog = object(r9.BackLog);
backlog.showBackLog();
},
clickSkip:function(ev){
if (ev) {
ev.stopImmediatePropagation();
}
if (game.state.now_skip == false) {
game.config.TEXT_SPEED = 10;
game.state.now_skip = true;
game.nextOrder();
$("#skip_button").css("background-color","red");
}else{
game.config.TEXT_SPEED = 20;
game.state.now_skip = false;
$("#skip_button").css("background-color","black");
}
},
clickShare:function(ev){
if (ev) {
ev.stopImmediatePropagation();
}
var share = object(r9.Share);
share.showShareDialog("");
}
};
r9.BackLog = {
array_log:[],
log_index:0,
showBackLog: function(){
if(game.config.TEXT_MODE ==="novel"){
game.state.novel_current_text = $("#story_text").html();
}
game.state.now_backlog = true;
var that = this;
this.array_log = game.array_done_text;
this.log_index = game.array_done_text.length -1;
$("#stroy_text").html(this.array_log[this.log_index]);
$("#story_text").css("color","pink");
(function(){
var button_back = $('<img id="log_button_back" src="./system/images/log_back.png" style="cursor:pointer;z-index:10004;position:absolute;top:270px;left:470px" />');
var button_next = $('<img id="log_button_next" src="./system/images/log_next.png" style="display:none;cursor:pointer;z-index:10004;position:absolute;top:270px;left:510px" />');
button_back.click(function(ev){
var str = that.array_log[that.log_index];
$("#story_text").html(str);
that.log_index --;
if (ev) {
ev.stopImmediatePropagation();
}
if(that.log_index == 0){
button_back.hide();
}
button_next.show();
});
button_next.click(function(ev){
that.log_index ++;
var str = that.array_log[that.log_index];
$("#story_text").html(str);
if (ev) {
ev.stopImmediatePropagation();
}
if(that.log_index == that.array_log.length){
game.nextOrder();
}
button_back.show();
});
$("#message_window_panel").append(button_back);
$("#message_window_panel").append(button_next);
})();
}
};
r9.Save = {
array_save_original:{},
showSaveDialog:function(flag){
if(game.state)game.state.enable_next_order = true;
$("#message_window_panel").hide("normal");
this.array_save_original = this.getSaveArray();
var array_save	= (this.getSaveArray()).data;
var j_save_root  =$("<div></div>");
var j_save_panel = $('<div id="save_panel"></div>');
var flag_str ="";
if (flag == "save") {
flag_str ="セーブ";
}else{
flag_str ="ロード";
}
var j_save_title     = $('<div id="save_title">'+flag_str+'<img src="./system/images/close_button.gif" class="window_close_button" alt="閉じる" /></div>');
this.close_button = j_save_title.find(".window_close_button");
var that = this;
var j_save_list = $('<ol id="save_list"></ol>');
for (var i = 0; i < array_save.length; i++) {
var save_element = $('<li>'+libs.cutstr(array_save[i].title,20)+'<input type="button" value="'+flag_str+'する"></li>');
var button_element = save_element.find("input");
if (flag == "save") {
(function(){
var save_number = i;
var button_element_tmp = button_element;
button_element_tmp.click(function(ev){
if (ev) {
ev.stopImmediatePropagation();
}
that.exeSave(save_number);
});
})();
}else{
(function(){
if(array_save[i].save_date===""){
button_element.attr('disabled','disabled');
}
var save_number = i;
var button_element_tmp = button_element;
button_element_tmp.click(function(ev){
if (ev) {
ev.stopImmediatePropagation();
}
that.exeLoad(save_number);
});
})();
}
j_save_list.append(save_element);
}
this.close_button.click(function(ev){
if(game.current_index){
j_save_root.remove();
ev.stopImmediatePropagation();
if(game.state)game.state.enable_next_order = true;
$("#message_window_panel").show("normal");
}else{
location.reload();
}
});
j_save_root.append(j_save_panel);
j_save_root.append(j_save_title);
j_save_root.append(j_save_list);
j_save_root.appendTo("#contents_panel");
},
getSaveArray:function(){
var tmp_array = libs.getStorage(r9game_folder+"_save_"+game.base["最初"]);
if(tmp_array){
return eval("("+tmp_array+")");
}else{
tmp_array = new Array();
var root = {kind:"save"};
for(var i=0;i<5;i++){
var json ={};
json.title	= "まだ、保存されているデータがありません";
json.scene_index = 0;
json.save_date = "";
json.story_file = "";
json.background = "";
json.characters = [];
json.music	="";
tmp_array.push(json);
}
root.data = tmp_array;
return root;
}
},
exeSave:function(index){
var json = this.array_save_original.data[index];
json.title	= game.array_done_text[game.array_done_text.length-1];
json.scene_index = game.current_index -1;
json.current_row = game.current_row;
json.save_date = libs.getNowDate() +" "+ libs.getNowTime();
json.story_file = game.current_story_file ;
if(game.current_background){
json.background = game.current_background;
}
if(game.current_music){
json.music  = game.current_music;
}else{json.music = null;}
json.characters = game.character_node.getCharacterDataToSave();
json.image_objects = game.object_node.getObjectDataToSave();
json.base = game.base;
json.flag	= game.flag.map_flag;
this.array_save_original.data[index] = json;
libs.setStorage(r9game_folder+"_save_"+game.base["最初"],$.toJSON(this.array_save_original));
alert("保存しました");
this.close_button.click();
game.state.enable_next_order = true;
$("#message_window_panel").show("normal");
},
exeLoad:function(index){
$("#contents_panel").empty();
var json = this.array_save_original.data[index];
if(json.title =="まだ、保存されているデータがありません"){
alert("ロードできません。");
return false;
}
game.load(json);
this.close_button.click();
game.state.enable_next_order = true;
$("#message_window_panel").show("normal");
},
closeSave:function(){
}
};
r9.Flag = {
map_flag : {},
initFlag:function(cb){
var that = this;
$.ajax({
type:"GET",
url: "./"+r9game_folder+"/flag.txt?"+Math.floor( Math.random() * 1000000) ,
dataType: 'text',
error: function(){
if(typeof cb =="function"){
cb();
}
},
success: function(data, status){
var flag_str = ""+data;
that.map_flag = libs.createParamObject(flag_str);
if(typeof cb =="function"){
cb();
}
}
});
},
getFlag:function(key){
if(this.map_flag[key]){
return this.map_flag[key];
}else{
alert("エラー：フラグが見つかりません");
}	},
setFlag:function(key,value){
this.map_flag[key] = value;
},
clearFlag:function(){
this.initFlag();
}
};
r9.Share = {
array_save_original:{},
showShareDialog:function(flag){
$("#noveljs").unbind("selectstart");
$("#noveljs").unbind("mousedown");
if(game.state)game.state.enable_next_order = false;
$("#message_window_panel").hide("normal");
var outer_element = $("<div style='font-size:12px;width:430px;height:280px;padding:3px;z-index:10002;position:absolute;top:50px;left:100px;background-color:#F8F3D2;border:solid 1px gray'></div>");
var close_button = $('<img id="close_window_button" src="./system/images/close_button.gif" style="z-index:10003;cursor:pointer;top:10px;left:395px;width:25px;height:25px;background-color:black;position:absolute;" >');
this.close_button = close_button;
var share_element = $("<div style='font-size:20px'>シェアする</div>");
outer_element.append(share_element);
var that = this;
var share_code = '<iframe src="'+document.URL+'" frameborder="0" scrolling="no" width="640px" height="390px" style="border:solid 1px gray"></iframe>';
var html ="<div style='font-size:12px;'><br />以下のコードを貼り付けることで<br />このゲームをあなたのサイトで表示することができます。<br />";
html+="<textarea  rows='6' onSelectStart = '' onMouseDown = '' onclick='this.focus();this.select();' style='width:300px;font-size:12px'>";
html+=share_code;
html+="</textarea>";
html+="</div><br /><br />";
var button_go_title = $("<input type='button' value='タイトルに戻る' />");
share_element.append($(html));
share_element.append(close_button);
share_element.append(button_go_title);
share_element.append($("<div style='clear:both'></div>"));
outer_element.append(share_element);
close_button.click(function(ev){
outer_element.remove();
ev.stopImmediatePropagation();
if(game.state)game.state.enable_next_order = true;
$("#message_window_panel").show("normal");
$("#noveljs").bind("selectstart",function(){return false;});
$("#noveljs").bind("mousedown",function(){return false;});
});
button_go_title.click(function(ev){
ev.stopImmediatePropagation();
if(game.state)game.state.enable_next_order = true;
var end_order = object(r9.order.Jump);
end_order.init({"行き先":"タイトル"});
end_order.start();
$("#noveljs").bind("selectstart",function(){return false;});
$("#noveljs").bind("mousedown",function(){return false;});
return false;
});
outer_element.append(close_button);
outer_element.appendTo("#contents_panel");
}
};
r9.FileManager = {
name: "動物",
load: function(start_file,cal_func){
var story_path = "";
if (start_file == "game_maker") {
var text_game_folder = $("#text_game_folder").val();
r9_path_define(text_game_folder, r9);
var order_str = $("#textarea_story").val();
game.character_node.clear();
game.object_node.clear();
$("#story_text").html("");
cal_func(order_str);
if($("#check_novel").get(0).checked == true){
game.config.TEXT_MODE = "novel";
$("#text_panel").css("height",370).css("top",10).css("width",600);
$("#message_inner_panel").css("height",370).css("top",20).css("width",570).css("left",30);
$("#story_text").css("padding-right",15).css("line-height","25px");
}else{
$("#text_panel").css("height",110).css("top",260).css("width",640);
$("#message_inner_panel").css("height",140).css("top",260).css("width",520).css("left",45);
}
}
else {
var httpObj = jQuery.get(r9.define.MYDATA_PATH + "story/" + start_file + "?" + Math.floor(Math.random() * 1000000), null, function(obj){
var order_str = "";
if (httpObj) {
if (httpObj.responseText) {
order_str = httpObj.responseText;
}
else {
order_str = obj;
}
}
else {
order_str = obj;
}
cal_func(order_str);
});
if (httpObj.statusText === "error") {
alert("ファイルが見つかりませんでした");
}
}
},
compile:function(order_str){
var array_order=[];
var order_list = {};
var comment_state = false;
for(var order_type in r9.order){
order_list[r9.order[order_type].order] = r9.order[order_type];
}
var array = order_str.split("\n");
var error_str ="";
for(var i=0;i<array.length;i++){
try{
var original_str = array[i];
var str = libs.rmspace(array[i]);
if(str != "" && comment_state == false){
var first_one = str.substr(0,1);
if(first_one =="#"){
var tmp_str = str.substr(1,str.length);
var tmp_array = tmp_str.split(":");
var order = tmp_array[0];
var param = tmp_array[1];
var tmp_array_param = param.split(",");
var param_map ={};
for(var j=0;j<tmp_array_param.length;j++){
var kv_str = tmp_array_param[j].split("=");
var key = kv_str[0];
var val="";
if(key==="ソース"){
val = this.getSource(array[i]);
}else{
val = kv_str[1];
}
param_map[key] = val;
}
if(order_list[order]){
var order_obj = object(order_list[order]);
order_obj.row = i;
order_obj.init(param_map);
order_obj.order_str = original_str;
if(order_obj.error != ""){
error_str += libs.error(i,order_obj.error);
}else{
array_order.push(order_obj);
}
}else{
error_str = libs.error(i,order+"　という命令は存在しません。");
}
}else if(first_one =="/"){
if(str.length > 1){
var two = str.substr(1,2);
if(two =="*"){
comment_state = true;
}
}
}else if(first_one =="@"){
var param_map={};
param_map["名前"] = str.replace("@","");
var order_obj = object(r9.order.Name);
order_obj.init(param_map);
order_obj.order_str = original_str;
if(order_obj.error != ""){
error_str += libs.error(i,order_obj.error);
}else{
array_order.push(order_obj);
}
}else if(first_one ==">"){
var mark_name = str.replace(">","");
if(mark_name !=""){
if(game.mark[mark_name]){
error_str += libs.error(i,mark_name+"はすでに定義済みのマークです。重複して定義することはできません。");
}else{
game.mark[mark_name] = array_order.length;
}
}
}else {
var param_map={};
param_map["内容"] = array[i];
var order_obj = object(r9.order.Text);
order_obj.row = i;
order_obj.init(param_map);
order_obj.order_str = original_str;
if(order_obj.error != ""){
error_str += libs.error(i,order_obj.error);
}else{
array_order.push(order_obj);
}
}
}else{
if(str.length > 1){
var one = str.substring(0,2);
if(one=="*/"){
comment_state = false;
}
}
}
}catch(e){
console.log(e);
error_str += (i+1)+"行目に未知数のエラー\n";
}
}
var result = {"error":error_str,"array_order":array_order}
return result;
},
getSource:function(str){
var pos = parseInt(str.indexOf("("));
var pos2 = parseInt(str.lastIndexOf(")"));
var source_str = str.substring(pos+1,pos2);
return source_str;
},
sayName: function(){
alert(this.name);
}
};
r9.CharacterNode = {
chara_num:0,
total_num:0,
array_chara:[],
init:function(){
},
add:function(obj){
this.chara_num++;
this.total_num++;
obj.id = "chara_"+this.total_num;
obj.position = 300;
obj.element = $("<div style='width:300px;height:400px;position:absolute;left:0px;top:0px;'><img src='"+r9.define.CHARACTER_PATH + obj.image+"' style='' /></div>");
obj.element.attr("id",obj.id);
obj.element.appendTo("#contents_panel");
this.array_chara.push(obj);
this.setPositionAuto();
},
setPositionAuto:function(){
var position_left = Math.floor(r9.define.DISPLAY_WIDTH / (parseInt(this.array_chara.length)+1));
var sum_position = position_left;
for(var i=0;i<this.array_chara.length;i++){
var obj = this.array_chara[i];
var new_position = sum_position - 150;
sum_position +=position_left;
game.effect.move(obj.element,obj.position,new_position,Tween.strongEaseOut,1);
this.array_chara[i].position = new_position;
}
},
move:function(){
},
getObjectByName:function(name){
for(var i=0;i<this.array_chara.length;i++){
var obj = this.array_chara[i];
if(obj.name == name){
return obj;
}
}
return null;
},
getCharacterDataToSave:function(){
var array = [];
for(var i=0;i<this.array_chara.length;i++){
var obj = {};
obj.name = this.array_chara[i].name;
obj.image = this.array_chara[i].image;
array.push(obj);
}
return array;
},
remove:function(obj){
if(obj.name =="全員"){
for(var i=0;i<this.array_chara.length;i++){
var tmp = this.array_chara[i];
var element = this.array_chara[i].element;
element.hide("fast");
element.remove();
}
for(var i=0;this.array_chara.length;i++){
this.array_chara.splice(0,1);
}
this.setPositionAuto();
return;
}
for(var i=0;i<this.array_chara.length;i++){
var tmp = this.array_chara[i];
if(tmp.name == obj.name){
var element = this.array_chara[i].element;
this.array_chara.splice(i,1);
element.hide("fast");
element.remove();
this.setPositionAuto();
}
}
},
clear:function(){
for(var i=0;i<this.array_chara.length;i++){
var tmp = this.array_chara[i];
var element = this.array_chara[i].element;
element.hide("fast");
element.remove();
}
for(var i=0;this.array_chara.length;i++){
this.array_chara.splice(0,1);
}
this.setPositionAuto();
return;
},
setState:function(obj){
var target_obj = this.getObjectByName(obj.name);
if(target_obj){
}else{
game.state.enable_next_order = true;
return true;
}
if(obj.comp_wait=="はい"){
game.state.enable_next_order = false;
}
var element = target_obj.element;
var image_obj = element.find('img');
if(obj.image){
image_obj.attr("src",r9.define.CHARACTER_PATH + obj.image);
}
if(obj.new_position){
var move_speed = 1;
if(obj.move_speed){
move_speed = obj.move_speed;
}
if(obj.comp_wait){
if(obj.comp_wait =="はい"){
game.effect.move(target_obj.element,target_obj.position,obj.new_position,Tween.strongEaseOut,move_speed,(function(){game.state.enable_next_order = true; game.nextOrder();}));
}else{
game.effect.move(target_obj.element,target_obj.position,obj.new_position,Tween.strongEaseOut,move_speed);
}
}
target_obj.position = parseInt(obj.new_position);
}
}
};
r9.ObjectNode = {
object_num:0,
total_num:0,
array_object:[],
init:function(){
},
add:function(obj){
var element = this.getObjectByName(obj.name);
if(element){
if(obj.top)element.top=obj.top;
if(obj.left)element.left=obj.left;
element.empty();
element.append($(obj.src_str));
}else{
this.object_num++;
this.total_num++;
obj.id = "object_"+this.total_num;
obj.element = $(obj.src_str);
if(obj.top)obj.element.css("top",obj.top);
if(obj.left)obj.element.css("left",obj.left);
if(obj.width)obj.element.css("width",obj.width);
if(obj.height)obj.element.css("height",obj.height);
obj.element.css("position","absolute");
obj.element.attr("id",obj.id);
obj.element.appendTo("#contents_panel");
this.array_object.push(obj);
}
},
getObjectByName:function(name){
for(var i=0;i<this.array_object.length;i++){
var obj = this.array_object[i];
if(obj.name == name){
return obj;
}
}
return null;
},
getObjectDataToSave:function(){
var array = [];
for(var i=0;i<this.array_object.length;i++){
var obj = {};
var tmp = this.array_object[i];
obj.height = tmp.height || "";
obj.width = tmp.width || "";
obj.image = tmp.image || "";
obj.left = tmp.left || "";
obj.top = tmp.top || "";
obj.name = tmp.name || "";
obj.src_str = tmp.src_str ||"";
array.push(obj);
}
return array;
},
remove:function(obj){
if(obj.name =="全部"){
for(var i=0;i<this.array_object.length;i++){
var tmp = this.array_object[i];
var element = this.array_object[i].element;
element.hide("fast");
element.remove();
}
for(var i=0;this.array_object.length;i++){
this.array_object.splice(0,1);
}
return;
}
for(var i=0;i<this.array_object.length;i++){
var tmp = this.array_object[i];
if(tmp.name == obj.name){
var element = this.array_object[i].element;
this.array_object.splice(i,1);
element.hide("fast");
element.remove();
}
}
},
clear:function(){
for(var i=0;i<this.array_object.length;i++){
var tmp = this.array_object[i];
var element = this.array_object[i].element;
element.hide("fast");
element.remove();
}
for(var i=0;this.array_object.length;i++){
this.array_object.splice(0,1);
}
return;
},
setState:function(obj){
var target_obj = this.getObjectByName(obj.name);
if(target_obj){
}else{
game.state.enable_next_order = true;
return true;
}
if(obj.comp_wait=="はい"){
game.state.enable_next_order = false;
}
var element = target_obj.element;
var image_obj = element.find('img');
if(obj.image){
image_obj.attr("src",r9.define.CHARACTER_PATH + obj.image);
}
if(obj.new_position){
var move_speed = 1;
if(obj.move_speed){
move_speed = obj.move_speed;
}
if(obj.comp_wait){
if(obj.comp_wait =="はい"){
game.effect.move(target_obj.element,target_obj.position,obj.new_position,Tween.strongEaseOut,move_speed,(function(){game.state.enable_next_order = true; game.nextOrder();}));
}else{
game.effect.move(target_obj.element,target_obj.position,obj.new_position,Tween.strongEaseOut,move_speed);
}
}
target_obj.position = parseInt(obj.new_position);
}
}
};
r9.PreLoader = {
array_image_path:[],
comp_num:0,
obj:{},
error_str:"",
check:function(obj){
var param_map = obj.param_map;
if(param_map["画像"]){
var image_obj = {};
image_obj.row = obj.row;
image_obj.path = obj.image_path + param_map["画像"];
this.add(image_obj);
}
},
add:function(image_obj){
this.array_image_path.push(image_obj);
},
load:function(){
var that = this;
if (this.array_image_path.length <= 0) {
game.ready();
return;
}
for(var i=0; i<this.array_image_path.length; i++){
var image_obj = this.array_image_path[i];
var src= image_obj.path;
var row = image_obj.row;
(function(src,row){
$('<img />').attr('src', src).load(function(e){
that.complete();
}).error(function(e){
game.error += libs.error(row,"指定された画像["+src+"]が見つかりません");
that.complete();
});
})(src,row);
}
},
clear:function(){
for(var i=0;this.array_image_path.length;i++){
this.array_image_path.splice(0,1);
}
},
complete:function(){
this.comp_num++;
if(this.comp_num == this.array_image_path.length){
game.ready();// 最終準備完了
}
}
};
r9.Comment ={
comment_index:0,
state: false,
array_comment:[],
top_pos : 20,
comment_enable : true,
init:function(array){
$("#comment_area").empty();
$("#comment_title_area").empty();
this.array_comment = array;
this.state = true;
var comment_box = $("<input id='comment_text' type='text' style='width:400px;height:30px;font-size:20px;border:solid 1px black;margin-left:5px;' />");
var comment_button = $("<input type='button' value='コメント' style='width:80px;height:30px' />");
var comment_enable = $("<img src='./system/images/comment_on.png' style='width:35px;height:35px;cursor:pointer;float:right' title='コメント表示・非表示を切り替え' />");
comment_enable.click(
function(event){
if(r9comment.comment_enable == true){
r9comment.comment_enable = false;
comment_enable.attr("src","./system/images/comment_off.png");
}else{
r9comment.comment_enable = true;
comment_enable.attr("src","./system/images/comment_on.png");
}
}
);
comment_box.keypress(function(event){
if(event.keyCode == 13){comment_button.click();}
});
comment_button.click(function(ev){
var str = libs.trim($("#comment_text").val());
var order_index = 0;
if(str ==="") {
return false;
}
if(game.current_row){
order_index = game.current_row;
}else{
}
$("#comment_text").val("");
$.ajax({
url: "http://corokke.jp/api/comment_add/",
data: {
tags: 'cat',
tagmode: 'any',
format: 'json',
game_id:query_map["game_id"],
str:str,
story_file:game.current_story_file,
order_index:order_index
},
dataType: 'jsonp',
jsonp: 'callback',
complete: function(){
},
success: function(data, status){
var cmid = "cm_test";
var com_obj = $("<div id='"+cmid+"' style='width:1000px;position:absolute;top:20px;color:white;font-size:24px;font-weight:bold;text-shadow: black 1px 1px 1px;color:yellow'>"+ libs.h(str) +"</div>");
$("#contents_panel").append(com_obj);
var speed = 6;
var t1 = new Tween(com_obj.get(0).style,'left',Tween.regularEaseIn,640,-300,speed,'px');
(function(that){
var tmp_cmid = cmid;
t1.onMotionFinished = function(){
var elm_id = "#"+tmp_cmid;
$(elm_id).remove();
that.top_pos = 20;
};
})(this);
t1.start();
}
});
}
);
$("#comment_area").append(comment_box);
$("#comment_area").append(comment_button);
$("#comment_area").append(comment_enable);
$("#comment_title_area").html("好きなタイミングにコメントを流すことができます");
},
load_reset:function(){
var index = game.current_row;
this.comment_index = 0;
for(var i=this.comment_index;i<this.array_comment.length;i++){
if(this.array_comment[i].order_index >= index){
this.comment_index = i;
break;
}
}
},
check:function(obj){
if(this.state == false){
return;
}
var index = 0;
if(game.current_row){
index = game.current_row;
}else{
index = 0;
}
if(this.array_comment.length < 1){
return false;
}
if(this.array_comment[this.comment_index]){
}else{
return false;
}
for(var i=this.comment_index;i<this.array_comment.length;i++){
if(this.array_comment[i].order_index <= index){
this.comment_index = i;
var cmid = "cm"+i+"";
var comment_str = this.array_comment[i].comment;
if(this.comment_enable == false){
comment_str ="";
}
var com_obj = $("<div id='"+cmid+"' style='z-index:99999;width:1000px;position:absolute;top:"+this.top_pos+"px;color:white;font-size:24px;font-weight:bold;text-shadow: black 0px -1px, black 1px 0px, black 0px 1px, black -1px 0px;'>"+ libs.h(comment_str) +"</div>");
$("#contents_panel").append(com_obj);
var lm = comment_str.length;
var speed = 6;
var first_pos = 640;
var randnum = Math.floor( Math.random() * 100 );
first_pos += randnum;
if(lm > 7){
speed = 5;
}else if(lm > 14){
speed = 4.5;
}else if(lm > 20){
speed = 4;
}else if(lm > 28){
speed = 3;
}
var t1 = new Tween(com_obj.get(0).style,'left',Tween.regularEaseIn,first_pos,-300,speed,'px');
(function(that){
var tmp_cmid = cmid;
t1.onMotionFinished = function(){
var elm_id = "#"+tmp_cmid;
$(elm_id).remove();
that.top_pos = 20;
};
})(this);
t1.start();
this.top_pos += 25;
if(this.top_pos > 400){
this.top_pos = 20;
}
if(i+1 >= this.array_comment.length){
this.comment_index = i+2;
}else{
this.comment_index = i;
}
}else{
this.comment_index = i;
break;
}
}
}	};
r9.Game = {
config:{
TEXT_SPEED:20,
TEXT_MODE:"default",
test:"wwww"
},
error:"",// 構文解析のエラーが集約
init:function(start_file){
$("#loading_image").css("display","");
this.current_index = 0;
this.array_done_text = [];
this.current_story_file = start_file;
this.array_audio = new Array();
this.error = "";
this.mark = new Object();
this.fm = object(r9.FileManager);
this.preloader = object(r9.PreLoader);
this.character_node = object(r9.CharacterNode);
this.object_node    = object(r9.ObjectNode);
this.effect = object(r9.Effect);
this.state = object(r9.state);
this.sound_swf = libs.swfName("externalnovelsound");
this.audio_obj = null;
this.event     = object(r9.Event);
this.event.init();
var that = this;
var call_back = that;
if(this.flag){
that.fm.load(start_file,function(result_str){call_back.createOrder.call(call_back,result_str)});
}else{
this.flag   = object(r9.Flag);
this.flag.initFlag(function(){that.fm.load(start_file,function(result_str){call_back.createOrder.call(call_back,result_str)});});
}
},
jump:function(start_file){
if (r9_game_mode == "comment") {
game.titleObj.getComment(start_file);
}
game.current_row = 0;
game.init(start_file);
},
load:function(json){
this.load_obj = json;
game.init(json.story_file);
},
createOrder:function(order_str){
this.order_str = order_str;
var result_compile = this.fm.compile(order_str);
if(result_compile.error !=""){
game.error += result_compile.error;
}
this.array_order = result_compile.array_order;
if (r9.define.VENDER_PREFIX != "ms") {
game.preloader.load();
}else{
game.ready();
}
},
ready:function(){
if(game.error !=""){
if(game.base["モード"] && game.base["モード"]==="リリース"){
}else{
alert("【エラーが見つかりました：デバッグモード】\n"+game.error);
}
}
if(game.load_obj){
json = game.load_obj;
game.current_index = json.scene_index;
game.current_story_file = json.story_file;
game.current_background = json.background;
game.current_music      = json.music;
game.current_row	= json.current_row;
game.flag.map_flag = json.flag;
game.titleObj.getComment(json.story_file,function(){
r9comment.load_reset();
});
if(game.current_background != ""){
$("#background_panel").attr("src",r9.define.BACKGROUND_PATH + game.current_background);
}
if(r9.define.ENVIRONMENT =="iphone" || r9.define.ENVIRONMENT == "andoroid"  || r9.define.VENDER_PREFIX !="Moz"){
//ロードの時に再生する
if(game.current_music){
this.audio_obj = new Audio(r9.define.MUSIC_PATH + game.current_music);
this.audio_obj.play();
game.array_audio.push(this.audio_obj);
}
}else{
try{
if(game.current_music){
game.sound_swf.playMusic(r9.define.MUSIC_PATH + game.current_music,99999);
}else{
game.sound_swf.stopMusic();
}
}catch(e){
if(game.base["モード"]==="デバッグ"){
alert("音楽再生でエラー");
}
}
}
game.base = json.base;
game.character_node.clear()
for(var i=0;i<json.characters.length;i++){
game.character_node.add(json.characters[i]);
}
game.object_node.clear()
for(var i=0;i<json.image_objects.length;i++){
game.object_node.add(json.image_objects[i]);
}
$("#story_text").html(json.title);
game.load_obj = null;
}
if(game.base["セーブ"]){
if(game.base["セーブ"]==="いいえ"){
$("#save_button").hide();
$("#load_button").hide();
}
}
if(game.base["シェア"]){
if(game.base["シェア"]==="いいえ"){
$("#share_button").hide();
}
}
$("#message_window_panel").show("normal");
$("#loading_image").css("display","none");
game.nextOrder();
},
nextOrder:function(){
if(game.state.now_divergence == true){
return false;
}
if (game.state.enable_next_order == false) {
return false;
}
if (game.state.now_backlog == true){
$("#log_button_back").remove();
$("#log_button_next").remove();
$("#story_text").css("color","white");
game.state.now_backlog = false;
$("#story_text").html(game.state.novel_current_text);
}
var index = this.current_index;
if(index>10){
}
this.current_index++;
if(this.array_order[index]){
}else{
location.reload();
return;
var end_order = object(r9.order.Jump);
end_order.init({"行き先":"タイトル"});
end_order.start();
return false;
}
if(this.array_order){
}else{
return false;
}
try{
this.array_order[index].start();
if(this.array_order[index].row){
this.current_row = this.array_order[index].row;
}
}catch(e){
if(game.base["モード"]==="デバッグ"){
alert(libs.error("実行",e));
}
}
if(r9game_folder ==="game_maker"){
var obj ={current:"",next:"",next2:""};
if(this.array_order[index-1])obj.current = this.array_order[index-1].order_str;
if(this.array_order[index])obj.next = this.array_order[index].order_str;
if(this.array_order[index+1])obj.next2 = this.array_order[index+1].order_str;
game_maker.debugOrder(obj);
}else{
r9comment.check();
}
},
func:function(){
}
};
if (AC_FL_RunContent == 0) {
alert("このページでは \"AC_RunActiveContent.js\" が必要です。");
} else {
AC_FL_RunContent(
'codebase', 'http://download.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=9,0,0,0',
'width', '1',
'height', '1',
'style','position:absolute',
'src', 'novel_sound',
'quality', 'high',
'pluginspage', 'http://www.macromedia.com/go/getflashplayer',
'align', 'middle',
'play', 'true',
'loop', 'true',
'scale', 'showall',
'wmode', 'window',
'devicefont', 'false',
'id', 'externalnovelsound',
'bgcolor', '#ffffff',
'name', 'externalnovelsound',
'menu', 'true',
'allowFullScreen', 'false',
'allowScriptAccess','always',
'movie', 'novel_sound',
'salign', ''
);
}
$(window).load(function(){
r9_start(r9game_folder,window);
});
r9.order ={};
r9.order.Text = {
order:"文章",
vital:["内容"],//必須項目
pm:["色","サイズ","フォント","スピード","ボイス"],
error:"",
param_map:{},
text_color:"white",
text_size:"",
text_font:"",
voice:"",
text:"",	current_str:"",//表示中のテキスト
view_index:0,
text_speed : 20,
text_mode:"default",
sound_path:r9.define.SOUND_PATH,
audio_obj:{},
init:function(param_map){
var that = this;
this.text_speed = game.config.TEXT_SPEED;
this.text_mode  = game.config.TEXT_MODE;
this.param_map = param_map;
libs.checkParam(this);
if(param_map["色"])this.text_color = param_map["色"];
if(param_map["サイズ"])this.text_size = param_map["サイズ"];
if(param_map["フォント"])this.text_font = param_map["フォント"];
if(param_map["スピード"])this.text_speed = parseInt(param_map["スピード"]);
if(param_map["ボイス"])this.voice = param_map["ボイス"];
var array_voice = this.param_map["内容"].split(">>");
if(array_voice.length>1){
this.voice = libs.rmspace(array_voice[1]);
this.text = libs.esc(libs.rmspace(array_voice[0]));
if(window.flag_apri == true){
that.audio_obj = new Media(libs.getBaseURL()+""+game.base.r9game_folder+"/sound/"+ this.voice,
function(){
that.audio_obj.release();
},
function(error){
});
}
}else{
this.text = libs.esc(this.param_map["内容"]);
}
this.text = this.text.replace(/\r\n?/g,"");
},
start:function(call_back){
this.current_str ="";
this.view_index=0;
$("#story_text").css("color",this.text_color);
$("#story_text").css("font-size",this.text_size);
$("#story_text").css("font-family",this.text_font);
game.state.enable_next_order = false;
if(game.config.TEXT_MODE ==="novel"){
$("#story_text").find("#next_icon").remove();
if(this.text ===";"){
game.array_done_text.push($("#story_text").html());
$("#story_text").html("");
game.state.enable_next_order = true;
game.nextOrder();
return ;
}
if(parseInt($("#story_text").css("height").replace("px","")) > 260){
game.array_done_text.push($("#story_text").html());
$("#story_text").html("");
}
var story_text = $("#story_text").html();
this.current_str = story_text;
if(this.voice!=""){
this.playVoice();
this.putCharNovel();
}else{
this.putCharNovel();
}
}else{
if(this.voice!=""){
this.playVoice();
this.putChar();
}else{
this.putChar();
}
}
},
putChar:function(){
this.current_str += this.text.substring(this.view_index, ++this.view_index);
$("#story_text").html(this.current_str);
if (this.view_index <= this.text.length){
var that = this;
setTimeout(function(){that.putChar.call(that)},that.text_speed);
}else{
game.array_done_text.push(this.current_str);
$("#story_text").html(this.current_str + "<img src='./system/images/nextpage.gif' />");
game.state.enable_next_order = true;
}
if (game.state.now_skip == true) {
game.nextOrder();
}	},
putCharNovel:function(){
this.current_str += this.text.substring(this.view_index, ++this.view_index);
$("#story_text").html(this.current_str);
if (this.view_index <= this.text.length){
var that = this;
setTimeout(function(){that.putCharNovel.call(that)},that.text_speed);
}else{
$("#story_text").html(this.current_str + "<img id='next_icon' src='./system/images/nextpage.gif' /><br />");
game.state.enable_next_order = true;
}
if (game.state.now_skip == true) {
game.nextOrder();
}	},
playVoice:function(cb){
if(window.flag_apri == true){
libs.play_audio(this.audio_obj);
}else if(r9.define.ENVIRONMENT == "iphone" || r9.define.ENVIRONMENT == "andoroid" || r9.define.VENDER_PREFIX !="Moz"){

this.audio_obj = new Audio(this.sound_path + this.param_map["ボイス"]);
this.audio_obj.load();
}
this.sound_path = r9.define.SOUND_PATH;
var file ="",
repeat=1;
file = this.voice;
if(r9.define.ENVIRONMENT =="iphone" || r9.define.ENVIRONMENT == "andoroid" || r9.define.VENDER_PREFIX !="Moz"){
if(file=="停止"){
this.audio_obj.pause();
}else{
if(repeat == 99999){
this.audio_obj.loop = true;
}

this.audio_obj.play();
}
}else{
game.sound_swf.playSound(this.sound_path + file,repeat);
}
}
};
r9.order.BackgroundImage = {
order:"背景",
vital:["画像"],//必須項目
pm:["効果","速度"],
error:"",
param_map:{},
image_path:r9.define.BACKGROUND_PATH,
init:function(param_map){
this.image_path = r9.define.BACKGROUND_PATH;
this.param_map = param_map;
libs.checkParam(this);
game.preloader.check(this);
},
start:function(call_back){
var that = this;
game.state.enable_next_order = false;
$("#background_panel_sub").unbind("load");
$("#background_panel").unbind("load");
$("#background_panel_sub").unbind("ready");
$("#background_panel").unbind("ready");
if(r9.define.ENVIRONMENT == "iphone" || r9.define.ENVIRONMENT == "andoroid" || r9.define.VENDER_PREFIX == "ms"){
$("#background_panel_sub").attr("src",$("#background_panel").attr("src")).ready(
function(){
that.setImage(that);
}	);
}else{
$("#background_panel_sub").attr("src",$("#background_panel").attr("src")).load(
function(){
that.setImage(that);
}	);
}
game.current_background = this.param_map["画像"];
},
setImage:function(that){
$("#background_panel_sub").css("display","");
if(r9.define.ENVIRONMENT == "iphone" || r9.define.ENVIRONMENT == "andoroid" || r9.define.VENDER_PREFIX == "ms"){
$("#background_panel").attr("src",that.image_path + that.param_map["画像"]).ready(
function(){
that.setImageEffect(that);
}
);
}else{
$("#background_panel").attr("src",that.image_path + that.param_map["画像"]).load(
function(){
that.setImageEffect(that);
}
);
}
},
setImageEffect:function(that){
$("#background_panel").css("display","none");
var effect ="ノーマル",
speed=2;
if(that.param_map["効果"])effect = that.param_map["効果"];
if(that.param_map["速度"])speed = that.param_map["速度"];
speed = speed * 1000;
if(effect =="ズーム"){
$("#background_panel").animate( { opacity: 'show'}, { duration: speed, easing: 'swing' } );
$("#background_panel_sub").animate( { width: '200%',height: '200%',left:'-300',top:'-300',opacity: 'hide'}, { duration: speed, easing: 'swing',
complete:
function(){
$("#background_panel_sub").css("width","640px").css("height","390px").css("left",0).css("top",0);
game.state.enable_next_order = true;
game.nextOrder();
}
} );
}else if(effect =="スライド" || effect =="左スライド"　|| effect =="右スライド"){
if(effect =="右スライド"){
$("#background_panel_sub").animate( {opacity: 'hide',left:'600'}, { duration: speed, easing: 'linear', } )
}else{
$("#background_panel_sub").animate( {opacity: 'hide',left:'-600'}, { duration: speed, easing: 'linear', } )
}
$("#background_panel").animate( { opacity: 'show'}, { duration: 0, easing: 'linear' } );
$("#background_panel_sub").animate( {opacity: 'hide',left:'-600'}, { duration: speed, easing: 'linear',
complete:
function(){
$("#background_panel_sub").css("width","640px").css("height","390px").css("left",0).css("top",0);
game.state.enable_next_order = true;
game.nextOrder();
}
} );
}else if(effect =="フォーカス"){
$("#background_panel_sub").animate( {opacity: 'hide'}, { duration: 1, easing: 'linear'});
$("#background_panel").animate( { width: '300%',height: '300%',left:'-100',top:'-150',opacity: 'show'}, { duration: 1, easing: 'swing' } );
$("#background_panel").animate( { width: '640px',height: '390px',left:'0',top:'0'}, { duration: speed, easing: 'swing',
complete:
function(){
$("#background_panel_sub").css("width","640px").css("height","390px").css("left",0).css("top",0);
game.state.enable_next_order = true;
game.nextOrder();
}
} );
}else{
$("#background_panel").animate( { opacity: 'show'}, { duration: speed, easing: 'swing' } )
$("#background_panel_sub").animate( { opacity: 'hide'}, { duration: speed, easing: 'swing',
complete:
function(){
game.state.enable_next_order = true;
game.nextOrder();
}
} );
}
}
};
r9.order.CharacterAdd = {
order:"キャラ登場",
vital:["名前","画像"],//必須項目
pm:[],
error:"",
param_map:{},
image_path:r9.define.CHARACTER_PATH,
init:function(param_map){
this.image_path = r9.define.CHARACTER_PATH;
this.param_map = param_map;
libs.checkParam(this);
this.character_node = game.character_node;
game.preloader.check(this);
},
start:function(call_back){
var obj = {};
if(this.param_map["名前"])obj.name = this.param_map["名前"];
if(this.param_map["画像"])obj.image= this.param_map["画像"];
this.character_node.add(obj);
game.nextOrder();
}
};
r9.order.CharacterRemove = {
order:"キャラ退場",
vital:["名前"],//必須項目
pm:[],
error:"",
param_map:{},
init:function(param_map){
this.param_map = param_map;
libs.checkParam(this);
this.character_node = game.character_node;
},
start:function(call_back){
var obj = {};
if(this.param_map["名前"])obj.name = this.param_map["名前"];
this.character_node.remove(obj);
game.nextOrder();
}
};
r9.order.CharacterStat = {
order:"キャラ変更",
vital:["名前"],//必須項目
pm:["画像","位置","速度","終了を待つ"],
error:"",
image_path:r9.define.CHARACTER_PATH,
init:function(param_map){
this.image_path = r9.define.CHARACTER_PATH;
this.param_map = param_map;
libs.checkParam(this);
this.character_node = game.character_node;
game.preloader.check(this);
},
start:function(call_back){
var obj = {};
if(this.param_map["名前"])obj.name = this.param_map["名前"];
if(this.param_map["画像"])obj.image = this.param_map["画像"];
if(this.param_map["位置"])obj.new_position = this.param_map["位置"];
if(this.param_map["速度"])obj.move_speed = this.param_map["速度"];
obj.comp_wait = "いいえ";
if(this.param_map["終了を待つ"])obj.comp_wait = this.param_map["終了を待つ"];
this.character_node.setState(obj);
if(game.state.enable_next_order == true){
game.nextOrder();
}
}
};
r9.order.FreeElementAdd = {
order:"エレメント追加",
vital:["名前","ソース"],//必須項目
pm:["横位置","縦位置","横幅","縦幅"],
error:"",
param_map:{},
image_path:r9.define.CHARACTER_PATH,
init:function(param_map){
this.image_path = r9.define.CHARACTER_PATH;
this.param_map = param_map;
libs.checkParam(this);
this.object_node = game.object_node;
},
start:function(call_back){
var obj = {};
if(this.param_map["名前"])obj.name = this.param_map["名前"];
if(this.param_map["ソース"])obj.src_str= this.param_map["ソース"];
if(this.param_map["横位置"])obj.left= this.param_map["横位置"];
if(this.param_map["縦位置"])obj.top= this.param_map["縦位置"];
if(this.param_map["横幅"])obj.width= this.param_map["横幅"];
if(this.param_map["縦幅"])obj.height= this.param_map["縦幅"];
this.object_node.add(obj);
game.nextOrder();
}
};
r9.order.FreeElementRemove = {
order:"エレメント削除",
vital:["名前"],//必須項目
pm:[],
error:"",
param_map:{},
init:function(param_map){
this.param_map = param_map;
libs.checkParam(this);
this.object_node = game.object_node;
},
start:function(call_back){
var obj = {};
if(this.param_map["名前"])obj.name = this.param_map["名前"];
this.object_node.remove(obj);
game.nextOrder();
}
};
r9.order.FreeImageAdd = {
order:"画像追加",
vital:["名前","画像"],//必須項目
pm:["横位置","縦位置","横幅","縦幅"],
error:"",
param_map:{},
image_path:r9.define.CHARACTER_PATH,
init:function(param_map){
this.image_path = r9.define.CHARACTER_PATH;
this.param_map = param_map;
libs.checkParam(this);
this.object_node = game.object_node;
game.preloader.check(this);
},
start:function(call_back){
var obj = {};
if(this.param_map["名前"])obj.name = this.param_map["名前"];
if(this.param_map["画像"])obj.image= this.param_map["画像"];
if(this.param_map["横位置"])obj.left= this.param_map["横位置"];
if(this.param_map["縦位置"])obj.top= this.param_map["縦位置"];
if(this.param_map["横幅"])obj.width= this.param_map["横幅"];
if(this.param_map["縦幅"])obj.height= this.param_map["縦幅"];
obj.src_str = "<img src='"+r9.define.BACKGROUND_PATH + this.param_map["画像"]+"' />";
this.object_node.add(obj);
game.nextOrder();
}
};
r9.order.FreeImageRemove = {
order:"画像削除",
vital:["名前"],//必須項目
pm:[],
error:"",
param_map:{},
init:function(param_map){
this.param_map = param_map;
libs.checkParam(this);
this.object_node = game.object_node;
},
start:function(call_back){
var obj = {};
if(this.param_map["名前"])obj.name = this.param_map["名前"];
this.object_node.remove(obj);
game.nextOrder();
}
};
r9.order.MovieAdd = {
order:"ようつべ追加",
vital:["名前","動画"],//必須項目
pm:["横位置","縦位置","横幅","縦幅","ループ","自動再生"],
error:"",
param_map:{},
init:function(param_map){
this.param_map = param_map;
libs.checkParam(this);
this.object_node = game.object_node;
},
start:function(call_back){
var obj = {};
obj.left = "260px";
obj.top  = "30px";
obj.width = "320px";
obj.height = "212px";
obj.loop  = "いいえ";
obj.autoplay ="いいえ";
if(this.param_map["名前"])obj.name = this.param_map["名前"];
if(this.param_map["動画"])obj.url= this.param_map["動画"];
if(this.param_map["横位置"])obj.left= this.param_map["横位置"];
if(this.param_map["縦位置"])obj.top= this.param_map["縦位置"];
if(this.param_map["横幅"])obj.width= this.param_map["横幅"];
if(this.param_map["縦幅"])obj.height= this.param_map["縦幅"];
if(this.param_map["ループ"])obj.loop= this.param_map["ループ"];
if(this.param_map["自動再生"])obj.autoplay= this.param_map["自動再生"];
var param_str = "";
param_str += obj.loop;
param_str += obj.autoplay;
if(obj.loop==="はい"){
param_str += "&loop=1";
}
if(obj.autoplay==="はい"){
param_str += "&autoplay=1";
}
obj.src_str = '<div style="display:none;"><object width="'+obj.width+'" height="'+obj.height+'"><param name="movie" value="http://www.youtube.com/v/'+obj.url+'?fs=1&hl=ja_JP&;rel=0'+param_str+'"></param><param name="wmode" value="transparent"><param name="allowFullScreen" value="true"></param><param name="allowscriptaccess" value="always"></param><embed src="http://www.youtube.com/v/'+obj.url+'?fs=1&hl=ja_JP&rel=0'+param_str+'" type="application/x-shockwave-flash" width="'+obj.width+'" height="'+obj.height+'" allowscriptaccess="always" allowfullscreen="true" wmode="transparent" ></embed></object></div>';
this.object_node.add(obj);
obj.element.show("fast");
game.nextOrder();
}
};
r9.order.MovieRemove = {
order:"ようつべ削除",
vital:["名前"],//必須項目
pm:[],
error:"",
param_map:{},
init:function(param_map){
this.param_map = param_map;
libs.checkParam(this);
this.object_node = game.object_node;
},
start:function(call_back){
var obj = {};
if(this.param_map["名前"])obj.name = this.param_map["名前"];
this.object_node.remove(obj);
game.nextOrder();
}
};
r9.order.Name = {
order:"名前設定",
vital:["名前"],//必須項目
error:"",
param_map:{},
init:function(param_map){
this.param_map = param_map;
},
start:function(call_back){
var name ="";
if(this.param_map["名前"])name = this.param_map["名前"];
$("#story_name").html(name);
game.nextOrder();
}
};
r9.order.Timeout = {
order:"タイムアウト",
vital:["時間"],//必須項目
error:"",
param_map:{},
init:function(param_map){
this.param_map = param_map;
},
start:function(call_back){
var time =2000;
if(this.param_map["時間"])time = this.param_map["時間"] * 1000;
game.state.enable_next_order = false;
setTimeout( function() {
game.state.enable_next_order = true;
if(r9.define.ENVIRONMENT == "iphone"){
game.nextOrder();
}else{
game.nextOrder();
}
}, time);
}
};
r9.order.TextWindow = {
order:"テキストウィンドウ",
vital:["操作"],//必須項目
pm:["時間"],
error:"",
param_map:{},
init:function(param_map){
this.param_map = param_map;
},
start:function(call_back){
var action ="消去";
var time   = 0;
if(this.param_map["操作"])action = this.param_map["操作"] ;
if(this.param_map["時間"])time = this.param_map["時間"] * 1000;
if(action ==="消去"){
$("#message_window_panel").hide();
game.state.visible_message_window = false;
}else{
time=0;
$("#message_window_panel").show();
game.state.visible_message_window = true;
}
if(time==0){
game.nextOrder();
game.state.enable_next_order = false;
}else{
setTimeout( function() {
game.state.enable_next_order = true;
game.event.clickMessageCloseButton();
game.nextOrder();
}, time);
game.state.enable_next_order = false;
}
}
};
r9.order.Sound = {
order:"効果音",
vital:["ファイル"],//必須項目
pm:["繰り返し"],
error:"",
param_map:{},
audio_obj:{},//オーディオオブジェクト　iphone用
sound_path:r9.define.SOUND_PATH,
init:function(param_map){
var that = this;
this.param_map = param_map;
if(window.flag_apri == true){
that.audio_obj = new Media(libs.getBaseURL()+""+game.base.r9game_folder+"/sound/"+ this.param_map["ファイル"],
function(){
var repeat = 1;
if(that.param_map["繰り返し"])repeat = that.param_map["繰り返し"];
if (repeat == 99999) {
if(that.audio_obj){
that.audio_obj.play();
}
}
},
function(error){
});
}else if(r9.define.ENVIRONMENT == "iphone" || r9.define.ENVIRONMENT == "andoroid"  || r9.define.VENDER_PREFIX !="Moz"){
this.audio_obj = new Audio(this.sound_path + this.param_map["ファイル"]);
this.audio_obj.load();
}
this.sound_path = r9.define.SOUND_PATH;
},
start:function(call_back){
var that = this;
var file ="",
repeat=1;
if(this.param_map["ファイル"])file = this.param_map["ファイル"];
if(this.param_map["繰り返し"])repeat = this.param_map["繰り返し"];
if(window.flag_apri == true){
if (file == "停止") {
that.audio_obj.stop();
that.audio_obj.release();
that.audio_obj = null;
game.array_audio = [];
}
else {
libs.play_audio(that.audio_obj);
}
}else if(r9.define.ENVIRONMENT =="iphone" || r9.define.ENVIRONMENT == "andoroid" || r9.define.VENDER_PREFIX !="Moz"){
if(file=="停止"){
this.audio_obj.pause();
}else{
if(repeat == 99999){
this.audio_obj.loop = true;
}
this.audio_obj.play();
}
}else{
if(file=="停止"){
game.sound_swf.stopSound();
}else{
game.sound_swf.playSound(this.sound_path + file,repeat);
}
}
game.nextOrder();
}
};
r9.order.Music = {
order:"音楽",
vital:["ファイル"],//必須項目
pm:["繰り返し"],
error:"",
param_map:{},
audio_obj:{},
sound_path:r9.define.MUSIC_PATH,
init:function(param_map){
var that = this;
this.param_map = param_map;
if(window.flag_apri == true){
that.audio_obj = new Media(libs.getBaseURL()+""+game.base.r9game_folder+"/sound/"+ that.param_map["ファイル"],
function(){
var repeat = 99999;
if(that.param_map["繰り返し"])repeat = that.param_map["繰り返し"];
if (repeat == 99999) {
if(game.array_audio.length != 0){
if(that.audio_obj){
that.audio_obj.play();
}
}
}
},
function(error){
});
game.array_audio.push(that.audio_obj);
}else{
if(r9.define.ENVIRONMENT == "iphone" || r9.define.ENVIRONMENT == "andoroid"  || r9.define.VENDER_PREFIX !="Moz"){
this.audio_obj = new Audio(this.sound_path + this.param_map["ファイル"]);
this.audio_obj.load();
game.array_audio.push(this.audio_obj);
}
}
this.sound_path = r9.define.MUSIC_PATH;
},
start:function(call_back){
var that = this;
var file ="",
repeat=99999;
if(this.param_map["ファイル"])file = this.param_map["ファイル"];
if(this.param_map["繰り返し"])repeat = this.param_map["繰り返し"];
if(window.flag_apri == true){
if (file == "停止") {
for (var i = 0; i < game.array_audio.length; i++) {
game.array_audio[i].stop();
game.array_audio[i].release();
game.array_audio[i] = null;
}
game.array_audio = [];
}
else {
libs.play_audio(that.audio_obj);
}
}else if(r9.define.ENVIRONMENT =="iphone" || r9.define.ENVIRONMENT == "andoroid"  || r9.define.VENDER_PREFIX !="Moz"){
if(file=="停止"){
for(var i=0;i<game.array_audio.length;i++){
game.array_audio[i].pause();
}
}else{
if(repeat == 99999){
this.audio_obj.loop = true;
}
this.audio_obj.play();
}
}else{
if(file=="停止"){
game.sound_swf.stopMusic();
}else{
game.sound_swf.playMusic(this.sound_path + file,repeat);
}
}
game.current_music = file;
game.nextOrder();
}
};
r9.order.Jump = {
order:"ジャンプ",
vital:["行き先"],//必須項目
pm:["条件"],
error:"",
param_map:{},
flag_key:"",
flag_value:"",
init:function(param_map){
this.param_map = param_map;
if(this.param_map["条件"]){
var tmp_array = (this.param_map["条件"]).split("-");
var flag_key = libs.rmspace(tmp_array[0]);
var flag_value = libs.rmspace(tmp_array[1]);
this.flag_key = flag_key;
this.flag_value = flag_value;
if(game.flag.map_flag[flag_key]){
}else{
this.error+="ジャンプ条件のフラグ「"+flag_key+"」が定義されていません。flag.txtを確認してください";
}
}else{
}
},
start:function(call_back){
if(this.flag_key!=""){
if(game.flag.map_flag[this.flag_key]==this.flag_value){
}else{
game.nextOrder();
return;
}
}
var goto_point ="";
if(this.param_map["行き先"])goto_point = this.param_map["行き先"];
var first_one = goto_point.substr(0,1);
if(first_one == ">"){
var mark_name = goto_point.replace(">","");
if(game.mark[mark_name]){
game.current_index = parseInt(game.mark[mark_name]) ;
}else{
}
game.nextOrder();
}else if(goto_point == "タイトル"){
game.character_node.clear();
game.object_node.clear();
$("#contents_panel").empty();
$("#story_text").html("");
$("#story_name").html("");
$("#message_window_panel").hide();
var title = object(r9.Title);
title.init(r9game_folder);
}else{
game.jump(goto_point);
}
}
};
r9.order.Flag = {
order:"フラグ",
vital:["フラグ名","値"],//必須項目
pm:[],
error:"",
param_map:{},
init:function(param_map){
this.param_map = param_map;
libs.checkParam(this);
try{
var key = this.param_map["フラグ名"];
var val = this.param_map["値"];
if(game.flag.map_flag[key]){
}else{
this.error +="フラグ["+key+"]に値を格納できません。flag.txtの定義を確認してください";
}
}catch(e){
}
},
start:function(call_back){
var key = this.param_map["フラグ名"];
var val = this.param_map["値"];
if(game.flag.map_flag[key]){
game.flag.map_flag[key] = val ;
}else{
error +="フラグ["+key+"]に値を格納できません。flag.txtの定義を確認してください";
}
game.nextOrder();
}
};
r9.order.Video = {
order:"ビデオ",
vital:["ファイル"],//必須項目
pm:["スキップ"],
error:"",
param_map:{},
image_path:r9.define.VIDEO_PATH,
init:function(param_map){
this.image_path = r9.define.VIDEO_PATH;
this.param_map = param_map;
libs.checkParam(this);
},
start:function(call_back){
var that = this;
if(r9.define.ENVIRONMENT == "iphone" || r9.define.ENVIRONMENT == "andoroid"){
$("#noveljs").click(function(e){
$("#noveljs").unbind("click",arguments.callee, false);
that.playVideo(that,call_back);
});
}else{
that.playVideo(that,call_back);
}
},
playVideo:function(that,call_back){
game.state.enable_next_order = false;
var url = that.image_path + that.param_map["ファイル"];
var video = document.createElement('video');
video.setAttribute('myvideo');
video.src = url;
video.style.backgroundColor = "black";
video.style.zIndex=99999;
video.style.position="absolute";
video.style.top="0px";
video.style.left="0px";
video.style.width="100%";
video.style.height="100%";
video.autoplay = true;
video.autobuffer = true;
video.addEventListener("ended",function(e){
game.state.enable_next_order = true;
$("#noveljs").find("video").remove();
});
document.getElementById("noveljs").appendChild(video);
video.load();
video.play();
},
};
r9.order.Divergence = {
order:"分岐",
vital:[],//必須項目
pm:["選択肢の文章"],
error:"",
param_map:{},
init:function(param_map){
this.param_map = param_map;
},
start:function(call_back){
var num = 50;
var array_select_element = [];
var that = this;
game.state.now_divergence = true;
for(select_str in this.param_map){
(function(){
var element = $("<div style='display:none;z-index:10;cursor:pointer;padding:5px;font-size:16px;left:100px;top:" + num + "px;width:400px;position:relative;background-color:black;color:white;border:solid 1px gray' >" + select_str + "</div>");
var that_select = select_str;
element.click(function(ev){
$("#message_window_panel").show();
game.state.visible_message_window = true;
game.state.now_divergence = false;
var jump_point = that.param_map[that_select];
var obj = object(r9.order.Jump);
obj.param_map["行き先"] = jump_point;
obj.start();
for(var i=0;i<array_select_element.length;i++){
array_select_element[i].hide("slow");
}
element.unbind();
if (ev) {
ev.stopImmediatePropagation();
}
});
element.mouseover(function(e){
element.css("background-color","white");
element.css("color","black");
});
element.mouseout(function(e){
element.css("background-color","black");
element.css("color","white");
});
$("#contents_panel").append(element);
array_select_element.push(element);
element.show("normal");
$("#message_window_panel").hide();
game.state.visible_message_window = false;
})();
num+=25;
}
}
};
r9.Libs = {
ready:false,
isNull:function(obj)
{
if(obj){
return obj;
}
return "";
},
trim:function(str){
return str.replace(/(^\s+)|(\s+$)/g, "");
},
getBaseURL:function(){
var str = location.pathname;
var i = str.lastIndexOf('/');
return str.substring(0,i+1);
},
getViewPort : function() {
var width, heiht;
if (self.innerHeight) {
width = self.innerWidth;
height = self.innerHeight;
} else if (document.documentElement && document.documentElement.clientHeight) {
width = document.documentElement.clientWidth;
height = document.documentElement.clientHeight;
} else if (document.body) {
width = document.body.clientWidth;
height = document.body.clientHeight;
}
return {width: width, height: height};
},
play_audio:function(audio_obj){
audio_obj.play();
},
rmspace:function(str){
str = str.replace(/ /g,"");
str = str.replace(/　/g,"");
str = str.replace(/\r\n?/g,"");
return str;
},
checkParam:function(obj){
var vital_array = obj.vital;
var param_map   = obj.param_map;
for(var i=0;i<vital_array.length;i++){
if(param_map[vital_array[i]]){
}else{
obj.error += obj.order+"には["+obj.vital[i]+"]が必要です";
}
}
},
swfName:function(str) {
if (navigator.appName.indexOf("Microsoft") != -1) {
return window[str];
}else {
return document[str];
}
},
error:function (num,str){
return num+1 + "行目："+str+"\n";
},
log:function(str){
},
getCookie:function(key){
var tmp = document.cookie + ";";
var index1 = tmp.indexOf(key, 0);
if(index1 != -1){
tmp = tmp.substring(index1,tmp.length);
var index2 = tmp.indexOf("=",0) + 1;
var index3 = tmp.indexOf(";",index2);
return(unescape(tmp.substring(index2,index3)));
}
return("");
},
setCookie:function (key, val){
document.cookie = key + "=" + escape(val) + ";expires=Fri, 31-Dec-2030 23:59:59;";
},
setStorage:function(key,val){
localStorage.setItem(key, escape(val));
},
getStorage:function(key){
var gv = "null";
if(localStorage.getItem(key)){
gv = unescape(localStorage.getItem(key));
}
if(gv =="null") return null;
return gv;
},
createParamObject:function(str){
var param_map ={};
var array = str.split("\n");
var error_str ="";
for (var i = 0; i < array.length; i++) {
try {
var str = libs.rmspace(array[i]);
var tmp_array = str.split("=");
var order = tmp_array[0];
var param = tmp_array[1];
param_map[order] = param;
}catch(e){
error_str +="";
}
}
return param_map;
},
getNowDate:function(){
var nowdate = new Date();
var year = nowdate.getFullYear();
var mon  = nowdate.getMonth() + 1;
var date = nowdate.getDate();
return year+"/"+mon+"/"+date;
},
getNowTime:function(){
var nowdate = new Date();
var h = nowdate.getHours();
var m = nowdate.getMinutes();
var s = nowdate.getSeconds();
return h+"："+m+"："+s;
},
cutstr:function(str ,num){
if(str){
if(str.length > num){
str = str.substring(0,num) + "…";
}
}else{
return null;
}
return str;
},
getYoutubeID:function(url_str){
var pos1 = url_str.indexOf("v=");
var tmp_str = url_str.substring(pos1);
var pos2 = tmp_str.indexOf("&");
var tmp_str2 = tmp_str.substring(0,pos2);
return tmp_str2;
},
esc:function(str){
if(str){
return $("<div/>").text(str).html();
}else{
return "";
}
},
h:function(val){
return $('<div>').text(val).html();
},
func:function(){
}	};
$.event.tap = function(o) {
o.bind('touchstart', onTouchStart_);
function onTouchStart_(e) {
e.preventDefault();
o.data('event.tap.moved', false)
.one('touchmove', onTouchMove_)
.one('touchend', onTouchEnd_);
e.stopPropagation();
}
function onTouchMove_(e) {
o.data('event.tap.moved', true);
e.stopPropagation();
}
function onTouchEnd_(e) {
if (!o.data('event.tap.moved')) {
o.unbind('touchmove', onTouchMove_);
o.trigger('click').click();
e.stopPropagation();
}
}
};
if ('ontouchend' in document) {
$.fn.tap = function(data, fn) {
if (fn == null) {
fn = data;
data = null;
}
if (arguments.length > 0) {
this.bind('tap', data, fn);
$.event.tap(this);
} else {
this.trigger('tap');
}
return this;
};
if ($.attrFn) {
$.attrFn['tap'] = true;
}
$.fn.click = $.fn.tap;
} else {
}